@@ -1,4 +1,4 @@
-/* $Id: cpl_error.h,v 1.81 2012/05/02 15:00:08 llundin Exp $
+/* $Id: cpl_error.h,v 1.81.2.1 2013/05/02 09:39:31 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/05/02 15:00:08 $
- * $Revision: 1.81 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/05/02 09:39:31 $
+ * $Revision: 1.81.2.1 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifndef CPL_ERROR_H
@@ -352,8 +352,8 @@ CPL_BEGIN_DECLS
 #define cpl_error_set_message(function, code, ...)                             \
     cpl_error_set_message_macro(function, code, __FILE__, __LINE__, __VA_ARGS__)
 #else
-#define cpl_error_set_message_one(function, code, text)                        \
-    cpl_error_set_message_macro(function, code, __FILE__, __LINE__, text)
+#define cpl_error_set_message(function, code, text)                        \
+    cpl_error_set_message_one_macro(function, code, __FILE__, __LINE__, text)
 #endif
 
 /*-----------------------------------------------------------------------------
