@@ -1,4 +1,4 @@
-/* $Id: cpl_image_basic_body.h,v 1.99 2012/05/03 12:07:07 llundin Exp $
+/* $Id: cpl_image_basic_body.h,v 1.100 2012/12/13 11:41:39 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -138,6 +138,29 @@ static cpl_error_code CPL_TYPE_ADD(cpl_image_exponential)(cpl_image *, double);
 
 static cpl_error_code CPL_TYPE_ADD(cpl_image_logarithm)(cpl_image *, double);
 
+static void CPL_TYPE_ADD(cpl_image_flip)(CPL_TYPE *, size_t) CPL_ATTR_NONNULL;
+
+/*----------------------------------------------------------------------------*/
+/**
+  @internal
+  @brief    Flip (reverse the order of) the elements
+  @param    self  The array
+  @param    n     The (positive) array size
+  @return   void
+
+ */
+/*----------------------------------------------------------------------------*/
+static void CPL_TYPE_ADD(cpl_image_flip)(CPL_TYPE * self, size_t n)
+{
+    size_t i;
+
+    for (i = 0; i < n/2; i++) {
+        const CPL_TYPE tmp = self[i];
+        self[i] = self[n-1-i];
+        self[n-1-i] = tmp;
+    }
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @internal
@@ -1323,6 +1346,14 @@ CPL_TYPE_ADD(cpl_image_collapse_window_create)(const cpl_image * self,
                     /* No pixels need to move - just swap nx and ny */
                     self->nx = self->ny;
                     self->ny = 1;
+                } else if (self->ny == 1) {
+                    /* The image is a single horizontal row,
+                       the order of the pixels needs to be reversed */
+  
+                    /* Flip the 1D-image and swap nx and ny */
+                    CPL_TYPE_ADD(cpl_image_flip)(pi, (size_t)self->nx);
+                    self->ny = self->nx;
+                    self->nx = 1;
                 } else {
                     /* Duplicate the input image :-( */
                     cpl_image      * tmp = cpl_image_duplicate(self);
@@ -1343,15 +1374,12 @@ CPL_TYPE_ADD(cpl_image_collapse_window_create)(const cpl_image * self,
                 break;
             }
             case 2: {
-                CPL_TYPE * pi = (CPL_TYPE *)self->pixels;
-                size_t   i;
-                size_t   j = self->nx * self->ny - 1;
+                /* A 180 degree rotation preserves the shape of the image,
+                   and reverts the order of the pixels */
 
-                for (i = 0; i < j; i++, j--) {
-                    const CPL_TYPE tmp = pi[i];
-                    pi[i] = pi[j];
-                    pi[j] = tmp;
-                }
+                CPL_TYPE_ADD(cpl_image_flip)((CPL_TYPE *)self->pixels,
+                                             (size_t)self->nx *
+                                             (size_t)self->ny);
                 break;
             }
             case 3: {
@@ -1379,6 +1407,14 @@ CPL_TYPE_ADD(cpl_image_collapse_window_create)(const cpl_image * self,
                     /* No pixels need to move - just swap nx and ny */
                     self->ny = self->nx;
                     self->nx = 1;
+                } else if (self->nx == 1) {
+                    /* The image is a single vertical solumn,
+                       the order of the pixels needs to be reversed */
+
+                    /* Flip the 1D-image and swap nx and ny */
+                    CPL_TYPE_ADD(cpl_image_flip)(pi, (size_t)self->ny);
+                    self->nx = self->ny;
+                    self->ny = 1;
                 } else {
                     /* Duplicate the input image :-( */
                     cpl_image      * tmp = cpl_image_duplicate(self);
@@ -1430,11 +1466,7 @@ CPL_TYPE_ADD(cpl_image_collapse_window_create)(const cpl_image * self,
         case 2: {
 
             for (j = 0; j < ny; j++, pi += nx) {
-                for (i = 0; i < nx/2; i++) {
-                    const CPL_TYPE tmp = pi[i];
-                    pi[i] = pi[nx-1-i];
-                    pi[nx-1-i] = tmp;
-                }
+                CPL_TYPE_ADD(cpl_image_flip)(pi, nx);
             }
             break;
         }
