@@ -1,4 +1,4 @@
-/* $Id: cpl_image_bpm.c,v 1.48 2011/12/20 10:15:02 llundin Exp $
+/* $Id: cpl_image_bpm.c,v 1.50 2012/12/10 13:19:48 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2011/12/20 10:15:02 $
- * $Revision: 1.48 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/12/10 13:19:48 $
+ * $Revision: 1.50 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,23 +34,114 @@
  -----------------------------------------------------------------------------*/
 
 #include "cpl_image_bpm.h"
-#include "cpl_mask.h"
 #include "cpl_tools.h"
 
 #include "cpl_error_impl.h"
-
 #include "cpl_image_defs.h"
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
+/* Needed for fpclassify() */
 #include <math.h>
 
+/*-----------------------------------------------------------------------------
+                                   Defines
+ -----------------------------------------------------------------------------*/
+
+/* These macros are needed for support of the different pixel types */
+
+#define CONCAT(a,b) a ## _ ## b
+#define CONCAT2X(a,b) CONCAT(a,b)
+
+#define ADDTYPE(a) CONCAT2X(a, CPL_TYPE_NAME)
+
+/*-----------------------------------------------------------------------------
+                            Static Function Prototypes
+ -----------------------------------------------------------------------------*/
+
+#define CPL_TYPE double
+#define CPL_TYPE_NAME double
+#include "cpl_image_bpm_body.h"
+#undef CPL_TYPE
+#undef CPL_TYPE_NAME
+
+#define CPL_TYPE float
+#define CPL_TYPE_NAME float
+#include "cpl_image_bpm_body.h"
+#undef CPL_TYPE
+#undef CPL_TYPE_NAME
+
+#ifdef CPL_FPCLASSIFY_COMPLEX
+#define CPL_TYPE double complex
+#define CPL_TYPE_NAME double_complex
+#include "cpl_image_bpm_body.h"
+#undef CPL_TYPE
+#undef CPL_TYPE_NAME
+
+#define CPL_TYPE float complex
+#define CPL_TYPE_NAME float_complex
+#include "cpl_image_bpm_body.h"
+#undef CPL_TYPE
+#undef CPL_TYPE_NAME
+#endif
+
+#define CPL_TYPE int
+#define CPL_TYPE_NAME int
+#define CPL_TYPE_IS_INT
+#include "cpl_image_bpm_body.h"
+#undef CPL_TYPE
+#undef CPL_TYPE_NAME
+#undef CPL_TYPE_IS_INT
+
 /*-----------------------------------------------------------------------------
                             Function codes
  -----------------------------------------------------------------------------*/
 
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Reject pixels with the specified special value(s)
+  @param    self   Input image to modify
+  @param    mode   Bit field specifying which special value(s) to reject
+
+  Possible #_cpl_error_code_ set in this function:
+  - CPL_ERROR_NULL_INPUT if an input pointer is NULL
+  - CPL_ERROR_INVALID_TYPE if mode is 1, e.g. due to a logical or (||)
+      of the allowed options or if the pixel type is complex
+  - CPL_ERROR_UNSUPPORTED_MODE if mode is otherwise different from the
+       allowed options.
+*/
+/*----------------------------------------------------------------------------*/
+cpl_error_code cpl_image_reject_value(cpl_image * self, cpl_value mode)
+{
+
+    cpl_error_code error = CPL_ERROR_NONE;
+
+    switch (cpl_image_get_type(self)) {
+    case CPL_TYPE_DOUBLE:
+        error = cpl_image_reject_value_double(self, mode);
+        break;
+    case CPL_TYPE_FLOAT:
+        error = cpl_image_reject_value_float(self, mode);
+        break;
+#ifdef CPL_FPCLASSIFY_COMPLEX
+    case CPL_TYPE_DOUBLE_COMPLEX:
+        error = cpl_image_reject_value_double_complex(self, mode);
+        break;
+    case CPL_TYPE_FLOAT_COMPLEX:
+        error = cpl_image_reject_value_float_complex(self, mode);
+        break;
+#endif
+    case CPL_TYPE_INT:
+        error = cpl_image_reject_value_int(self, mode);
+        break;
+    default:
+        /* NULL input and unsupported pixel types */
+        error = self != NULL ? CPL_ERROR_INVALID_TYPE : CPL_ERROR_NULL_INPUT;
+        break;
+    }
+
+    return error ? cpl_error_set_(error) : CPL_ERROR_NONE;
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @ingroup cpl_image
