@@ -1,4 +1,4 @@
-/* $Id: cpl_image_bpm.h,v 1.19 2011/07/19 14:37:27 llundin Exp $
+/* $Id: cpl_image_bpm.h,v 1.20 2012/12/07 13:51:34 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2011/07/19 14:37:27 $
- * $Revision: 1.19 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/12/07 13:51:34 $
+ * $Revision: 1.20 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifndef CPL_IMAGE_BPM_H
@@ -38,6 +38,64 @@
 
 CPL_BEGIN_DECLS
 
+/*-----------------------------------------------------------------------------
+                                   New types
+ -----------------------------------------------------------------------------*/
+
+/**
+ * @ingroup cpl_image
+ *
+ * @brief The special values that can be rejected
+ * They are a bit-field and can be combined with bitwise or.
+ */
+
+enum _cpl_value_ {
+
+/* No entry has the value 1 which makes the (mis)use of logical or detectable */
+
+    /**
+     * Not-a-Number (NaN)
+     * @hideinitializer
+     */
+    CPL_VALUE_NAN        =  1 << 1,
+    /**
+     * Plus Infinity
+     * @hideinitializer
+     */
+    CPL_VALUE_PLUSINF    =  1 <<  2,
+    /**
+     * Minus Infinity
+     * @hideinitializer
+     */
+    CPL_VALUE_MINUSINF   =  1 <<  3,
+    /**
+     * Zero
+     * @hideinitializer
+     */
+    CPL_VALUE_ZERO       =  1 <<  4,
+    /**
+     * Infinity with any sign
+     * @hideinitializer
+     */
+    CPL_VALUE_INF        =  CPL_VALUE_PLUSINF | CPL_VALUE_MINUSINF,
+    /**
+     * NaN or infinity with any sign
+     * @hideinitializer
+     */
+    CPL_VALUE_NOTFINITE  =  CPL_VALUE_INF | CPL_VALUE_NAN
+};
+
+
+/**
+ * @ingroup cpl_image
+ *
+ * @brief
+ *   The CPL special value. It is a bit field.
+ */
+typedef enum _cpl_value_ cpl_value;
+
+
+
 /*-----------------------------------------------------------------------------
                             Function prototypes
  -----------------------------------------------------------------------------*/
@@ -51,6 +109,7 @@ cpl_error_code cpl_image_reject(cpl_image *, cpl_size, cpl_size);
 cpl_error_code cpl_image_accept(cpl_image *, cpl_size, cpl_size);
 cpl_error_code cpl_image_accept_all(cpl_image *);
 cpl_error_code cpl_image_reject_from_mask(cpl_image *, const cpl_mask *);
+cpl_error_code cpl_image_reject_value(cpl_image *, cpl_value);
 
 CPL_END_DECLS
 
