@@ -1,4 +1,4 @@
-/* $Id: cpl_image_filter.c,v 1.126 2011/08/18 13:03:37 llundin Exp $
+/* $Id: cpl_image_filter.c,v 1.131 2013/02/22 16:03:33 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2011/08/18 13:03:37 $
- * $Revision: 1.126 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/22 16:03:33 $
+ * $Revision: 1.131 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -194,17 +194,19 @@ static cpl_mask * cpl_mask_new_from_matrix(const cpl_matrix *, double, double);
   kernel.
 
   Supported modes:
+
   CPL_FILTER_MEDIAN:
-      1x1 kernel or no bad pixels and kernel all ones:
          CPL_BORDER_FILTER, CPL_BORDER_COPY, CPL_BORDER_NOP, CPL_BORDER_CROP.
-      Otherwise:
-         CPL_BORDER_FILTER, CPL_BORDER_COPY, CPL_BORDER_NOP
+
   CPL_FILTER_AVERAGE:
          CPL_BORDER_FILTER
+
   CPL_FILTER_AVERAGE_FAST:
          CPL_BORDER_FILTER
+
   CPL_FILTER_STDEV:
          CPL_BORDER_FILTER
+
   CPL_FILTER_STDEV_FAST:
          CPL_BORDER_FILTER
 
@@ -288,10 +290,7 @@ cpl_error_code cpl_image_filter_mask(cpl_image * self,
        4)    bpm,     full kernel
     */
 
-    /* Input type 1 */
-    void               (*filter_func)(void *, const void *, const cpl_binary *,
-                                      cpl_size, cpl_size, cpl_size, cpl_size,
-                                      cpl_border_mode);
+    /* Input type 1: Not used (yet) */
     /* Input type 2 */
     void               (*filter_fast)(void *, const void *,
                                       cpl_size, cpl_size, cpl_size, cpl_size,
@@ -384,7 +383,6 @@ cpl_error_code cpl_image_filter_mask(cpl_image * self,
                      (size_t)mx * (size_t)my * sizeof(*pmask)) == NULL
         ? CPL_TRUE : CPL_FALSE;
 
-    filter_func = NULL;
     filter_fast = NULL;
     filter_bpm  = NULL;
     filter_full = NULL;
@@ -856,11 +854,6 @@ cpl_error_code cpl_image_filter_mask(cpl_image * self,
                     cpl_image_get_data_const(other),
                     nx, ny, hsizex, hsizey,
                     (unsigned)border);
-    } else if (filter_func != NULL) {
-        filter_func(cpl_image_get_data(self),
-                    cpl_image_get_data_const(other),
-                    pmask, nx, ny, hsizex, hsizey,
-                    (unsigned)border);
     } else if (filter_full != NULL) {
         filter_full(cpl_image_get_data(self), &pbpmself,
                    cpl_image_get_data_const(other), badmap,
@@ -904,20 +897,26 @@ cpl_error_code cpl_image_filter_mask(cpl_image * self,
   The kernel must have an odd number of rows and an odd number of columns
   and at least one non-zero element.
 
-  For a filtered pixel at least one input pixel with a non-zero weight must
-  be available. Output pixels where this is not the case are set to zero and
-  flagged as rejected.
+  For scaling filters (@c CPL_FILTER_LINEAR_SCALE and
+  @c CPL_FILTER_MORPHO_SCALE) the flux of the filtered image will be scaled
+  with the sum of the weights of the kernel. If for a given input pixel location
+  the kernel covers only bad pixels, the filtered pixel value is flagged as
+  bad and set to zero.
+
+  For flux-preserving filters (@c CPL_FILTER_LINEAR and @c CPL_FILTER_MORPHO)
+  the filtered pixel must have at least one input pixel with a non-zero weight
+  available. Output pixels where this is not the case are set to zero and
+  flagged as bad.
 
   In-place filtering is not supported, but if the two images have the same
   pixel type, then the input pixel buffer may overlap all but the 1+H first
   rows of the output pixel buffer, where 1+2*H is the number of rows in the
   kernel.
 
-  Supported modes:
-  CPL_FILTER_LINEAR:
-         CPL_BORDER_FILTER
-  CPL_FILTER_MORPHO:
-         CPL_BORDER_FILTER
+  Supported filters: @c CPL_FILTER_LINEAR, @c CPL_FILTER_MORPHO,
+                     @c CPL_FILTER_LINEAR_SCALE, @c CPL_FILTER_MORPHO_SCALE.
+
+  Supported borders modes: @c CPL_BORDER_FILTER
 
    @par Example:
    @code
@@ -929,7 +928,7 @@ cpl_error_code cpl_image_filter_mask(cpl_image * self,
   while the 1st element in a matrix  - at (0,0) - is the top left. Thus to
   shift an image 1 pixel up and 1 pixel right with the CPL_FILTER_LINEAR and
   a 3 by 3 kernel, one should set to 1.0 the bottom leftmost matrix element
-  - at row 3, column 1, i.e.
+  which is at row 3, column 1, i.e.
   @code
       cpl_matrix_set(kernel, 2, 0);
   @endcode
@@ -988,9 +987,11 @@ cpl_error_code cpl_image_filter(cpl_image        * self,
     cpl_error_code     (*filter_func)(void *, cpl_binary **,
                                       const void *, const cpl_binary *,
                                       const double *, cpl_size, cpl_size,
+                                      cpl_boolean,
                                       cpl_size, cpl_size, cpl_border_mode);
     cpl_boolean  same_type = cpl_image_get_type(self)
         == cpl_image_get_type(other);
+    cpl_boolean dodiv = CPL_FALSE;
     cpl_size i;
 
     cpl_ensure_code(self    != NULL, CPL_ERROR_NULL_INPUT);
@@ -1045,11 +1046,13 @@ cpl_error_code cpl_image_filter(cpl_image        * self,
 
     filter_func = NULL;
 
-    if (filter == CPL_FILTER_LINEAR) {
+    if (filter == CPL_FILTER_LINEAR || filter == CPL_FILTER_LINEAR_SCALE) {
 
         cpl_ensure_code(border == CPL_BORDER_FILTER,
                         CPL_ERROR_UNSUPPORTED_MODE);
 
+        dodiv = filter == CPL_FILTER_LINEAR;
+
         switch (cpl_image_get_type(self)) {
         case CPL_TYPE_DOUBLE: {
             switch (cpl_image_get_type(other)) {
@@ -1120,11 +1123,14 @@ cpl_error_code cpl_image_filter(cpl_image        * self,
             return cpl_error_set_(CPL_ERROR_INVALID_TYPE);
         }
 
-    } else if (filter == CPL_FILTER_MORPHO) {
+    } else if (filter == CPL_FILTER_MORPHO ||
+               filter == CPL_FILTER_MORPHO_SCALE) {
 
         cpl_ensure_code(border == CPL_BORDER_FILTER,
                         CPL_ERROR_UNSUPPORTED_MODE);
 
+        dodiv = filter == CPL_FILTER_MORPHO;
+
         switch (cpl_image_get_type(self)) {
         case CPL_TYPE_DOUBLE: {
             switch (cpl_image_get_type(other)) {
@@ -1200,9 +1206,8 @@ cpl_error_code cpl_image_filter(cpl_image        * self,
 
     if (filter_func(cpl_image_get_data(self), &pbpmself,
                     cpl_image_get_data_const(other), badmap,
-                    pkernel, nx, ny,
-                    hsizex, hsizey,
-                    border)) {
+                    pkernel, nx, ny, dodiv,
+                    hsizex, hsizey, border)) {
         return cpl_error_set_where_();
     }
 
