@@ -1,4 +1,4 @@
-/* $Id: cpl_image_filter_body.h,v 1.77 2012/01/20 16:00:32 llundin Exp $
+/* $Id: cpl_image_filter_body.h,v 1.80 2012/12/13 13:28:54 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -49,12 +49,14 @@ static cpl_error_code
 ADDTYPE_TWO(cpl_filter_linear_slow)(void *, cpl_binary **,
                                     const void *, const cpl_binary *,
                                     const double *, cpl_size, cpl_size,
+                                    cpl_boolean,
                                     cpl_size, cpl_size, cpl_border_mode);
 
 static cpl_error_code
 ADDTYPE_TWO(cpl_filter_morpho_slow)(void *, cpl_binary **,
                                     const void *, const cpl_binary *,
                                     const double *, cpl_size, cpl_size,
+                                    cpl_boolean,
                                     cpl_size, cpl_size, cpl_border_mode);
 
 #ifndef CPL_FILTER_NO_RECIPROCAL
@@ -170,11 +172,14 @@ ADDTYPE(cpl_filter_median_slow)(void * vout, cpl_binary ** ppbpm,
                 }
             }
         }
-    } else if (mode == CPL_BORDER_NOP || mode == CPL_BORDER_COPY) {
+    } else if (mode == CPL_BORDER_NOP || mode == CPL_BORDER_COPY ||
+               mode == CPL_BORDER_CROP) {
         OUT_TYPE      * out = (OUT_TYPE*)vout;
         const IN_TYPE * in  = (const IN_TYPE*)vin;
         IN_TYPE window[(2 * rx + 1) * (2 * ry + 1)];
         cpl_size     x, y;
+        cpl_size     nxo = mode == CPL_BORDER_CROP ? nx - 2 * rx : nx;
+        cpl_size     nyo = mode == CPL_BORDER_CROP ? ny - 2 * ry : ny;
 
         if (mode == CPL_BORDER_COPY) {
             /* Copy the first ry row(s) and
@@ -185,10 +190,12 @@ ADDTYPE(cpl_filter_median_slow)(void * vout, cpl_binary ** ppbpm,
         for (y = ry; y < ny - ry; y++) {
             const size_t y_1 = y - ry;
             const size_t y2  = y + ry;
+            const size_t yo = mode == CPL_BORDER_CROP ? y_1 : (size_t)y;
 
             for (x = rx; x < nx - rx; x++) {
                 const size_t     x1 = x - rx;
                 const size_t     x2 = x + rx;
+                const size_t     xo = mode == CPL_BORDER_CROP ? x1 : (size_t)x;
                 const IN_TYPE    * inj  = in + y_1 * nx;
                 const cpl_binary * pmaskj = pmask
                      + (rx - x) + ((ry - y) + y_1) * (2 * rx + 1);
@@ -215,15 +222,16 @@ ADDTYPE(cpl_filter_median_slow)(void * vout, cpl_binary ** ppbpm,
                     }
                 }
                 if (k > 0) {
-                    out[x + y * nx] = ADDTYPE(cpl_tools_get_median)(window, k);
+                    out[xo + yo * nxo] =
+                        ADDTYPE(cpl_tools_get_median)(window, k);
                 } else {
                     /* Flag as bad - and set to zero */
                     if (*ppbpm == NULL) {
-                        *ppbpm = cpl_calloc((size_t)nx * (size_t)ny,
+                        *ppbpm = cpl_calloc((size_t)nxo * (size_t)nyo,
                                             sizeof(cpl_binary));
                     }
-                    (*ppbpm)[x + y * nx] = CPL_BINARY_1;
-                    out[x + y * nx] = (OUT_TYPE)0;
+                    (*ppbpm)[xo + yo * nxo] = CPL_BINARY_1;
+                    out[xo + yo * nxo] = (OUT_TYPE)0;
                 }
             }
 
@@ -1594,6 +1602,7 @@ ADDTYPE_TWO(cpl_filter_average_bpm)(void * vout, cpl_binary ** pbpm,
    @param  pkernel The kernel
    @param  nx      image width
    @param  ny      image height
+   @param  dodiv   CPL_TRUE for division by the kernel absolute weights sum
    @param  rx      filtering half-size in x
    @param  ry      filtering half-size in y
    @return void
@@ -1608,6 +1617,7 @@ ADDTYPE_TWO(cpl_filter_linear_slow)(void * vout, cpl_binary ** ppbpm,
                                     const cpl_binary * bpm,
                                     const double * pkernel,
                                     cpl_size nx, cpl_size ny,
+                                    cpl_boolean dodiv,
                                     cpl_size rx, cpl_size ry,
                                     cpl_border_mode mode)
 {
@@ -1635,6 +1645,9 @@ ADDTYPE_TWO(cpl_filter_linear_slow)(void * vout, cpl_binary ** ppbpm,
                     + (rx - x) + (ry + y - y_1) * (2 * rx + 1);
                 double             sum    = 0.0;
                 double             weight = 0.0;
+                /* True iff the filtered pixel has contributing input pixels
+                   (ignoring zero-valued weigths) */
+                cpl_boolean isok = bpm == NULL;
                 size_t i, j;
 
                 if (bpm == NULL) {
@@ -1642,7 +1655,7 @@ ADDTYPE_TWO(cpl_filter_linear_slow)(void * vout, cpl_binary ** ppbpm,
                              pkernelj -= 2 * rx + 1) {
                         for (i = x1; i < 1 + x2; i++) {
                             sum += pkernelj[i] * (double)inj[i];
-                            weight += fabs(pkernelj[i]);
+                            if (dodiv) weight += fabs(pkernelj[i]);
                         }
                     }
                 } else {
@@ -1653,13 +1666,14 @@ ADDTYPE_TWO(cpl_filter_linear_slow)(void * vout, cpl_binary ** ppbpm,
                         for (i = x1; i < 1 + x2; i++) {
                             if (!bpmj[i]) {
                                 sum += pkernelj[i] * (double)inj[i];
-                                weight += fabs(pkernelj[i]);
+                                if (dodiv) weight += fabs(pkernelj[i]);
+                                else isok = CPL_TRUE;
                             }
                         }
                     }
                 }
-                if (weight > 0.0) {
-                    sum /= weight;
+                if (dodiv ? weight > 0.0 : isok) {
+                    if (dodiv) sum /= weight;
                 } else {
                     /* Flag as bad - and set to zero */
                     if (*ppbpm == NULL) {
@@ -1692,6 +1706,7 @@ ADDTYPE_TWO(cpl_filter_linear_slow)(void * vout, cpl_binary ** ppbpm,
    @param  pkernel The kernel
    @param  nx      image width
    @param  ny      image height
+   @param  dodiv   CPL_TRUE for division by the kernel absolute weights sum
    @param  rx      filtering half-size in x
    @param  ry      filtering half-size in y
    @return void
@@ -1706,6 +1721,7 @@ ADDTYPE_TWO(cpl_filter_morpho_slow)(void * vout, cpl_binary ** ppbpm,
                                     const cpl_binary * bpm,
                                     const double * pkernel,
                                     cpl_size nx, cpl_size ny,
+                                    cpl_boolean dodiv,
                                     cpl_size rx, cpl_size ry,
                                     cpl_border_mode mode)
 {
@@ -1735,7 +1751,7 @@ ADDTYPE_TWO(cpl_filter_morpho_slow)(void * vout, cpl_binary ** ppbpm,
                     for (j = y_1; j < 1 + y2; j++, inj += nx) {
                         for (i = x1; i < 1 + x2; i++) {
                             window[k] = inj[i];
-                            weight += fabs(pkernel[k]);
+                            if (dodiv) weight += fabs(pkernel[k]);
                             k++;
                         }
                     }
@@ -1746,20 +1762,20 @@ ADDTYPE_TWO(cpl_filter_morpho_slow)(void * vout, cpl_binary ** ppbpm,
                         for (i = x1; i < 1 + x2; i++) {
                             if (!bpmj[i]) {
                                 window[k] = inj[i];
-                                weight += fabs(pkernel[k]);
+                                if (dodiv) weight += fabs(pkernel[k]);
                                 k++;
                             }
                         }
                     }
                 }
-                if (weight > 0.0) {
+                if (dodiv ? weight > 0.0 : k > 0) {
                     /* Sort array with standard sorting routine */
                     /* assert(k > 0); */
                     ADDTYPE(cpl_tools_sort)(window, k);
                     for (; k--;) {
                         sum += pkernel[k] * (double)window[k];
                     }
-                    sum /= weight;
+                    if (dodiv) sum /= weight;
                 } else {
                     /* Flag as bad - and set to zero */
                     if (*ppbpm == NULL) {
