@@ -1,4 +1,4 @@
-/* $Id: cpl_image_iqe.c,v 1.32 2012/02/14 16:03:26 llundin Exp $
+/* $Id: cpl_image_iqe.c,v 1.33 2013/01/16 16:45:08 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/02/14 16:03:26 $
- * $Revision: 1.32 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/01/16 16:45:08 $
+ * $Revision: 1.33 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -740,7 +740,7 @@ if (nxs<0) nxs = 0;
 nys = floor(est[3] - 4.0*est[4]);
 if (nys<0) nys = 0;
 nx = ceil(8.0*est[2]);
-if (mx<nxs+nx) nx = my - nxs;
+if (mx<nxs+nx) nx = mx - nxs;
 ny = ceil(8.0*est[4]);
 if (my<nys+ny) ny = my - nys;
 
