@@ -1,4 +1,4 @@
-/* $Id: cpl_imagelist_basic.c,v 1.57 2012/06/12 12:32:16 llundin Exp $
+/* $Id: cpl_imagelist_basic.c,v 1.58 2012/12/05 08:17:31 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/06/12 12:32:16 $
- * $Revision: 1.57 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/12/05 08:17:31 $
+ * $Revision: 1.58 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -903,10 +903,11 @@ cpl_imagelist_collapse_sigclip_create(const cpl_imagelist * self,
 /*----------------------------------------------------------------------------*/
 cpl_image * cpl_imagelist_collapse_median_create(const cpl_imagelist * self)
 {
-    cpl_image    * median = NULL;
-    const size_t   nx  = cpl_image_get_size_x(cpl_imagelist_get_const(self, 0));
-    const size_t   ny  = cpl_image_get_size_y(cpl_imagelist_get_const(self, 0));
-    const cpl_type type = cpl_image_get_type (cpl_imagelist_get_const(self, 0));
+    cpl_image       * median = NULL;
+    const cpl_image * imself = cpl_imagelist_get_const(self, 0);
+    const size_t   nx        = (size_t)cpl_image_get_size_x(imself);
+    const size_t   ny        = (size_t)cpl_image_get_size_y(imself);
+    const cpl_type type      = cpl_image_get_type(imself);
     
     cpl_ensure(self != NULL, CPL_ERROR_NULL_INPUT, NULL);
     cpl_ensure(cpl_imagelist_is_uniform(self) == 0, CPL_ERROR_ILLEGAL_INPUT,
