@@ -1,4 +1,4 @@
-/* $Id: cpl_imagelist_basic_body.h,v 1.39 2011/07/29 09:30:13 llundin Exp $
+/* $Id: cpl_imagelist_basic_body.h,v 1.42 2012/06/13 15:14:42 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -106,32 +106,51 @@
 #endif
     case CPL_TYPE_T:
     {
-        const cpl_size nz = imlist->ni;
-        CPL_TYPE ** pi = cpl_malloc((size_t)nz * sizeof(CPL_TYPE*));
-        CPL_TYPE *  po = CPL_IMAGE_GET_DATA(median);
-        CPL_TYPE *  timeline = NULL;
+        const size_t        nz = self->ni;
+        CPL_TYPE         ** pi = cpl_malloc((size_t)nz * sizeof(CPL_TYPE*));
+        CPL_TYPE          * po = (CPL_TYPE*)cpl_malloc(nx * ny * sizeof(*po));
+        CPL_TYPE          * timeline = NULL;
+        const cpl_binary ** pbpm = NULL;
+        size_t              i, j, k;
+
+        /* Create the output image */
+        median = cpl_image_wrap(nx, ny, type, po);
+
+        /* Find planes with a non-empty bad pixel map - if any */
+        for (k = 0; k < nz; k++) {
+            const cpl_mask * bpm
+                = cpl_image_get_bpm_const(self->images[k]);
+
+            pi[k] = CPL_IMAGE_GET_DATA(self->images[k]);
+
+            if (bpm != NULL && !cpl_mask_is_empty(bpm)) {
+                /* Found one */
+                if (pbpm == NULL) {
+                    pbpm = cpl_calloc((size_t)nz, sizeof(*pbpm));
+                    /* Assume that cpl_calloc() fills with NULL */
+                }
+                pbpm[k] = cpl_mask_get_data_const(bpm);
+            }
+        }
 
-        for (k=0; k < nz; k++)
-            pi[k] = CPL_IMAGE_GET_DATA(imlist->images[k]);
 
 #if L2_CACHE_BYTES > 0
-        if (L2_CACHE_BYTES > 0 && sizeof(CPL_TYPE) * (size_t)nz
-            * (size_t)(1 + nx * ny) > L2_CACHE_BYTES) {
+        if (L2_CACHE_BYTES > 0 &&
+            sizeof(CPL_TYPE) * nz * (1 + nx * ny) > L2_CACHE_BYTES) {
             /* There is a cache available, and the entire imagelist does not
                fit inside it */
 
             /* Heuristics: When there are just a few planes, remapping does not
                pay off. It seems that break-even is at nz = nx / 15. */
-            const cpl_size max_aspect = 15;
+            const size_t max_aspect = 15;
 
             /* The largest number of pixels that can be handled by the cache */
-            const cpl_size mxl2 = (L2_CACHE_BYTES
-                                   - (cpl_size)sizeof(CPL_TYPE *) * nz)
-                / ((cpl_size)sizeof(CPL_TYPE) * (1 + 2 * nz));
-            const cpl_size mxmax = mxl2 < nz * max_aspect
+            const size_t mxl2 = (L2_CACHE_BYTES - sizeof(CPL_TYPE *) * nz)
+                / (sizeof(CPL_TYPE) * (1 + 2 * nz));
+            const size_t mxmax = mxl2 < nz * max_aspect
                 ? mxl2 : nz * max_aspect;
-            cpl_size mx = nx;
-            cpl_size my = ny;
+            size_t mx = nx;
+            size_t my = ny;
 
 
             while ((mx & 1) == 0 && mx > mxmax) {
@@ -155,40 +174,89 @@
                    cache to be usable, in this case fall back on the simple
                    method. It seems that the break-even is about 50% cache
                    usage */
+
+                size_t * ngood = cpl_calloc((size_t)mx, sizeof(*ngood));
                 timeline = cpl_malloc((size_t)mx * (size_t)nz
                                       * sizeof(CPL_TYPE));
 
                 /* For each time line */
                 for (j=0; j < my; j++) {
                     /* Get the pixels on the current time line  */
-                    for (k=0; k < nz; k++)
-                        for (i=0; i < mx; i++)
-                            timeline[k + i * nz] = pi[k][i + j * mx];
-
-                    for (i=0; i < mx; i++)
-                        /* Compute the median */
-                        po[i + j * mx] = CPL_IMAGE_GET_MEDIAN(timeline + i * nz,
-                                                              nz);
+                    if (pbpm == NULL) {
+                        for (k=0; k < nz; k++) {
+                            for (i=0; i < mx; i++) {
+                                timeline[k + i * nz] = pi[k][i + j * mx];
+                            }
+                        }
+                        for (i=0; i < mx; i++) {
+                            /* Compute the median */
+                            po[i + j * mx] = CPL_IMAGE_GET_MEDIAN
+                                (timeline + i * nz, nz);
+                        }
+                    } else {
+                        for (k=0; k < nz; k++) {
+                            for (i=0; i < mx; i++) {
+                                if (pbpm[k] == NULL || !pbpm[k][i + j * mx]) {
+                                    timeline[ngood[i]++ + i * nz] =
+                                        pi[k][i + j * mx];
+                                }
+                            }
+                        }
+                        for (i=0; i < mx; i++) {
+                            if (ngood[i] > 0) {
+                                /* Compute the median */
+                                po[i + j * mx] = CPL_IMAGE_GET_MEDIAN
+                                    (timeline + i * nz, ngood[i]);
+                                ngood[i] = 0;
+                            } else {
+                                po[i + j * mx] = (CPL_TYPE)0;
+                                cpl_image_reject(median, i + 1, j + 1);
+                            }
+                        }
+                    }
                 }
+                cpl_free(ngood);
             }
         }
 #endif
         if (timeline == NULL)  {
             /* Remap one pixel at a time */
             timeline = cpl_malloc((size_t)nz * sizeof(CPL_TYPE));
-            /* For each time line */
-            for (i=0; i < nx * ny; i++) {
-                /* Get the pixels on the current time line  */
-                for (k=0; k < nz; k++)
-                    timeline[k] = pi[k][i];
+            if (pbpm == NULL) {
+                /* For each time line */
+                for (i=0; i < nx * ny; i++) {
+                    /* Get the pixels on the current time line  */
+                    for (k=0; k < nz; k++)
+                        timeline[k] = pi[k][i];
 
-                /* Compute the median */
-                po[i] = CPL_IMAGE_GET_MEDIAN(timeline, nz);
+                    /* Compute the median */
+                    po[i] = CPL_IMAGE_GET_MEDIAN(timeline, nz);
+                }
+            } else {
+                /* For each time line */
+                for (i=0; i < nx * ny; i++) {
+                    /* Get the pixels on the current time line  */
+                    size_t igood = 0;
+                    for (k=0; k < nz; k++) {
+                        if (pbpm[k] == NULL || !pbpm[k][i]) {
+                            timeline[igood++] = pi[k][i];
+                        }
+                    }
+
+                    if (igood > 0) {
+                        /* Compute the median */
+                        po[i] = CPL_IMAGE_GET_MEDIAN(timeline, igood);
+                    } else {
+                        po[i] = (CPL_TYPE)0;
+                        cpl_image_reject(median, i%nx + 1, i/nx + 1);
+                    }
+                }
             }
         }
 
         cpl_free(pi);
         cpl_free(timeline);
+        cpl_free(pbpm);
         break;
     }
 
@@ -197,48 +265,83 @@
     case CPL_TYPE_T:
     {
         /* Pointers to the ni pixel buffers */
-        const CPL_TYPE ** pin = cpl_malloc((size_t)ni * sizeof(CPL_TYPE *));
+        const CPL_TYPE ** pin = cpl_malloc(ni * sizeof(CPL_TYPE *));
+        const cpl_binary ** pbpm = NULL;
 
         /* Output pixel buffer */
         CPL_TYPE       *  pavg
-            = cpl_malloc((size_t)nx * (size_t)ny * sizeof(*pavg));
+            = cpl_malloc(nx * ny * sizeof(*pavg));
 
         /* A single timeline */
-        CPL_TYPE * ptime = cpl_malloc((size_t)ni * sizeof(*ptime));
-        cpl_size   i, k;
+        CPL_TYPE * ptime = cpl_malloc(ni * sizeof(*ptime));
+        size_t     i, k;
 
+        avg = CPL_IMAGE_WRAP(nx, ny, pavg);
 
+        /* Find planes with a non-empty bad pixel map - if any */
         for (k = 0; k < ni; k++) {
+
+            const cpl_mask * bpm
+                = cpl_image_get_bpm_const(self->images[k]);
+
             pin[k] = CPL_IMAGE_GET_DATA_CONST(cpl_imagelist_get_const(self, k));
+
+            if (bpm != NULL && !cpl_mask_is_empty(bpm)) {
+                /* Found one */
+                if (pbpm == NULL) {
+                    pbpm = cpl_calloc(ni, sizeof(*pbpm));
+                    /* Assume that cpl_calloc() fills with NULL */
+                }
+                pbpm[k] = cpl_mask_get_data_const(bpm);
+            }
+
         }
 
+
         /* Loop on the pixels */
         for (i = 0; i < nx * ny; i++) {
-            double mean = 0.0;
+            size_t igood = 0;
+            size_t ilow, ihigh;
+            size_t ihbad;
 
             /* Fill the timeline */
             for (k = 0; k < ni; k++) {
-                ptime[k] = pin[k][i];
+                if (pbpm == NULL || pbpm[k] == NULL || !pbpm[k][i]) {
+                    ptime[igood++] = pin[k][i];
+                }
             }
 
-            /* Place nlow and nhigh samples at the ends */
-            if (nlow  > 0) (void)CPL_TOOLS_GET_KTH(ptime, ni, nlow-1);
-            if (nhigh > 0) (void)CPL_TOOLS_GET_KTH(ptime + nlow, ni-nlow, nuse);
+            ihbad = (ni - igood) / 2;
 
-            /* Compute the average */
-            /* - using the recurrence relation from cpl_vector_get_mean() */
-            for (k = 0; k < nuse; k++)
-                mean += ((double)ptime[nlow + k] - mean) / (double)(k + 1);
+            ilow  = (size_t)nlow  > ihbad ? (size_t)nlow  - ihbad : 0;
+            ihigh = (size_t)nhigh > ihbad ? (size_t)nhigh - ihbad : 0;
 
-            pavg[i] = (CPL_TYPE)mean;
+            if (igood > ilow + ihigh) {
+                double mean = 0.0;
+                const size_t iuse = igood - ilow - ihigh;
+
+                /* Place ilow and ihigh samples at the ends */
+                if (ilow  > 0) (void)CPL_TOOLS_GET_KTH(ptime, igood, ilow-1);
+                if (ihigh > 0) (void)CPL_TOOLS_GET_KTH(ptime + ilow,
+                                                       iuse + ihigh, iuse);
+
+                /* Compute the average - using the recurrence relation from
+                   cpl_tools_get_mean_double() */
+                for (k = 0; k < iuse; k++)
+                    mean += ((double)ptime[ilow + k] - mean) / (double)(k + 1);
+
+                pavg[i] = (CPL_TYPE)mean;
+
+                cpl_tools_add_flops(3 * iuse);
+            } else {
+                pavg[i] = (CPL_TYPE)0;
+                cpl_image_reject(avg, i%nx + 1, i/nx + 1);
+            }
         }
 
         cpl_free(pin);
         cpl_free(ptime);
-
-        avg = CPL_IMAGE_WRAP(nx, ny, pavg);
-
-        cpl_tools_add_flops(3 * nx * ny * nuse);
+        cpl_free(pbpm);
 
         break;
     }
