@@ -1,4 +1,4 @@
-/* $Id: cpl_imagelist_io.c,v 1.97 2012/04/26 11:37:38 llundin Exp $
+/* $Id: cpl_imagelist_io.c,v 1.108 2013/02/22 14:29:33 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/04/26 11:37:38 $
- * $Revision: 1.97 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/22 14:29:33 $
+ * $Revision: 1.108 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -262,8 +262,10 @@ const cpl_image * cpl_imagelist_get_const(const cpl_imagelist * imlist,
 
   It is not allowed to insert images of different size into a list.
 
-  You should not deallocate the image after it has been inserted into an
-  imagelist, since the cpl_imagelist_delete() will deallocate its images.
+  The added image is owned by the imagelist object, which deallocates it
+  cpl_imagelist_delete is called. Other option is to use cpl_imagelist_unset to
+  recover ownership of the image, in which case the cpl_imagelist object is
+  not longer responsible for deallocating it.
 
   Possible #_cpl_error_code_ set in this function:
   - CPL_ERROR_NULL_INPUT if an input pointer is NULL
@@ -454,6 +456,87 @@ void cpl_imagelist_delete(cpl_imagelist * self)
     return;
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @ingroup cpl_imagelist
+  @brief    Cast an imagelist, optionally in-place
+  @param    self   Destination imagelist
+  @param    other  Source imagelist, or NULL to cast in-place
+  @param    type   If called with empty self, cast to this pixel-type
+  @return   CPL_ERROR_NONE or the relevant #_cpl_error_code_ on error
+  @see cpl_image_cast()
+  @note    If called with a non-empty self in an out-of-place cast,
+  the input images are cast to the type already present in self and appended to
+  the output list. In this case the parameter type is ignored.
+
+  Possible #_cpl_error_code_ set in this function:
+  - CPL_ERROR_NULL_INPUT if the destination pointer is NULL
+  - CPL_ERROR_INCOMPATIBLE_INPUT if the same pointer is passed twice
+  - CPL_ERROR_ILLEGAL_INPUT if the passed type is invalid
+  - CPL_ERROR_TYPE_MISMATCH if the passed image type is complex and requested
+  casting type is non-complex.
+  - CPL_ERROR_INVALID_TYPE if the passed pixel type is not supported
+ */
+/*----------------------------------------------------------------------------*/
+cpl_error_code cpl_imagelist_cast(cpl_imagelist * self,
+                                  const cpl_imagelist * other,
+                                  cpl_type type)
+{
+
+    if (self == NULL) {
+        return cpl_error_set_(CPL_ERROR_NULL_INPUT);
+    } else if (self == other) {
+        return cpl_error_set_(CPL_ERROR_INCOMPATIBLE_INPUT);
+    } else {
+        const cpl_boolean     inplace = other == NULL ? CPL_TRUE : CPL_FALSE;
+        const cpl_imagelist * src     = inplace ? self : other;
+        cpl_imagelist       * dest    = inplace ? cpl_imagelist_new() : self;
+        const size_t          n       = (size_t)cpl_imagelist_get_size(src);
+        const size_t          m       = (size_t)cpl_imagelist_get_size(dest);
+        const cpl_type        ctype   = inplace || m == 0 ? type
+            : cpl_image_get_type(cpl_imagelist_get_const(dest, 0));
+        cpl_error_code        code    = CPL_ERROR_NONE;
+        size_t                i, j;
+
+        for (i = j = 0; i < n; i++) {
+
+            /* For in-place, empty src along the way */
+            const cpl_image * srcimg = cpl_imagelist_get_const(src,(cpl_size)j);
+            cpl_image       * tmpimg = cpl_image_cast(srcimg, ctype);
+
+            if (tmpimg == NULL) break;
+
+            if (cpl_imagelist_set(dest, tmpimg, m + (cpl_size)i)) break;
+
+            if (inplace) {
+                cpl_image_delete(cpl_imagelist_unset(self, 0));
+            } else {
+                j++;
+            }
+        }
+
+        if (i < n) {
+            /* An error happened */
+            code = cpl_error_set_where_();
+            if (inplace) {
+                cpl_imagelist_delete(dest);
+            }
+        } else if (inplace) {
+            /* Need to move dest to self (which is empty) */
+            cpl_imagelist * tmp = (cpl_imagelist*)cpl_malloc(sizeof(*tmp));
+
+            (void)memcpy(tmp,  self, sizeof(*tmp));
+            (void)memcpy(self, dest, sizeof(*tmp));
+
+            cpl_free(dest);
+            cpl_imagelist_delete(tmp);
+        }
+
+        return code;
+    }
+}
+
+
 /*----------------------------------------------------------------------------*/
 /**
   @ingroup cpl_imagelist
@@ -568,9 +651,17 @@ cpl_error_code cpl_imagelist_erase(
 
   Supported output modes are CPL_IO_CREATE (create a new file),
   CPL_IO_EXTEND (extend an existing file with a new extension) and
-  CPL_IO_APPEND (append list of images to the last data unit, which must
-  already contain compatible image(s)).
+  CPL_IO_APPEND (append a list of images to the last data unit, which
+  must already contain compatible image(s)).
 
+  When the data written to disk are of an integer type, the output mode
+  CPL_IO_EXTEND can be combined (via bit-wise or) with an option for
+  tile-compression. This compression of integer data is lossless.
+  The options are:
+  CPL_IO_COMPRESS_GZIP, CPL_IO_COMPRESS_RICE, CPL_IO_COMPRESS_HCOMPRESS,
+  CPL_IO_COMPRESS_PLIO.
+  With compression the type must be CPL_TYPE_UNSPECIFIED or CPL_TYPE_INT.
+ 
   In extend and append mode, make sure that the file has write permissions.
   You may have problems if you create a file in your application and append
   something to it with the umask set to 222. In this case, the file created
@@ -589,186 +680,15 @@ cpl_error_code cpl_imagelist_save(const cpl_imagelist    * self,
                                   const cpl_propertylist * pl,
                                   unsigned                 mode)
 {
-    int               error=0;
-    fitsfile       *  fptr;
-    cpl_size          i;
-    const char      * badkeys = mode & CPL_IO_EXTEND ?
-    CPL_FITS_BADKEYS_EXT  "|" CPL_FITS_COMPRKEYS :
-    CPL_FITS_BADKEYS_PRIM "|" CPL_FITS_COMPRKEYS;
-    const cpl_image * first = cpl_imagelist_get_const(self, 0);
-    const cpl_size    nx = cpl_image_get_size_x(first);
-    const cpl_size    ny = cpl_image_get_size_y(first);
-    const cpl_type    ftype = cpl_image_get_type(first);
-    const int         cfitsiotype = ftype == CPL_TYPE_DOUBLE ? TDOUBLE
-    : (ftype == CPL_TYPE_FLOAT ? TFLOAT : TINT);
-    const CPL_FITSIO_TYPE naxes[3] = {nx, ny, cpl_imagelist_get_size(self)};
-    long              plane1 = 0; /* First plane to write */
-    const int         ibpp = cpl_tools_get_bpp(type == CPL_TYPE_UNSPECIFIED ?
-                                               ftype : type);
 
-    /* Test entries */
-    cpl_ensure_code(filename != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(self     != NULL, CPL_ERROR_NULL_INPUT);
-    cpl_ensure_code(ibpp, CPL_ERROR_ILLEGAL_INPUT);
-
-    cpl_ensure_code(((mode & CPL_IO_CREATE) != 0) +
-                    ((mode & CPL_IO_EXTEND) != 0) +
-                    ((mode & CPL_IO_APPEND) != 0) == 1, CPL_ERROR_ILLEGAL_INPUT);
-
-    cpl_ensure_code(mode <= CPL_IO_MAX, CPL_ERROR_ILLEGAL_INPUT);
-
+    cpl_ensure_code(filename != NULL, CPL_ERROR_NULL_INPUT);
     cpl_ensure_code(cpl_imagelist_is_uniform(self)==0,
                     CPL_ERROR_ILLEGAL_INPUT);
 
-    cpl_ensure_code(ftype == CPL_TYPE_DOUBLE || ftype == CPL_TYPE_FLOAT ||
-                    ftype == CPL_TYPE_INT, CPL_ERROR_INVALID_TYPE);
-
-    if (mode & (CPL_IO_EXTEND | CPL_IO_APPEND)) {
-        /* Open the file */
-        if (cpl_io_fits_open_diskfile(&fptr, filename, READWRITE, &error)) {
-            return cpl_error_set_fits(CPL_ERROR_FILE_IO, error,
-                                      fits_open_diskfile, "filename='%s', "
-                                      "type=%d, mode=%d", filename, type, mode);
-        }
-    } else {
-        /* Create the file */
-        char * sval = cpl_sprintf("!%s", filename);
-        cpl_io_fits_create_file(&fptr, sval, &error);
-        cpl_free(sval);
-        if (error != 0) {
-            return cpl_error_set_fits(CPL_ERROR_FILE_IO, error,
-                                      fits_create_file, "filename='%s', "
-                                      "type=%d, mode=%d", filename, type, mode);
-        }
-    }
-
-    if (mode & CPL_IO_APPEND) {
-        int next;
-        int exttype;
-        cpl_boolean isok = CPL_FALSE;
-
-        fits_get_num_hdus(fptr, &next, &error);
-
-        fits_movabs_hdu(fptr, next, &exttype, &error);
-
-        if (exttype == IMAGE_HDU) {
-
-            int naxis;
-
-            fits_get_img_dim(fptr, &naxis, &error);
-
-            if (naxis == 2 || naxis == 3) {
-                /* Last element read on naxis=2 */
-                CPL_FITSIO_TYPE fnaxes[3] = {nx, ny, 0};
-                int bitpix;
-
-                fits_get_img_type(fptr, &bitpix, &error);
-
-                if (bitpix == ibpp) {
-
-                    CPL_FITSIO_GET_SIZE(fptr, naxis, fnaxes, &error);
-
-                    if (naxes[0] == fnaxes[0] && naxes[1] == fnaxes[1]) {
-                        plane1 = fnaxes[2];
-                        fnaxes[2] += naxes[2];
-                        CPL_FITSIO_RESIZE_IMG(fptr, bitpix, naxis, fnaxes,
-                                              &error);
-                        if (!error) isok = CPL_TRUE;
-                    } else {
-                    int error2 = 0;
-                    cpl_io_fits_close_file(fptr, &error2);
-                    return cpl_error_set_message_
-                        (CPL_ERROR_ILLEGAL_INPUT, "Data-unit %d in file %s has "
-                         "wrong NAXIS1/2 (%ldX%ld != %ldX%ld). type=%d, "
-                         "mode=%d)", next, filename, (long)fnaxes[0],
-                         (long)fnaxes[1], (long)naxes[0], (long)naxes[1],
-                         type, mode);
-                    }
-                } else {
-                    int error2 = 0;
-                    cpl_io_fits_close_file(fptr, &error2);
-                    return cpl_error_set_message_
-                        (CPL_ERROR_ILLEGAL_INPUT, "Data-unit %d in file %s has "
-                         "wrong BITPIX (%d != %d). type=%d, mode=%d)", next,
-                         filename, bitpix, ibpp, type, mode);
-                }
-            } else {
-                int error2 = 0;
-                cpl_io_fits_close_file(fptr, &error2);
-                return cpl_error_set_message_
-                    (CPL_ERROR_ILLEGAL_INPUT, "Data-unit %d in file %s has "
-                     "wrong NAXIS (%d != 2/3). type=%d, mode=%d)", next,
-                     filename, naxis, type, mode);
-            }
-        } else {
-            int error2 = 0;
-            cpl_io_fits_close_file(fptr, &error2);
-            return cpl_error_set_message_
-                (CPL_ERROR_ILLEGAL_INPUT, "Data-unit %d in file %s is not "
-                 "image-type (%d != %d. type=%d, mode=%d)",
-                 next, filename, exttype, IMAGE_HDU, type, mode);
-        }
-
-        if (error) {
-            int error2 = 0;
-            cpl_io_fits_close_file(fptr, &error2);
-            return cpl_error_set_fits(CPL_ERROR_FILE_IO, error, "CFITSIO",
-                                      "filename='%s', type=%d, mode=%d",
-                                      filename, type, mode);
-        } else if (!isok) {
-            /* Not supposed to enter here */
-            int error2 = 0;
-            cpl_io_fits_close_file(fptr, &error2);
-            return cpl_error_set_(CPL_ERROR_UNSPECIFIED);
-        }
-    } else {
-        /* Create the imagelist in a new HDU appended to the file */
-        CPL_FITSIO_CREATE_IMG(fptr, ibpp, 3, (CPL_FITSIO_TYPE*)naxes, &error);
-
-        if (mode & CPL_IO_CREATE)
-            fits_write_date(fptr, &error); /* Add Date */
-    }
-
-    if (error) {
-        int error2 = 0;
-        cpl_io_fits_close_file(fptr, &error2);
-        return cpl_error_set_fits(CPL_ERROR_FILE_IO, error, "CFITSIO",
-                                  "filename='%s', type=%d, mode=%d",
-                                  filename, type, mode);
-    }
-
-    /* Add the property list */
-    if (cpl_fits_add_properties(fptr, pl, badkeys)) {
-        cpl_io_fits_close_file(fptr, &error);
-        return cpl_error_set_(CPL_ERROR_ILLEGAL_INPUT);
-    }
-
-    /* Loop on the images */
-    for (i=0; i < self->ni; i++) {
-    const CPL_FITSIO_TYPE fpixel[3] = {1, 1, plane1 + i + 1};
-    const cpl_image     * image = cpl_imagelist_get_const(self, i);
-    const void          * data  = cpl_image_get_data_const(image);
-
-    /* Write the pixels */
-    if (CPL_FITSIO_WRITE_PIX(fptr, cfitsiotype, (CPL_FITSIO_TYPE*)fpixel,
-                             nx*ny, (void*)data, &error)) break;
-    }
-
-    /* Check  */
-    if (error) {
-        int error2 = 0;
-        cpl_io_fits_close_file(fptr, &error2);
-        return cpl_error_set_fits(CPL_ERROR_FILE_IO, error,
-                                  "CFITSIO", "filename='%s', "
-                                  "type=%d, mode=%d", filename, type, mode);
-    }
-
-    /* Close (and write to disk) */
-    return cpl_io_fits_close_file(fptr, &error)
-        ? cpl_error_set_fits(CPL_ERROR_FILE_IO, error,
-                             fits_close_file, "filename='%s', "
-                             "type=%d, mode=%d", filename, type, mode)
-        : CPL_ERROR_NONE;
+    return cpl_image_save_((const cpl_image**)(self->images), self->ni,
+                           CPL_TRUE, filename, type, pl, mode)
+        ? cpl_error_set_where_() : CPL_ERROR_NONE;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -927,7 +847,7 @@ static cpl_imagelist * cpl_imagelist_load_one(const char * filename,
     cpl_imagelist * self;
     cpl_image     * image;
     fitsfile      * fptr;
-    int             error = 0;
+    int             status = 0; /* CFITSIO status, must be set to zero */
     /* Initialize to indicate that they need to be read from the file */
     int             naxis = 0;
     CPL_FITSIO_TYPE naxes[3] ={0, 0, 0};
@@ -938,8 +858,8 @@ static cpl_imagelist * cpl_imagelist_load_one(const char * filename,
     cpl_ensure(filename != NULL, CPL_ERROR_NULL_INPUT,    NULL);
     cpl_ensure(xtnum    >= 0,    CPL_ERROR_ILLEGAL_INPUT, NULL);
 
-    if (cpl_io_fits_open_diskfile(&fptr, filename, READONLY, &error)) {
-        (void)cpl_error_set_fits(CPL_ERROR_FILE_IO, error, fits_open_diskfile,
+    if (cpl_io_fits_open_diskfile(&fptr, filename, READONLY, &status)) {
+        (void)cpl_error_set_fits(CPL_ERROR_FILE_IO, status, fits_open_diskfile,
                                  "filename='%s', im_type=%u, xtnum=%"
                                  CPL_SIZE_FORMAT, filename, im_type, xtnum);
         return NULL;
@@ -981,8 +901,8 @@ static cpl_imagelist * cpl_imagelist_load_one(const char * filename,
         }
     }
 
-    if (cpl_io_fits_close_file(fptr, &error)) {
-        (void)cpl_error_set_fits(CPL_ERROR_BAD_FILE_FORMAT, error,
+    if (cpl_io_fits_close_file(fptr, &status)) {
+        (void)cpl_error_set_fits(CPL_ERROR_BAD_FILE_FORMAT, status,
                                  fits_close_file, "filename='%s', "
                                  "im_type=%u, xtnum=%" CPL_SIZE_FORMAT,
                                  filename, (unsigned)im_type, xtnum);
