@@ -1,4 +1,4 @@
-/* $Id: cpl_imagelist_io.h,v 1.29 2012/04/04 12:26:54 llundin Exp $
+/* $Id: cpl_imagelist_io.h,v 1.30 2013/01/17 16:04:13 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/04/04 12:26:54 $
- * $Revision: 1.29 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/01/17 16:04:13 $
+ * $Revision: 1.30 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifndef CPL_IMAGELIST_IO_H
@@ -67,6 +67,9 @@ cpl_imagelist * cpl_imagelist_duplicate(const cpl_imagelist *) CPL_ATTR_ALLOC;
 cpl_error_code cpl_imagelist_erase(cpl_imagelist *, const cpl_vector *);
 int cpl_imagelist_is_uniform(const cpl_imagelist *);
 
+cpl_error_code cpl_imagelist_cast(cpl_imagelist *, const cpl_imagelist *,
+                                  cpl_type);
+
 cpl_error_code cpl_imagelist_dump_structure(const cpl_imagelist *, FILE *);
 cpl_error_code cpl_imagelist_dump_window(const cpl_imagelist *,
                      cpl_size, cpl_size, cpl_size, cpl_size, FILE *);
