@@ -1,4 +1,4 @@
-/* $Id: cpl_io.h,v 1.17 2011/04/01 09:57:38 llundin Exp $
+/* $Id: cpl_io.h,v 1.21 2013/02/21 17:14:53 cgarcia Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2011/04/01 09:57:38 $
- * $Revision: 1.17 $
- * $Name: cpl-6_2 $
+ * $Author: cgarcia $
+ * $Date: 2013/02/21 17:14:53 $
+ * $Revision: 1.21 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifndef CPL_IO_H
@@ -61,6 +61,9 @@ CPL_BEGIN_DECLS
 /**
  * 
  * @brief These are the file I/O modes.
+ *
+ * For the compression modes, 
+ * see http://heasarc.nasa.gov/docs/software/fitsio/compression.html
  */
 /*----------------------------------------------------------------------------*/
 
@@ -85,7 +88,23 @@ enum _cpl_io_type_ {
     /**< Append to the last data unit of the file. */
 
     /** @hideinitializer */
-    CPL_IO_MAX = CPL_IO_APPEND,
+    CPL_IO_COMPRESS_GZIP = ((unsigned)1 << 4),
+    /**< Use FITS tiled-image compression with GZIP algorithm. */
+
+    /** @hideinitializer */
+    CPL_IO_COMPRESS_RICE = ((unsigned)1 << 5),
+    /**< Use FITS tiled-image compression with RICE algorithm. */
+
+    /** @hideinitializer */
+    CPL_IO_COMPRESS_HCOMPRESS = ((unsigned)1 << 6),
+    /**< Use FITS tiled-image compression with HCOMPRESS algorithm. */
+
+    /** @hideinitializer */
+    CPL_IO_COMPRESS_PLIO = ((unsigned)1 << 7),
+    /**< Use FITS tiled-image compression with PLIO algorithm. */
+
+    /** @hideinitializer */
+    CPL_IO_MAX = ((unsigned)1 << 8),
     /**< Reserved for internal CPL usage. */
 
     /** @hideinitializer */
