@@ -1,4 +1,4 @@
-/* $Id: cpl_macros.h,v 1.10 2012/09/13 11:12:47 llundin Exp $
+/* $Id: cpl_macros.h,v 1.11 2013/02/15 09:24:42 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2012/09/13 11:12:47 $
- * $Revision: 1.10 $
- * $Name: cpl-6_2 $
+ * $Author: rpalsa $
+ * $Date: 2013/02/15 09:24:42 $
+ * $Revision: 1.11 $
+ * $Name: cpl-6_3_1 $
  */
 
 /*
@@ -115,6 +115,11 @@
 #    define CPL_ATTR_CALLOC  __attribute__((malloc))
 #    define CPL_ATTR_REALLOC __attribute__((malloc))
 #  endif
+
+#  if __GNUC__ >= 4
+#    define CPL_INTERNAL  __attribute__((visibility("hidden")))
+#    define CPL_EXPORT    __attribute__((visibility("default")))
+#  endif
 #endif
 
 #ifndef CPL_ATTR_ALLOC
@@ -162,4 +167,9 @@
 #    define CPL_ATTR_NOINLINE /* __attribute__ */
 #endif
 
+#ifndef CPL_INTERNAL
+#    define CPL_INTERNAL /* __attribute__ */
+#    define CPL_EXPORT   /* __attribute__ */
+#endif
+
 #endif /* CPL_MACROS_H */
