@@ -1,4 +1,4 @@
-/* $Id: cpl_msg.c,v 1.56 2012/10/29 09:52:08 llundin Exp $
+/* $Id: cpl_msg.c,v 1.58 2013/02/08 09:48:02 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2012/10/29 09:52:08 $
- * $Revision: 1.56 $
- * $Name: cpl-6_2 $
+ * $Author: rpalsa $
+ * $Date: 2013/02/08 09:48:02 $
+ * $Revision: 1.58 $
+ * $Name: cpl-6_3_1 $
  */
 
 
@@ -193,6 +193,7 @@ static const char       default_format[]                = "<empty message>";
 static cpl_msg_severity log_min_level                   = CPL_MSG_OFF;
 static cpl_msg_severity term_min_level                  = CPL_MSG_INFO;
 static int              time_tag                        = 0;
+static int              threadid_tag                    = 0;
 static int              domain_tag                      = 0;
 static int              component_tag                   = 0;
 static int              msg_init                        = 0;
@@ -586,8 +587,9 @@ inline static void cpl_msg_out(cpl_msg_severity severity,
     */
 
    tid = cpl_sprintf("[tid=%03d] ", omp_get_thread_num());
-   strcat(msg_term, tid);
    strcat(msg_log, tid);
+   if (threadid_tag)
+       strcat(msg_term, tid);
    cpl_free(tid);
 
 #endif
@@ -803,8 +805,11 @@ void cpl_msg_stop(void)
     cx_print_set_handler(default_printer);
     cx_printerr_set_handler(default_error);
 
-    fclose(msg_stdout);
-    fclose(msg_stderr);
+    if (msg_stdout != stdout)
+        fclose(msg_stdout);
+
+    if (msg_stderr != stderr)
+        fclose(msg_stderr);
 
     cpl_msg_stop_log();
 
@@ -1178,6 +1183,54 @@ void cpl_msg_set_time_off(void)
     time_tag = 0;
 }
 
+/**
+ * @brief
+ *   Attach a @em thread id tag to output messages.
+ *
+ * @return Nothing.
+ *
+ * As a default, @em thread ids tags are attached just to messages written
+ * to the log file. This function must be called to display the @em thread id
+ * tag also in messages written to terminal. To turn the @em thread id tag
+ * off the function @c cpl_msg_set_threadid_off() should be called.
+ *
+ * @note
+ *   This function is meant to configure once and for all the behaviour
+ *   and the "style" of the messaging system, and it is not supposed to
+ *   be called in threads.
+ */
+
+void cpl_msg_set_threadid_on(void)
+{
+    _cpl_msg_init("cpl_msg_set_threadid_on");
+
+    threadid_tag = 1;
+}
+
+
+/**
+ * @brief
+ *   Disable the @em thread id tag to output messages
+ *
+ * @return Nothing.
+ *
+ * The @em thread id tag is turned off in messages written to terminal.
+ * The @em thread id tag cannot be turned off in messages written to the
+ * log file.
+ *
+ * @note
+ *   This function is meant to configure once and for all the behaviour
+ *   and the "style" of the messaging system, and it is not supposed to
+ *   be called in threads.
+ */
+
+void cpl_msg_set_threadid_off(void)
+{
+    _cpl_msg_init("cpl_msg_set_threadid_off");
+
+    threadid_tag = 0;
+}
+
 
 /**
  * @brief
