@@ -1,4 +1,4 @@
-/* $Id: cpl_msg.h,v 1.17 2012/03/06 10:36:18 llundin Exp $
+/* $Id: cpl_msg.h,v 1.18 2013/01/28 12:31:19 cgarcia Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2012/03/06 10:36:18 $
- * $Revision: 1.17 $
- * $Name: cpl-6_2 $
+ * $Author: cgarcia $
+ * $Date: 2013/01/28 12:31:19 $
+ * $Revision: 1.18 $
+ * $Name: cpl-6_3_1 $
  */
 
 
@@ -94,6 +94,8 @@ void cpl_msg_set_component_on(void);
 void cpl_msg_set_component_off(void);
 void cpl_msg_set_domain_on(void);
 void cpl_msg_set_domain_off(void);
+void cpl_msg_set_threadid_on(void);
+void cpl_msg_set_threadid_off(void);
 
 void cpl_msg_set_domain(const char *);
 const char *cpl_msg_get_domain(void);
