@@ -1,4 +1,4 @@
-/* $Id: cpl_stats.c,v 1.58 2012/07/30 23:39:10 llundin Exp $
+/* $Id: cpl_stats.c,v 1.59 2012/11/14 12:23:28 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/07/30 23:39:10 $
- * $Revision: 1.58 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/11/14 12:23:28 $
+ * $Revision: 1.59 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -889,8 +889,8 @@ cpl_error_code cpl_stats_dump(const cpl_stats * self,
 
     cpl_ensure_code((mode & ~self->mode) == 0, CPL_ERROR_ILLEGAL_INPUT);
 
-    cpl_ensure_code( fprintf(stream, "\t\tPixel count: %d\n", self->npix) >0,
-                     CPL_ERROR_FILE_IO);
+    cpl_ensure_code( fprintf(stream, "\t\tPixel count: %" CPL_SIZE_FORMAT "\n",
+                             self->npix) >0, CPL_ERROR_FILE_IO);
 
     CPL_STATS_DUMP_ONE(CPL_STATS_MIN,        min,      "Min",        ".8g");
     CPL_STATS_DUMP_ONE(CPL_STATS_MAX,        max,      "Max",        ".8g");
@@ -904,8 +904,10 @@ cpl_error_code cpl_stats_dump(const cpl_stats * self,
     CPL_STATS_DUMP_ONE(CPL_STATS_SQFLUX,     sqflux,   "Sq. flux",   ".8g");
 
     CPL_STATS_DUMP_TWO(CPL_STATS_CENTROID,   centroid, "centroid",   ".8g");
-    CPL_STATS_DUMP_TWO(CPL_STATS_MINPOS,     min,      "min. pos.",  "d");
-    CPL_STATS_DUMP_TWO(CPL_STATS_MAXPOS,     max,      "max. pos.",  "d");
+    CPL_STATS_DUMP_TWO(CPL_STATS_MINPOS,     min,      "min. pos.",
+                       CPL_SIZE_FORMAT);
+    CPL_STATS_DUMP_TWO(CPL_STATS_MAXPOS,     max,      "max. pos.",
+                       CPL_SIZE_FORMAT);
 
     /* Failure here means a new member has been added, without dump support */
     return mode ? cpl_error_set_(CPL_ERROR_UNSUPPORTED_MODE) : CPL_ERROR_NONE;
