@@ -1,4 +1,4 @@
-/* $Id: cpl_stats_body.h,v 1.15 2012/04/04 09:46:12 llundin Exp $
+/* $Id: cpl_stats_body.h,v 1.16 2012/07/30 23:39:10 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -271,6 +271,57 @@
       break;
   }
 
+#elif CPL_OPERATION == CPL_IMAGE_STATS_MAD
+
+  case CPL_TYPE_T:
+  {
+
+      /* Duplicate the pixels inside the window */
+      CPL_TYPE * copybuf = cpl_malloc((size_t)npix * sizeof(CPL_TYPE));
+      cpl_size   ngood   = 0;
+
+
+      if (nbadpix != 0) {
+          /* Need to check bad pixel buffer */
+
+            /* Point to first pixel in first row to read */
+            const CPL_TYPE   * pi = (const CPL_TYPE*)image->pixels
+                + (llysz-1)*image->nx;
+
+            /* - ditto for bad pixel map */
+            const cpl_binary * pbpm = badmap + (llysz-1)*image->nx;
+
+            for (j = llysz - 1; j < urysz; j++, pi += image->nx, pbpm += image->nx) {
+                for (i = llxsz - 1; i < urxsz; i++) {
+                    /* Take only good pixels */
+                    if (pbpm[i] == CPL_BINARY_0) {
+                        copybuf[ngood++] = fabs((double)pi[i]-self->med);
+                    }
+                }
+            }
+      } else {
+            /* Point to first pixel in first row to read */
+            const CPL_TYPE   * pi = (const CPL_TYPE*)image->pixels
+                + (llysz-1)*image->nx;
+
+            for (j = llysz - 1; j < urysz; j++, pi += image->nx) {
+                for (i = llxsz - 1; i < urxsz; i++) {
+                    copybuf[ngood++] = fabs((double)pi[i]-self->med);
+                }
+            }
+      }
+      /* assert( ngood == npix ) */
+
+      cpl_tools_add_flops( 2 * npix );
+
+      /* Compute the median */
+      self->mad = CPL_TYPE_ADD(cpl_tools_get_median)(copybuf, npix);
+
+      cpl_free(copybuf);
+
+      break;
+  }
+
 #endif
 
 #undef CPL_TYPE
