@@ -1,4 +1,4 @@
-/* $Id: cpl_table.h,v 1.67 2011/03/01 13:15:30 cizzo Exp $
+/* $Id: cpl_table.h,v 1.68 2013/01/23 16:06:32 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: cizzo $
- * $Date: 2011/03/01 13:15:30 $
- * $Revision: 1.67 $
- * $Name: cpl-6_2 $
+ * $Author: rpalsa $
+ * $Date: 2013/01/23 16:06:32 $
+ * $Revision: 1.68 $
+ * $Name: cpl-6_3_1 $
  */
 
 
@@ -69,6 +69,7 @@ cpl_error_code cpl_table_set_column_savetype(cpl_table *,
                                              const char *name, cpl_type);
 
 cpl_error_code cpl_table_wrap_int(cpl_table *, int *, const char *);
+cpl_error_code cpl_table_wrap_long_long(cpl_table *, long long *, const char *);
 cpl_error_code cpl_table_wrap_float(cpl_table *, float *, const char *);
 cpl_error_code cpl_table_wrap_double(cpl_table *, double *, const char *);
 #ifdef _Complex_I
@@ -114,6 +115,9 @@ cpl_size cpl_table_get_column_dimension(const cpl_table *,
 int *cpl_table_get_data_int(cpl_table *, const char *name);
 const int *cpl_table_get_data_int_const(const cpl_table *, 
                                         const char *name);
+long long *cpl_table_get_data_long_long(cpl_table *, const char *name);
+const long long *cpl_table_get_data_long_long_const(const cpl_table *,
+                                                    const char *name);
 float *cpl_table_get_data_float(cpl_table *, const char *name);
 const float *cpl_table_get_data_float_const(const cpl_table *, 
                                             const char *name);
@@ -137,6 +141,8 @@ const cpl_array **cpl_table_get_data_array_const(const cpl_table *,
 
 double cpl_table_get(const cpl_table *, const char *, cpl_size, int *null);
 int cpl_table_get_int(const cpl_table *, const char *, cpl_size, int *null);
+long long cpl_table_get_long_long(const cpl_table *, const char *, cpl_size,
+                                  int *null);
 float cpl_table_get_float(const cpl_table *, const char *, cpl_size, int *null);
 double cpl_table_get_double(const cpl_table *, const char *, cpl_size, 
                                                                 int *null);
@@ -153,6 +159,8 @@ const cpl_array *cpl_table_get_array(const cpl_table *, const char *, cpl_size);
 
 cpl_error_code cpl_table_set(cpl_table *, const char *, cpl_size, double);
 cpl_error_code cpl_table_set_int(cpl_table *, const char *, cpl_size, int);
+cpl_error_code cpl_table_set_long_long(cpl_table *, const char *, cpl_size,
+                                       long long);
 cpl_error_code cpl_table_set_float(cpl_table *, const char *, cpl_size, float);
 cpl_error_code cpl_table_set_double(cpl_table *, const char *, cpl_size, 
                                                                     double);
@@ -173,6 +181,9 @@ cpl_error_code cpl_table_fill_column_window(cpl_table *, const char *,
                                      cpl_size, cpl_size, double);
 cpl_error_code cpl_table_fill_column_window_int(cpl_table *, const char *, 
                                          cpl_size, cpl_size, int);
+cpl_error_code cpl_table_fill_column_window_long_long(cpl_table *, const char *,
+                                                      cpl_size, cpl_size,
+                                                      long long);
 cpl_error_code cpl_table_fill_column_window_float(cpl_table *, const char *, 
                                            cpl_size, cpl_size, float);
 cpl_error_code cpl_table_fill_column_window_double(cpl_table *, const char *, 
@@ -191,6 +202,8 @@ cpl_error_code cpl_table_fill_column_window_array(cpl_table *, const char *,
                                       cpl_size, cpl_size, const cpl_array *);
 
 cpl_error_code cpl_table_copy_data_int(cpl_table *, const char *, const int *);
+cpl_error_code cpl_table_copy_data_long_long(cpl_table *, const char *,
+                                             const long long *);
 cpl_error_code cpl_table_copy_data_float(cpl_table *, const char *, 
                                          const float *);
 cpl_error_code cpl_table_copy_data_double(cpl_table *, const char *, 
@@ -218,6 +231,8 @@ int cpl_table_has_valid(const cpl_table *table, const char *name);
 
 cpl_error_code cpl_table_fill_invalid_int(cpl_table *, const char *, 
                                               int);
+cpl_error_code cpl_table_fill_invalid_long_long(cpl_table *, const char *,
+                                                long long);
 cpl_error_code cpl_table_fill_invalid_float(cpl_table *, const char *, 
                                                 float);
 cpl_error_code cpl_table_fill_invalid_double(cpl_table *, const char *, 
@@ -328,7 +343,10 @@ cpl_size cpl_table_and_selected_int(cpl_table *, const char *,
                                   cpl_table_select_operator, int);
 cpl_size cpl_table_or_selected_int(cpl_table *, const char *, 
                                   cpl_table_select_operator, int);
-
+cpl_size cpl_table_and_selected_long_long(cpl_table *, const char *,
+                                          cpl_table_select_operator, long long);
+cpl_size cpl_table_or_selected_long_long(cpl_table *, const char *,
+                                         cpl_table_select_operator, long long);
 cpl_size cpl_table_and_selected_float(cpl_table *, const char *, 
                                     cpl_table_select_operator, float);
 cpl_size cpl_table_or_selected_float(cpl_table *, const char *, 
