@@ -1,4 +1,4 @@
-/* $Id: cpl_test.h,v 1.61 2012/08/23 12:52:49 llundin Exp $
+/* $Id: cpl_test.h,v 1.62 2013/02/20 09:47:08 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/08/23 12:52:49 $
- * $Revision: 1.61 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/20 09:47:08 $
+ * $Revision: 1.62 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifndef CPL_TEST_H
@@ -899,6 +899,7 @@ CPL_BEGIN_DECLS
   @ingroup cpl_test
   @brief  Test if the memory system is empty
   @see    cpl_memory_is_empty()
+  @deprecated Called by cpl_test_end()
  */
 /*----------------------------------------------------------------------------*/
 #define cpl_test_memory_is_empty() do {                                 \
@@ -908,7 +909,8 @@ CPL_BEGIN_DECLS
         cpl_errorstate cpl_test_state = cpl_errorstate_get();           \
         cpl_test_memory_is_empty_macro(cpl_test_errno, cpl_test_time,   \
                                        cpl_test_flops, cpl_test_state,  \
-                                       cpl_func, __FILE__, __LINE__)
+                                       cpl_func, __FILE__, __LINE__);   \
+    } while (0)
 
 /*----------------------------------------------------------------------------*/
 /**
