@@ -1,4 +1,4 @@
-/* $Id: cpl_vector.h,v 1.65 2011/11/29 13:28:48 llundin Exp $
+/* $Id: cpl_vector.h,v 1.66 2013/02/04 12:57:00 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2011/11/29 13:28:48 $
- * $Revision: 1.65 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/04 12:57:00 $
+ * $Revision: 1.66 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifndef CPL_VECTOR_H
@@ -159,6 +159,7 @@ cpl_vector * cpl_vector_extract(const cpl_vector *, cpl_size,
 /* Statistics on cpl_vector */
 double cpl_vector_get_min(const cpl_vector *);
 double cpl_vector_get_max(const cpl_vector *);
+double cpl_vector_get_sum(const cpl_vector *);
 double cpl_vector_get_mean(const cpl_vector *);
 double cpl_vector_get_median(cpl_vector *);
 double cpl_vector_get_median_const(const cpl_vector *);
