@@ -1,4 +1,4 @@
-/* $Id: cpl_xmemory.c,v 1.41 2011/08/18 07:58:32 llundin Exp $
+/* $Id: cpl_xmemory.c,v 1.43 2012/11/15 10:25:16 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2011/08/18 07:58:32 $
- * $Revision: 1.41 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/11/15 10:25:16 $
+ * $Revision: 1.43 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -199,8 +199,8 @@ void * cpl_xmemory_malloc_count(size_t size)
 
     } else if (size != 0) {
 
-        fprintf(stderr, "cpl_xmemory fatal error: malloc(%lu) returned NULL:\n",
-                (long unsigned)size);
+        fprintf(stderr, "cpl_xmemory fatal error: malloc(%zu) returned NULL:\n",
+                size);
         perror(NULL);
         cpl_xmemory_fatal = 1;
         cpl_xmemory_status(cpl_xmemory_table_size ? 2 : 1);
@@ -245,8 +245,8 @@ void * cpl_xmemory_calloc_count(size_t nmemb, size_t size)
 
     } else if (size != 0 && nmemb != 0) {
 
-        fprintf(stderr, "cpl_xmemory fatal error: calloc(%lu, %lu) returned "
-                "NULL:\n", (long unsigned)nmemb, (long unsigned)size);
+        fprintf(stderr, "cpl_xmemory fatal error: calloc(%zu, %zu) returned "
+                "NULL:\n", nmemb, size);
         perror(NULL);
         cpl_xmemory_fatal = 1;
         cpl_xmemory_status(cpl_xmemory_table_size ? 2 : 1);
@@ -283,8 +283,8 @@ void * cpl_xmemory_realloc_count(void * oldptr, size_t size)
         ptr = cpl_xmemory_malloc_count(size);
 
     } else if (cpl_xmemory_ncells == 0) {
-        fprintf(stderr, "cpl_xmemory error: Ignoring realloc() to %lu bytes on "
-                "unallocated pointer (%p)\n", (long unsigned)size, oldptr);
+        fprintf(stderr, "cpl_xmemory error: Ignoring realloc() to %zu bytes on "
+                "unallocated pointer (%p)\n", size, oldptr);
         ptr = NULL;
     } else {
 
@@ -295,8 +295,8 @@ void * cpl_xmemory_realloc_count(void * oldptr, size_t size)
         if (ptr == NULL) {
 
             if (size != 0) {
-                fprintf(stderr, "cpl_xmemory fatal error: realloc(%p, %lu) "
-                        "returned NULL:\n", oldptr, (long unsigned)size);
+                fprintf(stderr, "cpl_xmemory fatal error: realloc(%p, %zu) "
+                        "returned NULL:\n", oldptr, size);
                 perror(NULL);
                 cpl_xmemory_fatal = 1;
                 cpl_xmemory_status(cpl_xmemory_table_size ? 2 : 1);
@@ -454,18 +454,16 @@ void * cpl_xmemory_realloc(void * oldptr, size_t size)
     if (oldptr != NULL) {
 
         if (cpl_xmemory_table_size == 0) {
-            fprintf(stderr, "cpl_xmemory error: Ignoring realloc() of %lu bytes"
-                    " requested on unallocated pointer (%p)\n",
-                    (unsigned long) size, oldptr);
+            fprintf(stderr, "cpl_xmemory error: Ignoring realloc() of %zu bytes"
+                    " requested on unallocated pointer (%p)\n", size, oldptr);
             return NULL;
         }
 
         pos = cpl_xmemory_findcell(oldptr);
 
         if (pos == cpl_xmemory_table_size) {
-            fprintf(stderr, "cpl_xmemory error: Ignoring realloc() of %lu bytes"
-                    " requested on unallocated pointer (%p)\n",
-                    (unsigned long) size, oldptr);
+            fprintf(stderr, "cpl_xmemory error: Ignoring realloc() of %zu bytes"
+                    " requested on unallocated pointer (%p)\n", size, oldptr);
             return NULL;
         }
 
@@ -596,26 +594,26 @@ void cpl_xmemory_status(int mode)
 
             if (mode == 2) {
                 fprintf(stderr,
-                        "Peak pointer usage [pointer]: %u\n"
-                        "Peak memory allocation [B]:   %lu\n"
-                        "Peak table size [pointer]:    %lu\n"
-                        "Peak table size [B]:          %lu\n",
+                        "Peak pointer usage [pointer]: %zu\n"
+                        "Peak memory allocation [B]:   %zu\n"
+                        "Peak table size [pointer]:    %zu\n"
+                        "Peak table size [B]:          %zu\n",
                         cpl_xmemory_max_cells,
-                        (unsigned long)cpl_xmemory_alloc_max,
-                        (unsigned long)cpl_xmemory_table_size_max,
-                        (unsigned long)(cpl_xmemory_table_size_max*rowsize));
+                        cpl_xmemory_alloc_max,
+                        cpl_xmemory_table_size_max,
+                        cpl_xmemory_table_size_max * rowsize);
             } else {
                 fprintf(stderr, "Maximum number of pointers"
 #               ifdef _OPENMP
                         /* cpl_xmemory_max_cells is not updated thread-safely */
                         " (approximate)"
 #               endif
-                        ": %u\n", cpl_xmemory_max_cells);
+                        ": %zu\n", cpl_xmemory_max_cells);
             }
 
             fprintf(stderr, "#----- Memory Currently Allocated -----\n");
 
-            fprintf(stderr, "Number of active pointers:    %u\n",
+            fprintf(stderr, "Number of active pointers:    %zu\n",
                     cpl_xmemory_ncells);
 
             if (mode == 2 && cpl_xmemory_ncells > 0) {
@@ -625,12 +623,12 @@ void cpl_xmemory_status(int mode)
                 /* assert( cpl_xmemory_table_size != 0 ); */
 
                 fprintf(stderr,
-                        "Memory allocation [B]:        %lu\n"
-                        "Current table size [pointer]: %u\n"
-                        "Current table size [B]:       %lu\n",
-                        (unsigned long)cpl_xmemory_alloc_ram,
-                        (unsigned)cpl_xmemory_table_size,
-                        (unsigned long)(cpl_xmemory_table_size*rowsize));
+                        "Memory allocation [B]:        %zu\n"
+                        "Current table size [pointer]: %zu\n"
+                        "Current table size [B]:       %zu\n",
+                        cpl_xmemory_alloc_ram,
+                        cpl_xmemory_table_size,
+                        cpl_xmemory_table_size * rowsize);
 
                 /* Do not print entire table on fatal error
                    - it is likely huge */
@@ -640,19 +638,16 @@ void cpl_xmemory_status(int mode)
                     if (cpl_xmemory_p_type[ii] != CPL_XMEMORY_TYPE_FREE) {
                         ntype[cpl_xmemory_p_type[ii]]++;
                         if (cpl_xmemory_fatal == 0)
-                            fprintf(stderr, "(%p) - %s() of %lu bytes\n",
+                            fprintf(stderr, "(%p) - %s() of %zu bytes\n",
                                     cpl_xmemory_p_val[ii],
                                     cpl_xmemory_type[cpl_xmemory_p_type[ii]],
-                                    (unsigned long)cpl_xmemory_p_size[ii]);
+                                    cpl_xmemory_p_size[ii]);
                     }
                 }
                 fprintf(stderr, "#- Types of active pointers\n");
-                fprintf(stderr, "%7s(): %u\n", cpl_xmemory_type[1],
-                        (unsigned)ntype[1]);
-                fprintf(stderr, "%7s(): %u\n", cpl_xmemory_type[2],
-                        (unsigned)ntype[2]);
-                fprintf(stderr, "%7s(): %u\n", cpl_xmemory_type[3],
-                        (unsigned)ntype[3]);
+                fprintf(stderr, "%7s(): %zu\n", cpl_xmemory_type[1], ntype[1]);
+                fprintf(stderr, "%7s(): %zu\n", cpl_xmemory_type[2], ntype[2]);
+                fprintf(stderr, "%7s(): %zu\n", cpl_xmemory_type[3], ntype[3]);
             }
             if (cpl_xmemory_fatal != 0) (void)fflush(stderr);
         }
@@ -762,7 +757,7 @@ static void cpl_xmemory_init_alloc(void)
         cpl_xmemory_p_type == NULL) {
         /* The table could not be allocated */
         fprintf(stderr, "cpl_xmemory fatal error: calloc() of memory table "
-                "failed with size %u:\n", cpl_xmemory_table_size);
+                "failed with size %zu:\n", cpl_xmemory_table_size);
         perror(NULL);
         cpl_xmemory_fatal = 1;
         cpl_xmemory_status(1); /* Mode-2 data is invalid! */
@@ -804,7 +799,7 @@ static void cpl_xmemory_resize(void)
     if (cpl_xmemory_table_size <= old_size) {
         /* The table could not be resized */
         fprintf(stderr, "cpl_xmemory fatal error: Memory table could not be "
-                "resized, %u < %u:\n", cpl_xmemory_table_size, old_size);
+                "resized, %zu < %zu:\n", cpl_xmemory_table_size, old_size);
         perror(NULL);
         cpl_xmemory_fatal = 1;
         cpl_xmemory_status(1); /* Mode-2 data is invalid! */
