@@ -1,4 +1,4 @@
-/* $Id: cpl_image_basic-test.c,v 1.98 2012/11/07 09:46:07 llundin Exp $
+/* $Id: cpl_image_basic-test.c,v 1.98.2.1 2013/04/22 06:52:07 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/11/07 09:46:07 $
- * $Revision: 1.98 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/04/22 06:52:07 $
+ * $Revision: 1.98.2.1 $
+ * $Name: cpl-6_3_1 $
  */
 
 /*-----------------------------------------------------------------------------
@@ -70,6 +70,7 @@ static void cpl_image_collapse_median_test(void);
 static void cpl_image_complex_mult(size_t o1, size_t o2, size_t n);
 static void cpl_image_complex_mult_d(size_t o1, size_t o2, size_t n);
 static void cpl_image_get_fwhm_test(void);
+static void cpl_image_divide_test_one(void);
 
 /*-----------------------------------------------------------------------------
                                   Main
@@ -131,6 +132,8 @@ int main(void)
 
     /* Insert tests below */
 
+    cpl_image_divide_test_one();
+
     cpl_image_get_fwhm_test();
     cpl_image_collapse_median_test();
     cpl_image_copy_test();
@@ -1738,3 +1741,49 @@ static void cpl_image_get_fwhm_test(void)
     cpl_test_eq_ptr((const void*)x, cpl_image_unwrap(im1d));
 
 }
+
+/*----------------------------------------------------------------------------*/
+/**
+  @internal
+  @brief  Test the CPL function
+  @return void
+  @see cpl_image_divide()
+
+ */
+/*----------------------------------------------------------------------------*/
+static void cpl_image_divide_test_one(void) {
+
+    cpl_image * img1 = cpl_image_new(1, 2, CPL_TYPE_DOUBLE);
+    cpl_image * img2 = cpl_image_new(1, 2, CPL_TYPE_DOUBLE);
+    cpl_error_code code;
+
+    code = cpl_image_add_scalar(img1, 5.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    code = cpl_image_add_scalar(img2, 1.0);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+
+    cpl_test_abs(cpl_image_get_flux(img1), 10.0, DBL_EPSILON);
+
+    cpl_test_zero(cpl_image_count_rejected(img1));
+    cpl_test_zero(cpl_image_count_rejected(img2));
+    code = cpl_image_reject(img1, 1, 1);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+    cpl_test_eq(cpl_image_count_rejected(img1), 1);
+
+    cpl_test_abs(cpl_image_get_flux(img1), 5.0, DBL_EPSILON);
+
+    code = cpl_image_divide(img1, img2);
+    cpl_test_eq_error(code, CPL_ERROR_NONE);
+
+
+    cpl_test_abs(cpl_image_get_flux(img1), 5.0, DBL_EPSILON);
+
+    cpl_test_eq(cpl_image_count_rejected(img1), 1);
+
+    cpl_image_delete(img1);
+    cpl_image_delete(img2);
+
+}
