@@ -1,4 +1,4 @@
-/* $Id: cpl_image_filter-test.c,v 1.48 2011/07/01 14:41:44 llundin Exp $
+/* $Id: cpl_image_filter-test.c,v 1.53 2012/12/17 11:48:40 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2011/07/01 14:41:44 $
- * $Revision: 1.48 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/12/17 11:48:40 $
+ * $Revision: 1.53 $
+ * $Name: cpl-6_3_1 $
  */
 
 /*-----------------------------------------------------------------------------
@@ -82,6 +82,9 @@ int main(void)
     cpl_image_filter_test(8, 8, 0, 2);
     cpl_image_filter_test(8, 8, 2, 2);
 
+    cpl_image_filter_test(31, 31, 2, 2);
+    cpl_image_filter_test(15, 63, 1, 1);
+
     return cpl_test_end(0);
 }
 
@@ -106,13 +109,26 @@ static void cpl_image_filter_test(int nx, int ny, int hm, int hn)
                                            CPL_FILTER_STDEV_FAST, 
                                            CPL_FILTER_AVERAGE, 
                                            CPL_FILTER_AVERAGE_FAST,
-                                           CPL_FILTER_LINEAR};
+                                           CPL_FILTER_LINEAR,
+                                           CPL_FILTER_LINEAR_SCALE};
 
+    /* Whether the above filter is used with cpl_image_filter_mask() */
     const cpl_boolean filter_mask[] = {CPL_TRUE, CPL_TRUE, CPL_TRUE,
-                                       CPL_TRUE, CPL_TRUE, CPL_FALSE};
-    /* Compare with morpho on a kernel of ones */
-    const cpl_boolean filter_morph[]  = {CPL_FALSE, CPL_FALSE, CPL_FALSE,
-                     CPL_TRUE, CPL_FALSE, CPL_TRUE};
+                                       CPL_TRUE, CPL_TRUE,
+                                       CPL_FALSE, CPL_FALSE};
+    /* Compare with different filter on a kernel also of all ones */
+    const cpl_filter_mode filter_ones[]  = {CPL_FILTER_MEDIAN,
+                                            CPL_FILTER_STDEV_FAST, 
+                                            CPL_FILTER_STDEV, 
+                                            CPL_FILTER_LINEAR,
+                                            CPL_FILTER_LINEAR,
+                                            CPL_FILTER_MORPHO,
+                                            CPL_FILTER_MORPHO_SCALE};
+
+    /* Whether the above filter is used with cpl_image_filter_mask() */
+    const cpl_boolean filter_mask1[] = {CPL_TRUE, CPL_TRUE, CPL_TRUE,
+                                        CPL_FALSE, CPL_FALSE,
+                                        CPL_FALSE, CPL_FALSE};
 
     const cpl_type pixel_type[] = {CPL_TYPE_INT, CPL_TYPE_FLOAT,
                                    CPL_TYPE_DOUBLE};
@@ -134,6 +150,12 @@ static void cpl_image_filter_test(int nx, int ny, int hm, int hn)
     cpl_test_eq(sizeof(filter_mode)/sizeof(filter_mode[0]),
                 sizeof(filter_mask)/sizeof(filter_mask[0]));
 
+    cpl_test_eq(sizeof(filter_mask)/sizeof(filter_mask[0]),
+                sizeof(filter_mask1)/sizeof(filter_mask1[0]));
+
+    cpl_test_eq(sizeof(filter_ones)/sizeof(filter_ones[0]),
+                sizeof(filter_mask1)/sizeof(filter_mask1[0]));
+
     cpl_test_zero(cpl_mask_not(window1));
     cpl_test_zero(cpl_matrix_fill(xwindow1, 1.0));
 
@@ -180,8 +202,9 @@ static void cpl_image_filter_test(int nx, int ny, int hm, int hn)
                     double tol = 0.0;
 
 
-                    cpl_msg_info(cpl_func, "%u-filtering %u X %u %s to %s with "
-                                 "%u X %u", filter_mode[ifilt], nx, ny,
+                    cpl_msg_info(cpl_func, "%u <=> %u - filtering %u X %u %s "
+                                 "to %s with %u X %u", filter_mode[ifilt],
+                                 filter_ones[ifilt], nx, ny,
                                  cpl_type_get_name(pixel_type[itype1]),
                                  cpl_type_get_name(pixel_type[itype2]), m, n);
 
@@ -224,7 +247,7 @@ static void cpl_image_filter_test(int nx, int ny, int hm, int hn)
                                mask of filt2 equals filt1, except that is has a
                                halo of zeros */
                             if (filter_mode[ifilt] == CPL_FILTER_AVERAGE_FAST
-                || filter_mode[ifilt] == CPL_FILTER_STDEV_FAST) {
+                                || filter_mode[ifilt] == CPL_FILTER_STDEV_FAST) {
                                 /* In this case filtim1 is actually done with 
                                    CPL_FILTER_AVERAGE */
                                 tol = 10.0 * (xmax - xmin)
@@ -253,28 +276,50 @@ static void cpl_image_filter_test(int nx, int ny, int hm, int hn)
                                 }
                             }
 
-                /* The precision loss is higher in this case */
-                if (filter_mode[ifilt] == CPL_FILTER_STDEV_FAST)
-                tol = 1.0;
+                            /* The precision loss is higher in this case */
+                            if (filter_mode[ifilt] == CPL_FILTER_STDEV_FAST)
+                                tol = 1.0;
                         }
                         cpl_test_image_abs(filtim1, filtim2, tol);
 
-                        if (filter_morph[ifilt]) {
-                            /* Result should equal that of a morpho with
-                               all ones */
+                        if (filter_ones[ifilt] != filter_mode[ifilt]) {
+                            /* Result should equal that of a different filter
+                               also with all ones */
                             /* The additions are reordered (sorted),
                                i.e. different round-off */
+                            const cpl_boolean isfloat =
+                                pixel_type[itype1] == CPL_TYPE_FLOAT || 
+                                pixel_type[itype2] == CPL_TYPE_FLOAT;
                             tol = (xmax - xmin)
-                                * ((pixel_type[itype1] == CPL_TYPE_FLOAT || 
-                                    pixel_type[itype2] == CPL_TYPE_FLOAT)
-                                   ? FLT_EPSILON : DBL_EPSILON);
+                                * (isfloat ? FLT_EPSILON : DBL_EPSILON);
 
-                            error = cpl_image_filter(filtim2, testimg,
-                                                     xwindow1,
-                                                     CPL_FILTER_MORPHO,
-                                                     CPL_BORDER_FILTER);
+                            if (filter_mode[ifilt] == CPL_FILTER_LINEAR_SCALE
+                                && !isfloat) tol *= (double)(n*m);
+                            else if (filter_mode[ifilt] == CPL_FILTER_LINEAR &&
+                                     filter_ones[ifilt] == CPL_FILTER_MORPHO &&
+                                     !isfloat)
+                                    tol *= 1.5;
+                            if (filter_mode[ifilt] == CPL_FILTER_AVERAGE_FAST)
+                                tol *= (1.0 + (double)n)*(1.0 + (double)m);
+                            if (filter_mode[ifilt] == CPL_FILTER_STDEV_FAST ||
+                                filter_ones[ifilt] == CPL_FILTER_STDEV_FAST) {
+                                if (pixel_type[itype1] == CPL_TYPE_INT &&
+                                    pixel_type[itype2] == CPL_TYPE_INT)
+                                    tol = -1.0; /* FIXME: Not supported */
+                                else tol *= 100.0 * (double)(n * m);
+                            }
+
+                            error = filter_mask1[ifilt] ?
+                                cpl_image_filter_mask(filtim2, testimg, window1,
+                                                      filter_ones[ifilt],
+                                                      CPL_BORDER_FILTER) :
+                                cpl_image_filter(filtim2, testimg,
+                                                 xwindow1,
+                                                 filter_ones[ifilt],
+                                                 CPL_BORDER_FILTER);
                             cpl_test_eq_error(error, exp_err);
-                            cpl_test_image_abs(filtim1, filtim2, tol);
+                            if (tol >= 0.0)
+                                cpl_test_image_abs(filtim1, filtim2, tol);
                         }
 
                         if (itype1 == itype2) {
@@ -317,7 +362,8 @@ static void cpl_image_filter_test(int nx, int ny, int hm, int hn)
 
                                     cpl_test_error(error);
                                     if (filter_mode[ifilt] == CPL_FILTER_STDEV
-                    || filter_mode[ifilt] == CPL_FILTER_STDEV_FAST) {
+                                        || filter_mode[ifilt] ==
+                                        CPL_FILTER_STDEV_FAST) {
                                         cpl_test_eq(error,
                                                     CPL_ERROR_DATA_NOT_FOUND);
                                     } else {
