@@ -1,4 +1,4 @@
-/* $Id: cpl_image_io-test.c,v 1.66 2012/03/13 15:06:03 llundin Exp $
+/* $Id: cpl_image_io-test.c,v 1.75 2013/02/22 14:29:33 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,26 +20,19 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/03/13 15:06:03 $
- * $Revision: 1.66 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/22 14:29:33 $
+ * $Revision: 1.75 $
+ * $Name: cpl-6_3_1 $
  */
 
 /*-----------------------------------------------------------------------------
                                    Includes
  -----------------------------------------------------------------------------*/
 
-#include <math.h>
-#include <complex.h>
-
-#include "cpl_fits.h"
 #include "cpl_image_io_impl.h"
-#include "cpl_image_gen.h"
-#include "cpl_image_bpm.h"
 #include "cpl_test.h"
-#include "cpl_memory.h"
+#include "cpl_fits.h"
 
-#include "fitsio.h"
 /*-----------------------------------------------------------------------------
                                    Defines
  -----------------------------------------------------------------------------*/
@@ -56,6 +49,7 @@
 
 static double cpl_image_get_precision(cpl_type, cpl_type, double);
 static void cpl_image_fill_int_test(void);
+static void cpl_image_save_compression_test(void);
 
 /*-----------------------------------------------------------------------------
                                   Main
@@ -64,7 +58,7 @@ int main(void)
 {
     const cpl_type     imtypes[] = {CPL_TYPE_DOUBLE, CPL_TYPE_FLOAT,
                                     CPL_TYPE_INT, CPL_TYPE_DOUBLE_COMPLEX,
-                    CPL_TYPE_FLOAT_COMPLEX};
+                                    CPL_TYPE_FLOAT_COMPLEX};
     const cpl_type bpps[] = {CPL_TYPE_UCHAR, CPL_TYPE_SHORT,
                              CPL_TYPE_USHORT, CPL_TYPE_INT,
                              CPL_TYPE_FLOAT, CPL_TYPE_DOUBLE};
@@ -92,6 +86,8 @@ int main(void)
 
     cpl_test_nonnull(stream);
 
+    (void)remove(FILENAME); /* May (also) exist with wrong perms */
+
     /* Check the image type size */
     cpl_test_eq( cpl_type_get_sizeof(CPL_TYPE_DOUBLE), sizeof(double));
     cpl_test_eq( cpl_type_get_sizeof(CPL_TYPE_FLOAT),  sizeof(float));
@@ -124,7 +120,6 @@ int main(void)
     cpl_test_error(CPL_ERROR_NULL_INPUT);
     cpl_test_null(nullimg);
 
-    (void)remove(FILENAME); /* May (also) exist with wrong perms */
     nullimg = cpl_image_load(FILENAME, CPL_TYPE_UNSPECIFIED, 0, 0);
     cpl_test_error(CPL_ERROR_FILE_IO);
     cpl_test_null(nullimg);
@@ -525,6 +520,7 @@ int main(void)
     if ( imtype != CPL_TYPE_FLOAT_COMPLEX && 
          imtype != CPL_TYPE_DOUBLE_COMPLEX) {
         for (ibpp = 0; ibpp < nbpp; ibpp++) {
+            int j;
 
             cpl_msg_info(cpl_func, "Testing saving with BITPIX=%d and pixels "
                          "ranging: %g -> %g", bpps[ibpp], minval[ibpp],
@@ -588,23 +584,36 @@ int main(void)
 
             cpl_test_eq( cpl_fits_count_extensions(FILENAME), ibpp );
 
-            /* Tests for no-casting type */
-            copy = cpl_image_load(FILENAME, CPL_TYPE_UNSPECIFIED,
-                                  0, ibpp);
-            cpl_test_error(CPL_ERROR_NONE);
-            cpl_test_nonnull(copy);
+            error = cpl_image_save(img, FILENAME, bpps[ibpp] == CPL_TYPE_USHORT
+                                   ? CPL_TYPE_SHORT : bpps[ibpp],
+                                   NULL, CPL_IO_APPEND);
+            cpl_test_eq_error(error, CPL_ERROR_ILLEGAL_INPUT);
 
-            if (bpps[ibpp] == CPL_TYPE_UCHAR  ||
-                bpps[ibpp] == CPL_TYPE_SHORT   ||
-                bpps[ibpp] == CPL_TYPE_USHORT ||
-                bpps[ibpp] == CPL_TYPE_INT     )
-                cpl_test_eq(cpl_image_get_type(copy), CPL_TYPE_INT);
-            else if (bpps[ibpp] == CPL_TYPE_FLOAT)
-                cpl_test_eq(cpl_image_get_type(copy), CPL_TYPE_FLOAT);
-            else
-                cpl_test_eq(cpl_image_get_type(copy), CPL_TYPE_DOUBLE);
+            cpl_test_eq( cpl_fits_count_extensions(FILENAME), ibpp );
 
-            cpl_image_delete(copy);
+            for (j = 0; j < 1; j++) { /* Only 1 iteration, no append */
+                /* Tests for no-casting type */
+                copy = cpl_image_load(FILENAME, CPL_TYPE_UNSPECIFIED,
+                                      j, ibpp);
+                cpl_test_error(CPL_ERROR_NONE);
+                cpl_test_nonnull(copy);
+
+                if (bpps[ibpp] == CPL_TYPE_UCHAR  ||
+                    bpps[ibpp] == CPL_TYPE_SHORT   ||
+                    bpps[ibpp] == CPL_TYPE_USHORT ||
+                    bpps[ibpp] == CPL_TYPE_INT     ) {
+                    cpl_test_eq(cpl_image_get_type(copy), CPL_TYPE_INT);
+                    cpl_test_image_abs(copy, img, 0.0);
+                } else if (bpps[ibpp] == CPL_TYPE_FLOAT) {
+                    cpl_test_eq(cpl_image_get_type(copy), CPL_TYPE_FLOAT);
+                    cpl_test_image_abs(copy, img, maxval[ibpp] * FLT_EPSILON);
+                } else {
+                    cpl_test_eq(cpl_image_get_type(copy), CPL_TYPE_DOUBLE);
+                    cpl_test_image_abs(copy, img, maxval[ibpp] * DBL_EPSILON);
+                }
+
+                cpl_image_delete(copy);
+            }
 
             /* Check error handling in windowed image loading */
             nullimg = cpl_image_load_window(FILENAME, CPL_TYPE_UNSPECIFIED,
@@ -965,6 +974,9 @@ int main(void)
 
     }
 
+    /* Image compression tests */
+    cpl_image_save_compression_test();
+
     cpl_test_zero( remove(FILENAME) );
 
     if (stream != stdout) cpl_test_zero( fclose(stream) );
@@ -977,6 +989,9 @@ int main(void)
 /**
   @internal
   @brief  Get the precision obtainable for the combined types
+  @param  pixeltype The CPL image pixel type
+  @param  bpptype   The CFITSIO pixel type to be used on disk
+  @param  rel2abs The largest absolute value used in the image
   @note   Ugly, incorrect kludge for CPL_TYPE_FLOAT + CPL_TYPE_DOUBLE
  */
 /*----------------------------------------------------------------------------*/
@@ -1047,3 +1062,166 @@ static void cpl_image_fill_int_test(void)
     cpl_image_delete(self);
 
 }
+
+/*----------------------------------------------------------------------------*/
+/**
+  @brief    Test saving with compression
+  @return   void
+  @see cpl_image_save()
+ */
+/*----------------------------------------------------------------------------*/
+static void cpl_image_save_compression_test(void)
+{
+    /* Default CFITSIO quantization parameter for lossy floating point
+       compression is q = 1, reducing precision to 4.08 % */
+    const double prec = 0.0408;
+    const double maxval = 255.0;
+    const cpl_type imtypes[] = {CPL_TYPE_DOUBLE, CPL_TYPE_FLOAT,
+                                CPL_TYPE_INT};
+    const size_t   ntyp = sizeof(imtypes)/sizeof(imtypes[0]);
+    size_t         ityp;
+
+    /* Saving with different image types, bitpix and compression types */
+
+    for (ityp = 0; ityp < ntyp; ityp++) {
+        const cpl_type bpps[] = {CPL_TYPE_UCHAR, CPL_TYPE_SHORT,
+                                 CPL_TYPE_USHORT, CPL_TYPE_INT,
+                                 CPL_TYPE_FLOAT, CPL_TYPE_DOUBLE,
+                                 CPL_TYPE_UNSPECIFIED};
+        const size_t   nbpp = sizeof(bpps)/sizeof(bpps[0]);
+
+        const cpl_type imtype = imtypes[ityp];
+        cpl_image * img = cpl_image_new(IMAGESZ, IMAGESZ, imtype);
+        cpl_error_code error;
+        int isig;
+
+        error = cpl_image_add_scalar(img, maxval);
+        cpl_test_eq_error(error, CPL_ERROR_NONE);
+
+        for (isig=0; isig < 2; isig++) {
+            size_t         ibpp;
+
+            for (ibpp = 0; ibpp < nbpp; ibpp++) {
+                const cpl_io_type comp_meths[] = {CPL_IO_COMPRESS_GZIP, 
+                                                  CPL_IO_COMPRESS_RICE, 
+                                                  CPL_IO_COMPRESS_HCOMPRESS,
+                                                  CPL_IO_COMPRESS_PLIO};
+                const size_t ncomp = sizeof(comp_meths)/sizeof(comp_meths[0]);
+                const int bitpix =
+                    cpl_tools_get_bpp(bpps[ibpp] == CPL_TYPE_UNSPECIFIED
+                                      ? imtype : bpps[ibpp]);
+                size_t icomp;
+                int ext = 0;
+
+                error = cpl_image_save(img, FILENAME, bpps[ibpp], NULL,
+                                       CPL_IO_CREATE);            
+                cpl_test_eq_error(error, CPL_ERROR_NONE);
+
+                /* Tests with compression */
+                for (icomp = 0; icomp < ncomp; icomp++) {
+                    const cpl_io_type comp_method = comp_meths[icomp];
+
+                    /* The compression method flag must be non-zero */
+                    cpl_test(comp_method);
+
+                    /* Saving with compression in non supported combinations */
+                    error = cpl_image_save(NULL, FILENAME, bpps[ibpp], NULL,
+                                           CPL_IO_EXTEND | comp_method);
+                    cpl_test_eq_error(error, CPL_ERROR_ILLEGAL_INPUT);
+
+                    /* Compression is only supported when adding new extensions, 
+                     * not creating a new file and saving data in the main header */
+                    error = cpl_image_save(img, FILENAME, bpps[ibpp], NULL,
+                                           CPL_IO_CREATE | comp_method);
+                    cpl_test_eq_error(error, CPL_ERROR_ILLEGAL_INPUT);
+
+                    for (size_t icomp2 = 0; icomp2 < icomp; icomp2++) {
+                        const cpl_io_type comp_method2 = comp_meths[icomp2];
+
+                        error = cpl_image_save(img, FILENAME, bpps[ibpp], NULL,
+                                               CPL_IO_EXTEND | comp_method
+                                               | comp_method2);
+                        cpl_test_eq_error(error, CPL_ERROR_ILLEGAL_INPUT);
+
+                        for (size_t icomp3 = 0; icomp3 < icomp2; icomp3++) {
+                            const cpl_io_type comp_method3 = comp_meths[icomp3];
+
+                            error = cpl_image_save(img, FILENAME, bpps[ibpp], NULL,
+                                                   CPL_IO_EXTEND | comp_method
+                                                   | comp_method2 | comp_method3);
+                            cpl_test_eq_error(error, CPL_ERROR_ILLEGAL_INPUT);
+                        }
+
+                    }
+
+                    error = cpl_image_save(img, FILENAME, bpps[ibpp], NULL,
+                                           CPL_IO_EXTEND | CPL_IO_COMPRESS_GZIP |
+                                           CPL_IO_COMPRESS_RICE | 
+                                           CPL_IO_COMPRESS_HCOMPRESS |
+                                           CPL_IO_COMPRESS_PLIO);
+                    cpl_test_eq_error(error, CPL_ERROR_ILLEGAL_INPUT);
+
+
+                    error = cpl_image_save(img, FILENAME, bpps[ibpp], NULL,
+                                           CPL_IO_EXTEND | comp_method);
+
+                    if (
+#ifndef CPL_IO_COMPRESSION_LOSSY
+                        /* Currently, compression only allowed with integer data */
+                        bitpix < 0 ||
+#endif
+                        /* FP-data compresses only to int, float or double */ 
+                        /* RICE-compression supports only int, float or double */
+                        /* In fact, this applies to all compressions... */
+                        abs(bitpix) < 32) {
+
+                        cpl_test_eq_error(error, CPL_ERROR_UNSUPPORTED_MODE);
+
+                    } else {
+
+                        cpl_image * img_load;
+
+                        cpl_test_eq_error(error, CPL_ERROR_NONE);
+
+                        cpl_test_fits(FILENAME);
+                        ext++;
+
+                        cpl_test_eq( cpl_fits_count_extensions(FILENAME), ext);
+
+                        img_load = cpl_image_load(FILENAME,
+                                                  CPL_TYPE_UNSPECIFIED,
+                                                  0,  ext);
+
+                        cpl_test_error(CPL_ERROR_NONE);
+                        cpl_test_nonnull(img_load);
+
+                        if (img_load != NULL) {
+
+                            cpl_test_eq(cpl_image_get_size_x(img_load),
+                                        IMAGESZ);
+                            cpl_test_eq(cpl_image_get_size_y(img_load),
+                                        IMAGESZ);
+
+                            if (imtype == CPL_TYPE_INT) {
+                                cpl_test_image_abs(img, img_load, 0.0);
+                            } else {
+                                cpl_test_image_abs(img, img_load,
+                                                   prec * maxval);
+                            }
+                            cpl_image_delete(img_load);
+                        }
+                    }
+                }
+            }
+
+            error = cpl_image_subtract_scalar(img, maxval);
+            cpl_test_eq_error(error, CPL_ERROR_NONE);
+
+            error = cpl_image_fill_noise_uniform(img, 0.0, maxval);
+            cpl_test_eq_error(error, CPL_ERROR_NONE);
+
+        }
+
+        cpl_image_delete(img);
+    }
+}
