@@ -1,4 +1,4 @@
-/* $Id: cpl_image_iqe-test.c,v 1.20 2010/11/11 09:23:18 llundin Exp $
+/* $Id: cpl_image_iqe-test.c,v 1.21 2013/01/16 16:45:07 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2010/11/11 09:23:18 $
- * $Revision: 1.20 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/01/16 16:45:07 $
+ * $Revision: 1.21 $
+ * $Name: cpl-6_3_1 $
  */
 
 /*-----------------------------------------------------------------------------
@@ -114,6 +114,27 @@ int main(void)
 
     cpl_image_delete(imd); 
     cpl_image_delete(imf);
+    
+    /*
+     * Regression test for a copy and paste bug found in line cpl_image_iqe.c:745.
+     */
+    imf = cpl_image_new(200, 64, CPL_TYPE_FLOAT);
+    cpl_test_nonnull(imf);
+    cpl_image_fill_noise_uniform(imf, -10, 10);
+    cpl_test_error( CPL_ERROR_NONE );
+    imd = cpl_image_duplicate(imf);
+    cpl_test_nonnull(imd);
+    cpl_image_fill_gaussian(imd, 168, 32, 50000.0, 15, 4);
+    cpl_test_error( CPL_ERROR_NONE );
+    cpl_image_add(imf, imd);
+    cpl_test_error( CPL_ERROR_NONE );
+    res = cpl_image_iqe(imf, 1, 1, cpl_image_get_size_x(imf),
+                        cpl_image_get_size_y(imf));
+    cpl_test_error( CPL_ERROR_NONE );
+    cpl_test_nonnull(res);
+    cpl_bivector_delete(res);
+    cpl_image_delete(imd);
+    cpl_image_delete(imf);
 
     if (stream != stdout) cpl_test_zero( fclose(stream) );
 
