@@ -1,4 +1,4 @@
-/* $Id: cpl_matrix-test.c,v 1.56 2012/09/07 09:02:29 llundin Exp $
+/* $Id: cpl_matrix-test.c,v 1.57 2012/11/16 09:52:52 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/09/07 09:02:29 $
- * $Revision: 1.56 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/11/16 09:52:52 $
+ * $Revision: 1.57 $
+ * $Name: cpl-6_3_1 $
  */
 
 /*-----------------------------------------------------------------------------
@@ -337,7 +337,8 @@ int main(void)
 
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
-          sprintf(message, "Check element %d, %d of constant matrix... ", i, j);
+          sprintf(message, "Check element %" CPL_SIZE_FORMAT ", %"
+                  CPL_SIZE_FORMAT " of constant matrix... ", i, j);
           test_fvalue(13.565656565, .000001, cpl_matrix_get(matrix, i, j), 
                       message);
       }
@@ -443,18 +444,20 @@ int main(void)
   c = cpl_matrix_get_ncol(matrix);
 
   for (i = 0; i < c; i++) {
-      sprintf(message, "Check element %d of copied row... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT " of copied row... ",
+              i);
       test_fvalue(cpl_matrix_get(matrix, 2, i), 0.00001,
                   cpl_matrix_get(copia, 0, i), message);
   }
 
   cpl_matrix_delete(copia);
 
-/*
+#ifdef CPL_MATRIX_TEST_EXTRA
   test(cpl_matrix_copy_row_remove(matrix, subdArray, 1), "Write one row... ");
 
   for (i = 0; i < c; i++) {
-      sprintf(message, "Check element %d of written row... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT
+              " of written row... ", i);
       test_fvalue(subdArray[i], 0.00001, cpl_matrix_get(matrix, 1, i),
                   message);
   }
@@ -464,22 +467,25 @@ int main(void)
   r = cpl_matrix_get_nrow(matrix);
 
   for (i = 0; i < r; i++) {
-      sprintf(message, "Check element %d of copied column... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT
+              " of copied column... ", i);
       test_fvalue(cpl_matrix_get(matrix, i, 3), 0.00001,
                   cpl_matrix_get(copia, i, 0), message);
   }
 
   cpl_matrix_delete(copia);
 
-  test(cpl_matrix_copy_column_remove(matrix, subdArray, 1), "Write one column... ");
+  test(cpl_matrix_copy_column_remove(matrix, subdArray, 1),
+       "Write one column... ");
 
   for (i = 0; i < r; i++) {
-      sprintf(message, "Check element %d of written column... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT
+              " of written column... ", i);
       test_fvalue(subdArray[i], 0.00001, cpl_matrix_get(matrix, i, 1),
                   message);
   }
 
-*/
+#endif
 
   value = 9.00;
   for (i = 0; i < nelem; i++) {
@@ -493,7 +499,8 @@ int main(void)
   r = cpl_matrix_get_nrow(matrix);
 
   for (i = 0; i < r; i++) {
-      sprintf(message, "Check element %d of copied diagonal... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT
+              " of copied diagonal... ", i);
       test_fvalue(cpl_matrix_get(matrix, i, i), 0.00001,
                   cpl_matrix_get(copia, i, 0), message);
   }
@@ -504,20 +511,22 @@ int main(void)
                     "Copy third diagonal... ");
 
   for (i = 0; i < r; i++) {
-      sprintf(message, "Check element %d of copied third diagonal... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT
+              " of copied third diagonal... ", i);
       test_fvalue(cpl_matrix_get(matrix, i , i + 2), 0.00001,
                   cpl_matrix_get(copia, i, 0), message);
   }
 
   cpl_matrix_delete(copia);
 
-/*
+#ifdef CPL_MATRIX_TEST_EXTRA
 
   test(cpl_matrix_copy_diagonal_remove(matrix, subdArray, 0), 
                     "Write main diagonal... ");
 
   for (i = 0; i < r; i++) {
-      sprintf(message, "Check element %d of written diagonal... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT " of written "
+              "diagonal... ", i);;
       test_fvalue(subdArray[i], 0.00001, cpl_matrix_get(matrix, i, i),
                   message);
   }
@@ -526,12 +535,13 @@ int main(void)
                     "Write third diagonal... ");
 
   for (i = 0; i < r; i++) {
-      sprintf(message, "Check element %d of written diagonal... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT " of written "
+              "diagonal... ", i);
       test_fvalue(subdArray[i], 0.00001, cpl_matrix_get(matrix, i, i + 2),
                   message);
   }
 
-*/
+#endif
 
   value = 9.00;
   for (i = 0; i < nelem; i++) {
@@ -550,7 +560,8 @@ int main(void)
   c = cpl_matrix_get_ncol(matrix);
 
   for (i = 0; i < c; i++) {
-      sprintf(message, "Check element %d of copied diagonal (vertical)... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT " of copied diagonal "
+              "(vertical)... ", i);
       test_fvalue(cpl_matrix_get(matrix, i, i), 0.00001,
                   cpl_matrix_get(copia, 0, i), message);
   }
@@ -562,21 +573,23 @@ int main(void)
 
   for (i = 0; i < c; i++) {
       sprintf(message, 
-              "Check element %d of copied second diagonal (vertical)... ", i);
+              "Check element %" CPL_SIZE_FORMAT " of copied second diagonal "
+              "(vertical)... ", i);
       test_fvalue(cpl_matrix_get(matrix, i + 1, i), 0.00001,
                   cpl_matrix_get(copia, 0, i), message);
   }
 
   cpl_matrix_delete(copia);
 
-/*
+#ifdef CPL_MATRIX_TEST_EXTRA
 
   test(cpl_matrix_copy_diagonal_remove(matrix, subdArray, 0),
                     "Write main diagonal (vertical)... ");
 
   for (i = 0; i < c; i++) {
       sprintf(message, 
-              "Check element %d of written diagonal (vertical)... ", i);
+              "Check element %" CPL_SIZE_FORMAT " of written diagonal "
+              "(vertical)... ", i);
       test_fvalue(subdArray[i], 0.00001, cpl_matrix_get(matrix, i, i),
                   message);
   }
@@ -586,12 +599,13 @@ int main(void)
 
   for (i = 0; i < c; i++) {
       sprintf(message, 
-              "Check element %d of written second diagonal (vertical)... ", i);
+              "Check element %" CPL_SIZE_FORMAT " of written second diagonal "
+              "(vertical)... ", i);
       test_fvalue(subdArray[i], 0.00001, cpl_matrix_get(matrix, i + 1, i),
                   message);
   }
 
-*/
+#endif
 
   cpl_free(subdArray);
 
@@ -601,7 +615,8 @@ int main(void)
   r = c * cpl_matrix_get_nrow(matrix);
 
   for (i = 0; i < r; i++) {
-      sprintf(message, "Check element %d, %d of matrix... ", i / c, i % c);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+              " of matrix... ", i / c, i % c);
       test_fvalue(3.33, 0.00001, cpl_matrix_get(matrix, i / c, i % c),
                   message);
   }
@@ -609,7 +624,8 @@ int main(void)
   test(cpl_matrix_fill_row(matrix, 2.0, 4), "Write 2 to row 4...");
 
   for (i = 0; i < c; i++) {
-      sprintf(message, "Check element %d of constant row... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT " of constant row... ",
+              i);
       test_fvalue(2.0, 0.00001, cpl_matrix_get(matrix, 4, i), message);
   }
 
@@ -618,7 +634,8 @@ int main(void)
   r = cpl_matrix_get_nrow(matrix);
 
   for (i = 0; i < r; i++) {
-      sprintf(message, "Check element %d of constant column... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT
+              " of constant column... ", i);
       test_fvalue(9.99, 0.00001, cpl_matrix_get(matrix, i, 2), message);
   }
 
@@ -626,7 +643,8 @@ int main(void)
        "Write 1.11 to main diagonal...");
 
   for (i = 0; i < c; i++) {
-      sprintf(message, "Check element %d of constant main diagonal... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT
+              " of constant main diagonal... ", i);
       test_fvalue(1.11, 0.00001, cpl_matrix_get(matrix, i, i), message);
   }
 
@@ -634,7 +652,8 @@ int main(void)
                     "Write 1.11 to second diagonal...");
 
   for (i = 0; i < c; i++) {
-      sprintf(message, "Check element %d of constant second diagonal... ", i);
+      sprintf(message, "Check element %" CPL_SIZE_FORMAT
+              " of constant second diagonal... ", i);
       test_fvalue(1.1, 0.00001, cpl_matrix_get(matrix, i + 1, i), message);
   }
 
@@ -657,7 +676,8 @@ int main(void)
 
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
-          sprintf(message, "Check element %d, %d of submatrix... ", i, j);
+          sprintf(message, "Check element %" CPL_SIZE_FORMAT ", %"
+                  CPL_SIZE_FORMAT " of submatrix... ", i, j);
           test_fvalue(cpl_matrix_get(matrix, i, j), 0.00001,
                       cpl_matrix_get(copia, i, j), message);
       }
@@ -669,7 +689,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message, 
-                  "Check element %d, %d of modified submatrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of modified submatrix... ", i, j);
           test_fvalue(cpl_matrix_get(matrix, i, j) - 8., 0.00001,
                       cpl_matrix_get(copia, i, j), message);
       }
@@ -681,7 +702,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of modified matrix... ", i + 2, j + 2);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of modified matrix... ", i + 2, j + 2);
           test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                       cpl_matrix_get(matrix, i + 2, j + 2), message);
       }
@@ -695,7 +717,8 @@ int main(void)
   for (i = 1; i < 4; i++) {
       for (j = 1; j < 3; j++) {
           sprintf(message,
-                  "Check element %d, %d of constant submatrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of constant submatrix... ", i, j);
           test_fvalue(0.0, 0.00001, cpl_matrix_get(matrix, i, j), message);
       }
   }
@@ -716,7 +739,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of overwritten matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of overwritten matrix... ", i, j);
           if (i > 1 && j > 1) {
               test_fvalue(0.0, 0.00001, 
                           cpl_matrix_get(matrix, i, j), message);
@@ -750,7 +774,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message, 
-                  "Check element %d, %d of first shifted matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of first shifted matrix... ", i, j);
           if (i > r - 2) {
               test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                           cpl_matrix_get(matrix, i + 1 - r, j), message);
@@ -770,7 +795,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of second shifted matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of second shifted matrix... ", i, j);
           if (j > c - 2) {
               test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                           cpl_matrix_get(matrix, i, j + 1 - c), message);
@@ -790,7 +816,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of third shifted matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of third shifted matrix... ", i, j);
           if (j > c - 5 && i > r - 5) {
               test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                           cpl_matrix_get(matrix, i + 4 - r, j + 4 - c), 
@@ -819,7 +846,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of fourth shifted matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of fourth shifted matrix... ", i, j);
           if (j < 4 && i < 4) {
               test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                           cpl_matrix_get(matrix, i - 4 + r, j - 4 + c),
@@ -895,7 +923,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of chopped matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of chopped matrix... ", i, j);
           if (cpl_matrix_get(copia, i, j) < 9.505) {
               test_fvalue(0.0, 0.00001,
                           cpl_matrix_get(matrix, i, j), message);
@@ -926,7 +955,8 @@ int main(void)
   test(cpl_matrix_swap_rows(matrix, 1, 3), "Swap rows 1 and 3... ");
 
   for (j = 0; j < c; j++) {
-      sprintf(message, "Check column %d of row swapped matrix... ", j);
+      sprintf(message, "Check column %" CPL_SIZE_FORMAT
+              " of row swapped matrix... ", j);
       test_fvalue(cpl_matrix_get(copia, 1, j), 0.00001,
                   cpl_matrix_get(matrix, 3, j), message);
       test_fvalue(cpl_matrix_get(copia, 3, j), 0.00001,
@@ -942,7 +972,8 @@ int main(void)
   test(cpl_matrix_swap_columns(matrix, 1, 3), "Swap columns 1 and 3... ");
 
   for (i = 0; i < r; i++) {
-      sprintf(message, "Check row %d of column swapped matrix... ", i);
+      sprintf(message, "Check row %" CPL_SIZE_FORMAT
+              " of column swapped matrix... ", i);
       test_fvalue(cpl_matrix_get(copia, i, 1), 0.00001,
                   cpl_matrix_get(matrix, i, 3), message);
       test_fvalue(cpl_matrix_get(copia, i, 1), 0.00001,
@@ -966,7 +997,8 @@ int main(void)
                     "Swapping row 1 with column 1... ");
 
   for (i = 0; i < 5; i++) {
-      sprintf(message, "Check row/column element %d of swapped matrix... ", i);
+      sprintf(message, "Check row/column element %" CPL_SIZE_FORMAT
+              " of swapped matrix... ", i);
       test_fvalue(cpl_matrix_get(matrix, i, 1), 0.00001,
                   cpl_matrix_get(copia, 1, i), message);
       test_fvalue(cpl_matrix_get(matrix, i, 1), 0.00001,
@@ -982,7 +1014,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of row-flipped matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of row-flipped matrix... ", i, j);
           test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                       cpl_matrix_get(matrix, r - i - 1, j), message);
       }
@@ -993,7 +1026,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of row-flipped matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of row-flipped matrix... ", i, j);
           test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                       cpl_matrix_get(matrix, r - i - 1, c - j - 1), message);
       }
@@ -1007,12 +1041,14 @@ int main(void)
       value += .01;
   }
 
-  test_data(copia, cpl_matrix_transpose_create(matrix), "Compute transpose... ");
+  test_data(copia, cpl_matrix_transpose_create(matrix),
+            "Compute transpose... ");
 
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of transposed matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of transposed matrix... ", i, j);
           test_fvalue(cpl_matrix_get(matrix, i, j), 0.00001,
                       cpl_matrix_get(copia, j, i), message);
       }
@@ -1035,7 +1071,8 @@ int main(void)
           break;
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of row-deleted matrix... ", k, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of row-deleted matrix... ", k, j);
           test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                       cpl_matrix_get(matrix, k, j), message);
       }
@@ -1052,7 +1089,8 @@ int main(void)
           if (j > 1 && j < 5)
               break;
           sprintf(message,
-                  "Check element %d, %d of row-deleted matrix... ", k, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of row-deleted matrix... ", k, j);
           test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                       cpl_matrix_get(matrix, k, j), message);
           l++;
@@ -1082,7 +1120,8 @@ int main(void)
   for (i = 2; i < r - 2; i++) {
       for (j = 2; j < c - 2; j++) {
           sprintf(message,
-                  "Check element %d, %d of cropped matrix... ", i - 2, j - 2);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of cropped matrix... ", i - 2, j - 2);
           test_fvalue(cpl_matrix_get(matrix, i - 2, j - 2), 0.00001,
                       cpl_matrix_get(copia, i, j), message);
       }
@@ -1093,7 +1132,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of expanded matrix... ", i, j);
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of expanded matrix... ", i, j);
           if (i > 1 && i < r - 2 && j > 1 && j < c - 2) {
               test_fvalue(cpl_matrix_get(copia, i, j), 0.00001,
                           cpl_matrix_get(matrix, i, j), message);
@@ -1132,7 +1172,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of horizontally merged matrix... ", 
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of horizontally merged matrix... ", 
                   i, j + 1);
           test_fvalue(cpl_matrix_get(matrix, i, j), 0.00001,
                       cpl_matrix_get(copia, i, j + 1), message);
@@ -1141,7 +1182,8 @@ int main(void)
 
   for (i = 0; i < r; i++) {
       sprintf(message, 
-              "Check element %d, %d of horizontally merged matrix... ",
+              "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+              " of horizontally merged matrix... ",
               i, 0);
       test_fvalue(cpl_matrix_get(product, i, 0), 0.00001,
                   cpl_matrix_get(copia, i, 0), message);
@@ -1160,7 +1202,8 @@ int main(void)
   for (i = 0; i < 4; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of vertically merged matrix... ",
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of vertically merged matrix... ",
                   i, j);
           test_fvalue(cpl_matrix_get(product, i, j), 0.00001,
                       cpl_matrix_get(copia, i, j), message);
@@ -1170,7 +1213,8 @@ int main(void)
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
           sprintf(message,
-                  "Check element %d, %d of vertically merged matrix... ",
+                  "Check element %" CPL_SIZE_FORMAT ", %" CPL_SIZE_FORMAT
+                  " of vertically merged matrix... ",
                   i + 4, j);
           test_fvalue(cpl_matrix_get(matrix, i, j), 0.00001,
                       cpl_matrix_get(copia, i + 4, j), message);
@@ -1187,7 +1231,8 @@ int main(void)
 
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
-          sprintf(message, "Check element %d, %d of sum matrix... ", i, j);
+          sprintf(message, "Check element %" CPL_SIZE_FORMAT ", %"
+                  CPL_SIZE_FORMAT " of sum matrix... ", i, j);
           test_fvalue(cpl_matrix_get(matrix, i, j) * 2, 0.00001,
                       cpl_matrix_get(copia, i, j), message);
       }
@@ -1197,7 +1242,8 @@ int main(void)
 
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
-          sprintf(message, "Check element %d, %d of diff matrix... ", i, j);
+          sprintf(message, "Check element %" CPL_SIZE_FORMAT ", %"
+                  CPL_SIZE_FORMAT " of diff matrix... ", i, j);
           test_fvalue(cpl_matrix_get(matrix, i, j), 0.00001,
                       cpl_matrix_get(copia, i, j), message);
       }
@@ -1207,7 +1253,8 @@ int main(void)
 
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
-          sprintf(message, "Check element %d, %d of mult matrix... ", i, j);
+          sprintf(message, "Check element %" CPL_SIZE_FORMAT ", %"
+                  CPL_SIZE_FORMAT " of mult matrix... ", i, j);
           test_fvalue(cpl_matrix_get(matrix, i, j) * 
                       cpl_matrix_get(matrix, i, j), 0.00001,
                       cpl_matrix_get(copia, i, j), message);
@@ -1218,7 +1265,8 @@ int main(void)
 
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
-          sprintf(message, "Check element %d, %d of ratio matrix... ", i, j);
+          sprintf(message, "Check element %" CPL_SIZE_FORMAT ", %"
+                  CPL_SIZE_FORMAT " of ratio matrix... ", i, j);
           test_fvalue(cpl_matrix_get(matrix, i, j), 0.00001,
                       cpl_matrix_get(copia, i, j), message);
       }
@@ -1228,7 +1276,8 @@ int main(void)
 
   for (i = 0; i < r; i++) {
       for (j = 0; j < c; j++) {
-          sprintf(message, "Check element %d, %d of half matrix... ", i, j);
+          sprintf(message, "Check element %" CPL_SIZE_FORMAT ", %"
+                  CPL_SIZE_FORMAT " of half matrix... ", i, j);
           test_fvalue(cpl_matrix_get(matrix, i, j) / 2, 0.00001,
                       cpl_matrix_get(copia, i, j), message);
       }
@@ -1247,7 +1296,8 @@ int main(void)
   for (i = 0, k = 0; i < 3; i++) {
       for (j = 0; j < 4; j++) {
           k++;
-          sprintf(message, "Writing to element %d of the first matrix... ", k);
+          sprintf(message, "Writing to element %" CPL_SIZE_FORMAT
+                  " of the first matrix... ", k);
           test(cpl_matrix_set(matrix, i, j, value), message);
           value++;
       }
@@ -1257,13 +1307,15 @@ int main(void)
   for (i = 0, k = 0; i < 4; i++) {
       for (j = 0; j < 5; j++) {
           k++;
-          sprintf(message, "Writing to element %d of the second matrix... ", k);
+          sprintf(message, "Writing to element %" CPL_SIZE_FORMAT
+                  " of the second matrix... ", k);
           test(cpl_matrix_set(copia, i, j, value), message);
           value++;
       }
   }
 
-  test_data(product, cpl_matrix_product_create(matrix, copia), "Matrix product... ");
+  test_data(product, cpl_matrix_product_create(matrix, copia),
+            "Matrix product... ");
 
   test_fvalue(10., 0.00001, cpl_matrix_get(product, 0, 0), 
               "Check element 0, 0 of product... ");
@@ -1317,7 +1369,8 @@ int main(void)
   test_ivalue(1, r, "Check min row pos 2...");
   test_ivalue(1, c, "Check min col pos 2...");
 
-  test_fvalue(-2.0, 0.0001, cpl_matrix_get_min(matrix), "Check min value 2... ");
+  test_fvalue(-2.0, 0.0001, cpl_matrix_get_min(matrix),
+              "Check min value 2... ");
 
   test(cpl_matrix_get_maxpos(matrix, &r, &c), "Find max pos 2... ");
 
@@ -1352,7 +1405,8 @@ int main(void)
   /* cpl_matrix_dump(matrix); */
   /* cpl_matrix_dump(copia); */
 
-  test_data(product, cpl_matrix_solve_normal(matrix, copia), "Least squares... ");
+  test_data(product, cpl_matrix_solve_normal(matrix, copia),
+            "Least squares... ");
 
   /* cpl_matrix_dump(product); */
 /* */
@@ -1480,11 +1534,11 @@ int main(void)
 
       error = cpl_matrix_get_2norm_1(xsolv);
 
-      cpl_msg_info("","2-norm of residual with ill-conditioned %d x %d [DBL_EPSILON]: %g",
-                   size, size, residual/DBL_EPSILON);
+      cpl_msg_info("","2-norm of residual with ill-conditioned %d x %d "
+                   "[DBL_EPSILON]: %g", size, size, residual/DBL_EPSILON);
 
-      cpl_msg_info("","2-norm of error on solution with ill-conditioned %d x %d : %g",
-                   size, size, error);
+      cpl_msg_info("","2-norm of error on solution with ill-conditioned "
+                   "%d x %d : %g", size, size, error);
 
       cpl_matrix_dump(xsolv, stream);
 
