@@ -1,4 +1,4 @@
-/* $Id: cpl_msg-test.c,v 1.13 2010/11/11 09:23:18 llundin Exp $
+/* $Id: cpl_msg-test.c,v 1.14 2012/11/15 09:36:07 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2010/11/11 09:23:18 $
- * $Revision: 1.13 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/11/15 09:36:07 $
+ * $Revision: 1.14 $
+ * $Name: cpl-6_3_1 $
  */
 
 #include <string.h>
@@ -65,7 +65,7 @@ int main(void)
     cpl_msg_indent_more(); nindent++;
     cpl_msg_info(cpl_func,"hhd: %hhd\n", (char)-1);
     cpl_msg_indent_more(); nindent++;
-    cpl_msg_info(cpl_func,"zu: %zu\n", sizeof(int));
+    cpl_msg_info(cpl_func,"zu: %zu\n", sizeof(size_t));
     cpl_msg_indent_more(); nindent++;
     cpl_msg_info(cpl_func,"td: %td\n",  (__func__ ) - (__func__ + 2) );
     cpl_msg_indent_more(); nindent++;
