@@ -1,4 +1,4 @@
-/* $Id: cpl_vector-test.c,v 1.96 2012/08/27 11:35:40 llundin Exp $
+/* $Id: cpl_vector-test.c,v 1.97 2013/02/04 12:57:00 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/08/27 11:35:40 $
- * $Revision: 1.96 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/04 12:57:00 $
+ * $Revision: 1.97 $
+ * $Name: cpl-6_3_1 $
  */
 
 /*-----------------------------------------------------------------------------
@@ -428,6 +428,12 @@ int main(void)
     cpl_test_eq_error( cpl_vector_fill(tmp_vec, 1.0), CPL_ERROR_NONE );
     cpl_test_abs( cpl_vector_get_mean(tmp_vec), 1.0, DBL_EPSILON );
 
+    cpl_test_abs( cpl_vector_get_sum(tmp_vec), (double)(VECTOR_SIZE),
+                  DBL_EPSILON * sqrt((double)(VECTOR_SIZE)));
+
+    (void)cpl_vector_get_sum(NULL);
+    cpl_test_error(CPL_ERROR_NULL_INPUT);
+
     /* Test extract function */
     tmp_vec2 = cpl_vector_extract(tmp_vec, 0, VECTOR_SIZE/2, 1);
     cpl_test_nonnull( tmp_vec2 );
