@@ -1,4 +1,4 @@
-/* $Id: cpl_dfs.c,v 1.135 2012/08/17 13:53:40 rpalsa Exp $
+/* $Id: cpl_dfs.c,v 1.136 2012/12/04 08:06:30 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: rpalsa $
- * $Date: 2012/08/17 13:53:40 $
- * $Revision: 1.135 $
- * $Name: cpl-6_2 $
+ * $Author: llundin $
+ * $Date: 2012/12/04 08:06:30 $
+ * $Revision: 1.136 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -109,8 +109,14 @@
  */
 
 /**@{*/
+
+#ifdef HAVE_OPENSSL
+#include <openssl/evp.h>
+#else
 /* Declarations of static MD5 functions */
 #include "md5.h"
+#endif
+
 
 #if defined CFITSIO_MAJOR && (CFITSIO_MAJOR > 3 || CFITSIO_MINOR >= 26)
 /* Not needed from 3.26 */
@@ -1223,7 +1229,6 @@ static cpl_error_code cpl_dfs_update_product_header_(cpl_frameset * self)
 
 }
 
-
 /*----------------------------------------------------------------------------*/
 /**
   @internal
@@ -1258,8 +1263,14 @@ static char * cpl_dfs_find_md5sum(fitsfile * fproduct)
 
     */
 
+#ifdef HAVE_OPENSSL
+    EVP_MD_CTX        ctx;
+    unsigned char     digest[EVP_MAX_MD_SIZE];
+    unsigned int      md_len;
+#else
     struct MD5Context ctx;
     unsigned char     digest[(MD5HASHSZ)>>1];
+#endif
 
     int error = 0;
     int next = 0;
@@ -1285,7 +1296,12 @@ static char * cpl_dfs_find_md5sum(fitsfile * fproduct)
 
     cpl_ensure(fproduct != NULL, CPL_ERROR_NULL_INPUT, NULL);
 
+#ifdef HAVE_OPENSSL
+    assert( (EVP_MAX_MD_SIZE) >= (MD5HASHSZ) );
+    EVP_DigestInit(&ctx, EVP_md5());
+#else
     MD5Init(&ctx);
+#endif
 
     /* Iterate through main HDU and all extensions */
     do {
@@ -1332,8 +1348,13 @@ static char * cpl_dfs_find_md5sum(fitsfile * fproduct)
                 }
 
                 /* Compute MD5 sum here */
+#ifdef HAVE_OPENSSL
+                EVP_DigestUpdate(&ctx, (const void *)buffer, (size_t) blocksize);
+#else
                 MD5Update(&ctx, (const unsigned char *)buffer,
                           (unsigned)blocksize);
+#endif
+
                 datasize -= blocksize;
                 datastart += blocksize;;
             } while (datasize > 0);
@@ -1369,7 +1390,12 @@ static char * cpl_dfs_find_md5sum(fitsfile * fproduct)
         return NULL;
     }
 
+#ifdef HAVE_OPENSSL
+    EVP_DigestFinal_ex(&ctx, digest, &md_len);
+    EVP_MD_CTX_cleanup(&ctx);
+#else
     MD5Final(digest, &ctx);
+#endif
 
     /* Write digest into a string */
     return cpl_sprintf
@@ -2044,5 +2070,7 @@ static char * cpl_dfs_extract_printable(const char * self)
 #endif
 
 
+#ifndef HAVE_OPENSSL
 /* Definitions of static MD5 functions */
 #include "md5.c"
+#endif
