@@ -1,4 +1,4 @@
-/* $Id: cpl_apertures.c,v 1.33 2012/04/04 12:05:51 llundin Exp $
+/* $Id: cpl_apertures.c,v 1.34 2012/11/14 12:23:29 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2012/04/04 12:05:51 $
- * $Revision: 1.33 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/11/14 12:23:29 $
+ * $Revision: 1.34 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -189,14 +189,15 @@ void cpl_apertures_dump(const cpl_apertures * self,
         fprintf(fp, "\n");
 
         for (i = 0; i < self->naperts; i++) {
-            fprintf(fp, "% 3d %6.1f %6.1f", i+1, self->x[i], self->y[i]);
+            fprintf(fp, "% 3" CPL_SIZE_FORMAT " %6.1f %6.1f", i+1,
+                    self->x[i], self->y[i]);
             fprintf(fp, "    %6.1f    %6.1f",
                     self->xcentroid[i], self->ycentroid[i]);
             fprintf(fp, " %6" CPL_SIZE_FORMAT " %6" CPL_SIZE_FORMAT,
                     self->maxpos_x[i], self->maxpos_y[i]);
             fprintf(fp, " %6" CPL_SIZE_FORMAT " %6" CPL_SIZE_FORMAT,
                     self->minpos_x[i], self->minpos_y[i]);
-            fprintf(fp, " % 6d", self->npix[i]);
+            fprintf(fp, " % 6" CPL_SIZE_FORMAT, self->npix[i]);
             fprintf(fp, " %6.2f", self->max_val[i]);
             fprintf(fp, " %6.2f", self->min_val[i]);
             fprintf(fp, " %6.2f", self->mean[i]);
