@@ -1,4 +1,4 @@
-/* $Id: cpl_fft.h,v 1.7 2012/05/09 08:42:37 llundin Exp $
+/* $Id: cpl_fft.h,v 1.8 2013/01/24 17:21:52 cgarcia Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -73,7 +73,7 @@ enum _cpl_fft_mode_ {
      * Spend even more time finding the best transform
      * @hideinitializer
      */
-    CPL_FFT_FIND_EXHAUSTIVE =  1 <<  6,
+    CPL_FFT_FIND_EXHAUSTIVE =  1 <<  6
 
 };
 
