@@ -1,4 +1,4 @@
-/* $Id: cpl_ppm.c,v 1.36 2011/10/06 10:07:48 llundin Exp $
+/* $Id: cpl_ppm.c,v 1.37 2012/11/14 12:56:21 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2002-2007 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2011/10/06 10:07:48 $
- * $Revision: 1.36 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/11/14 12:56:21 $
+ * $Revision: 1.37 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -44,7 +44,6 @@
 #include <cpl_polynomial.h>
 #include <cpl_ppm.h>
 
-
 /**
  * @defgroup cpl_ppm Point pattern matching module
  *
@@ -1549,10 +1548,10 @@ cpl_ppm_match_points(const cpl_matrix *data, cpl_size use_data, double err_data,
     cpl_polynomial *trans_y;
     double          err;
     double         *distance;
-    double         *scale, median_scale, rms_scale;
-    double         *angle, median_angle, rms_angle;
-    double         *angle_s, median_s, rms_s;
-    double         *angle_c, median_c, rms_c;
+    double         *scale, median_scale;
+    double         *angle, median_angle;
+    double         *angle_s;
+    double         *angle_c;
     double          scale_tolerance, angle_tolerance;
     int             i;
 
@@ -1712,24 +1711,28 @@ cpl_ppm_match_points(const cpl_matrix *data, cpl_size use_data, double err_data,
      */
 
     if (cpl_table_has_valid(table, "distance")) {
+        const double median_s = cpl_table_get_column_median(table, "angle_s");
+#ifdef CPL_PPM_DEBUG
+        const double rms_s    = cpl_table_get_column_stdev(table, "angle_s");
+        const double rms_c    = cpl_table_get_column_stdev(table, "angle_c");
+        const double rms_angle= sqrt(rms_s*rms_s + rms_c*rms_c);
+        double rms_scale;
+#endif
+        const double median_c = cpl_table_get_column_median(table, "angle_c");
+
         median_scale = cpl_table_get_column_median(table, "scale");
-        rms_scale    = cpl_table_get_column_stdev(table, "scale");
-/*
-        cpl_msg_debug(cpl_func, 
-                     "Median scale (first iteration) = %.4f +/- %.4f", 
-                     median_scale, rms_scale);
-*/
-        median_s     = cpl_table_get_column_median(table, "angle_s");
-        rms_s        = cpl_table_get_column_stdev(table, "angle_s");
-        median_c     = cpl_table_get_column_median(table, "angle_c");
-        rms_c        = cpl_table_get_column_stdev(table, "angle_c");
         median_angle = atan2(median_s, median_c);
-        rms_angle    = sqrt(rms_s*rms_s + rms_c*rms_c);
-/*
+
+#ifdef CPL_PPM_DEBUG
+        rms_scale = cpl_table_get_column_stdev(table, "scale");
+
         cpl_msg_debug(cpl_func, 
-                     "Median angle (first iteration) = %.4f +/- %.4f degrees", 
-                     median_angle*CPL_MATH_DEG_RAD, rms_angle*CPL_MATH_DEG_RAD);
-*/
+                      "Median scale (first iteration) = %.4f +/- %.4f", 
+                      median_scale, rms_scale);
+        cpl_msg_debug(cpl_func, 
+                      "Median angle (first iteration) = %.4f +/- %.4f degrees", 
+                      median_angle*CPL_MATH_DEG_RAD, rms_angle*CPL_MATH_DEG_RAD);
+#endif
     }
     else {
         cpl_msg_debug(cpl_func, "No match found");
@@ -1773,24 +1776,28 @@ cpl_ppm_match_points(const cpl_matrix *data, cpl_size use_data, double err_data,
      */
 
     if (cpl_table_has_valid(table, "distance")) {
+        const double median_s = cpl_table_get_column_median(table, "angle_s");
+#ifdef CPL_PPM_DEBUG
+        const double rms_s    = cpl_table_get_column_stdev(table, "angle_s");
+        const double rms_c    = cpl_table_get_column_stdev(table, "angle_c");
+        const double rms_angle= sqrt(rms_s*rms_s + rms_c*rms_c);
+        double rms_scale;
+#endif
+        const double median_c = cpl_table_get_column_median(table, "angle_c");
+
         median_scale = cpl_table_get_column_median(table, "scale");
-        rms_scale    = cpl_table_get_column_stdev(table, "scale");
-/*
-        cpl_msg_debug(cpl_func, 
-                     "Median scale (second iteration) = %.4f +/- %.4f",
-                     median_scale, rms_scale);
-*/
-        median_s     = cpl_table_get_column_median(table, "angle_s");
-        rms_s        = cpl_table_get_column_stdev(table, "angle_s");
-        median_c     = cpl_table_get_column_median(table, "angle_c");
-        rms_c        = cpl_table_get_column_stdev(table, "angle_c");
         median_angle = atan2(median_s, median_c);
-        rms_angle    = sqrt(rms_s*rms_s + rms_c*rms_c);
-/*
+
+#ifdef CPL_PPM_DEBUG
+        rms_scale = cpl_table_get_column_stdev(table, "scale");
+
         cpl_msg_debug(cpl_func, 
-                     "Median angle (second iteration) = %.4f +/- %.4f degrees", 
-                     median_angle*CPL_MATH_DEG_RAD, rms_angle*CPL_MATH_DEG_RAD);
-*/
+                      "Median scale (second iteration) = %.4f +/- %.4f",
+                      median_scale, rms_scale);
+        cpl_msg_debug(cpl_func, 
+                      "Median angle (second iteration) = %.4f +/- %.4f degrees", 
+                      median_angle*CPL_MATH_DEG_RAD, rms_angle*CPL_MATH_DEG_RAD);
+#endif
     }
     else {
 /*
