@@ -1,4 +1,4 @@
-/* $Id: cpl_wcs.c,v 1.50 2012/03/19 09:54:06 rpalsa Exp $
+/* $Id: cpl_wcs.c,v 1.54 2013/01/07 12:39:11 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: rpalsa $
- * $Date: 2012/03/19 09:54:06 $
- * $Revision: 1.50 $
- * $Name: cpl-6_2 $
+ * $Author: llundin $
+ * $Date: 2013/01/07 12:39:11 $
+ * $Revision: 1.54 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -169,6 +169,11 @@ static int cpl_wcs_ffhdr2str(fitsfile *fptr, int exclude_comm, char **exclist,
  * header information is created by parsing the FITS WCS keywords from the
  * header of a file. A few ancillary items are also filled in.
  *
+ * It is allowed to pass a cpl_propertylist with a valid WCS structure and
+ * NAXIS = 0, such a propertylist can be created by cpl_wcs_platesol().
+ * In this case a cpl_wcs object is returned for which the dimensional
+ * information (accessible via cpl_wcs_get_image_dims()) will be NULL.
+ *
  * The returned property must be destroyed using the wcs destructor
  * @b cpl_wcs_delete().
  *
@@ -177,11 +182,10 @@ static int cpl_wcs_ffhdr2str(fitsfile *fptr, int exclude_comm, char **exclist,
 
 cpl_wcs *cpl_wcs_new_from_propertylist(const cpl_propertylist *plist) {
 #ifdef CPL_WCS_INSTALLED    /* If WCS is installed */
-    char *shdr,nax[9],fmt[16];
+    char *shdr;
     cpl_wcs *wcs;
-    cpl_errorstate prevstate;
     cpl_propertylist *testp;
-    int retval,nrej,nwcs,i;
+    int retval,nrej,nwcs;
     int np = 0;
     int istab = -1;
     struct wcsprm *wwcs = NULL;
@@ -248,58 +252,65 @@ cpl_wcs *cpl_wcs_new_from_propertylist(const cpl_propertylist *plist) {
     wcsset(wcs->wcsptr);
     wcsvfree(&nwcs,&wwcs);
 
-    /* If this is an image, then see if it's a compressed image */
+    wcs->naxis = wcs->wcsptr->naxis;
 
-    if (! istab) {
-	if (cpl_propertylist_has(plist,"ZNAXIS"))
-	    (void)strncpy(fmt,"ZNAXIS",16);
-	else
-	    (void)strncpy(fmt,"NAXIS",16);
+    if (wcs->naxis > 0) {
 
-	/* Now copy the stuff over to someplace where we can get it */
+        /* If this is a table, then just copy the vital WCS information over
+           and leave the image dimensional information as NULL */
 
-	wcs->naxis = wcs->wcsptr->naxis;
-	if (wcs->naxis != 0) {
-	    wcs->dims = cpl_calloc((size_t)wcs->naxis, sizeof(int));
-	    wcs->imdims = cpl_array_wrap_int(wcs->dims, wcs->naxis);
-	}
         wcs->crval = cpl_array_wrap_double(wcs->wcsptr->crval, wcs->naxis);
         wcs->crpix = cpl_array_wrap_double(wcs->wcsptr->crpix, wcs->naxis);
-        wcs->cd = cpl_matrix_wrap(wcs->naxis, wcs->naxis, wcs->wcsptr->cd);
+        wcs->cd    = cpl_matrix_wrap(wcs->naxis, wcs->naxis, wcs->wcsptr->cd);
 
-	/* Get the image size information */
+        if (! istab ) {
+            cpl_errorstate prevstate = cpl_errorstate_get();
 
-	(void)strncat(fmt,"%d",16);
-        for (i = 1; i <= wcs->naxis; i++) {
-            (void)snprintf(nax,9,fmt,i);
-            prevstate = cpl_errorstate_get();
-            wcs->dims[i-1] = cpl_propertylist_get_int(plist,nax);
-            if (!cpl_errorstate_is_equal(prevstate)) {
+            /* This is an image, see if it's a compressed image */
+            const int compressed = cpl_propertylist_has(plist, "ZNAXIS");
+            const char * fmt = compressed ? "ZNAXIS%d" : "NAXIS%d";
+            int i = wcs->naxis;
+            char * nax = cpl_sprintf(fmt, i); /* Sufficient, minimal length */
+            char * naxd = nax + (compressed ? 6 : 5); /* Digit(s) start here */
+
+            /* Now copy the stuff over to someplace where we can get it */
+
+            wcs->dims = cpl_malloc((size_t)wcs->naxis * sizeof(int));
+
+            /* Get the image size information */
+
+            for (; i > 0;) {
+                const int inax = cpl_propertylist_get_int(plist, nax);
+
+                if (!cpl_errorstate_is_equal(prevstate)) break; /* Card not OK*/
+
+                i--;
+
+                wcs->dims[i] = inax;
+
+                (void)sprintf(naxd, "%d", i); /* Cannot overflow buffer */
+            }
+
+            cpl_free(nax);
+
+            if (i > 0) {
+                /* Set the image dimensional information as NULL */
                 cpl_errorstate_set(prevstate);
-		cpl_free(wcs->dims);
-		wcs->dims = NULL;
-		wcs->naxis = 0;
-		cpl_array_unwrap(wcs->imdims);
-		wcs->imdims = NULL;
-		cpl_msg_warning(cpl_func,
-				"Image size information missing %s: "
-				"Proceed with caution\n",nax);
-		break;
-	    }
+                cpl_free(wcs->dims);
+                wcs->dims = NULL;
+                wcs->imdims = NULL;
+                wcs->naxis = 0; /* crval, crpix and cd are still non-NULL */
+            } else {
+                wcs->imdims = cpl_array_wrap_int(wcs->dims, wcs->naxis);
+            }
         }
-
-    /* If this is a table, then just copy the vital WCS information over
-       and leave the image dimensional information as NULL */
-
     } else {
-	wcs->naxis = wcs->wcsptr->naxis;
-        wcs->crval = cpl_array_wrap_double(wcs->wcsptr->crval, wcs->naxis);
-        wcs->crpix = cpl_array_wrap_double(wcs->wcsptr->crpix, wcs->naxis);
-        wcs->cd = cpl_matrix_wrap(wcs->naxis, wcs->naxis, wcs->wcsptr->cd);
+        /* FIXME: Is it correct/necessary to set to NULL ? */
+        wcs->crval = NULL;
+        wcs->crpix = NULL;
+        wcs->cd    = NULL;
     }
 
-    /* Get out of here */
-
     return(wcs);
 
 #else
