@@ -1,4 +1,4 @@
-/* $Id: cpl_wcs-test.c,v 1.33 2011/04/12 06:20:52 llundin Exp $
+/* $Id: cpl_wcs-test.c,v 1.35 2013/01/07 13:10:01 llundin Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2008 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: llundin $
- * $Date: 2011/04/12 06:20:52 $
- * $Revision: 1.33 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/01/07 13:10:01 $
+ * $Revision: 1.35 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,6 +50,8 @@
 #include <wcslib.h>
 #endif
 
+#define TESTFILE "nonaxis.fits"
+
 #define NSK 2
 #define NDK 13
 #define NIK 3
@@ -287,6 +289,8 @@ const double radec[] = {
 };
 
 static void cpl_wcs_error_test(int);
+static void cpl_wcs_test_propertylist(const cpl_propertylist *);
+static void cpl_wcs_test_one(void);
 
 int main (void) {
     int i;
@@ -308,6 +312,7 @@ int main (void) {
 
     cpl_test_init(PACKAGE_BUGREPORT,CPL_MSG_WARNING);
 
+    cpl_wcs_test_one();
     cpl_wcs_error_test(1);
 
     /* Create a propertylist for the WCS header items */
@@ -648,6 +653,7 @@ int main (void) {
     cpl_msg_info("","WCS 6 constant fit with errors: %20.12g %20.12g",d1,d2);
     cpl_test_leq(d1, 3.8e-5);
     cpl_test_leq(d2, 3.8e-5);
+    cpl_wcs_test_propertylist(opl);
     if (cpl_msg_get_level() <= CPL_MSG_DEBUG)
         cpl_propertylist_dump(opl, stdout);
     cpl_propertylist_delete(opl);
@@ -663,6 +669,7 @@ int main (void) {
     cpl_msg_info("","WCS 6 constant fit with errors: %20.12g %20.12g",d1,d2);
     cpl_test_leq(d1, 3.8e-5);
     cpl_test_leq(d2, 3.8e-5);
+    cpl_wcs_test_propertylist(opl);
     if (cpl_msg_get_level() <= CPL_MSG_DEBUG)
         cpl_propertylist_dump(opl, stdout);
     cpl_propertylist_delete(opl);
@@ -678,6 +685,7 @@ int main (void) {
     cpl_msg_info("","WCS 4 constant fit with errors: %20.12g %20.12g",d1,d2);
     cpl_test_leq(d1, 1.05e-4);
     cpl_test_leq(d2, 7.3e-5);
+    cpl_wcs_test_propertylist(opl);
     if (cpl_msg_get_level() <= CPL_MSG_DEBUG)
         cpl_propertylist_dump(opl, stdout);
     cpl_propertylist_delete(opl);
@@ -692,6 +700,7 @@ int main (void) {
     cpl_msg_info("","WCS 6 constant fit with errors: %20.12g %20.12g",d1,d2);
     cpl_test_leq(d1, 1.05e-4);
     cpl_test_leq(d2, 7.3e-5);
+    cpl_wcs_test_propertylist(opl);
     if (cpl_msg_get_level() <= CPL_MSG_DEBUG)
         cpl_propertylist_dump(opl, stdout);
     cpl_propertylist_delete(opl);
@@ -785,6 +794,47 @@ int main (void) {
     return cpl_test_end(0);
 }
 
+/*----------------------------------------------------------------------------*/
+/**
+  @internal
+  @brief  Test cpl_wcs_new_from_propertylist() using a specified propertylist
+  @param  self The propertylist to test, must be non-NULL and with NAXIS == 0
+  @return void
+  @see cpl_wcs_new_from_propertylist()
+
+  FIXME: Add more validation
+
+ */
+/*----------------------------------------------------------------------------*/
+static void cpl_wcs_test_propertylist(const cpl_propertylist * self)
+{
+        cpl_wcs * wcs =  cpl_wcs_new_from_propertylist(self);
+        const int naxis = cpl_wcs_get_image_naxis(wcs);
+        const cpl_array  * ardims  = cpl_wcs_get_image_dims(wcs);
+        const cpl_array  * arcrval = cpl_wcs_get_crval(wcs);
+        const cpl_array  * arcrpix = cpl_wcs_get_crpix(wcs);
+        const cpl_matrix * mtcd    = cpl_wcs_get_cd(wcs);
+
+        cpl_test_error(CPL_ERROR_NONE);
+        cpl_test_nonnull(wcs);
+
+        cpl_test_zero(naxis);
+
+        cpl_test_null(ardims);
+
+        cpl_test_nonnull(arcrval);
+        cpl_test_eq(cpl_array_get_size(arcrval), 2);
+
+        cpl_test_nonnull(arcrpix);
+        cpl_test_eq(cpl_array_get_size(arcrpix), 2);
+
+        cpl_test_nonnull(mtcd);
+        cpl_test_eq(cpl_matrix_get_nrow(mtcd), 2);
+        cpl_test_eq(cpl_matrix_get_ncol(mtcd), 2);
+
+        cpl_wcs_delete(wcs);
+}
+
 /*----------------------------------------------------------------------------*/
 /**
   @internal
@@ -809,3 +859,28 @@ static void cpl_wcs_error_test(int nerror) {
         cpl_test_eq_error(error, CPL_ERROR_EOL);
     }
 }
+
+
+/*----------------------------------------------------------------------------*/
+/**
+  @internal
+  @brief  Test a header from a specific file, nonaxis.fits, w. NAXIS=0
+  @return void
+
+ */
+/*----------------------------------------------------------------------------*/
+static void cpl_wcs_test_one(void)
+{
+
+    cpl_propertylist * pl = cpl_propertylist_load(TESTFILE, 0);
+
+    cpl_msg_info(cpl_func, "Testing " TESTFILE ": %p", (const void*)pl);
+
+    if (pl == NULL) {
+        /* Ignore errors */
+        cpl_test_error(cpl_error_get_code());
+    } else {
+        cpl_wcs_test_propertylist(pl);
+        cpl_propertylist_delete(pl);
+    }
+}
