@@ -1,4 +1,4 @@
-/* $Id: cpl_gasgano.c,v 1.22 2012/05/25 10:02:51 llundin Exp $
+/* $Id: cpl_gasgano.c,v 1.23 2013/01/30 15:59:18 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2006 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2012/05/25 10:02:51 $
- * $Revision: 1.22 $
- * $Name: cpl-6_2 $
+ * $Author: rpalsa $
+ * $Date: 2013/01/30 15:59:18 $
+ * $Revision: 1.23 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -69,6 +69,9 @@
 #  include "org_eso_cpl_test_NativeTest.h"
 #endif
 
+#ifdef _OPENMP
+#include <omp.h>
+#endif
 
 /*
  *Library version.
@@ -1231,6 +1234,11 @@ static void out_message_handler(const cxchar *msg) {
    JNIEnv *env;
    jstring jMsg = (jstring)0;
    int ok = 1;
+   /* java method cannot be called from multiple threads
+    * for unknown reasons a lock is insufficient too */
+#ifdef _OPENMP
+   ok = omp_get_thread_num() == 0;
+#endif
 
    ok = ok &&
       (env = currentEnv);
@@ -1252,6 +1260,11 @@ static void err_message_handler(const cxchar *msg) {
    JNIEnv *env;
    jstring jMsg = (jstring)0;
    int ok = 1;
+   /* java method cannot be called from multiple threads
+    * for unknown reasons a lock is insufficient too */
+#ifdef _OPENMP
+   ok = omp_get_thread_num() == 0;
+#endif
 
    ok = ok &&
       (env = currentEnv);
@@ -1276,6 +1289,11 @@ static void default_log_message_handler(const cxchar *domain,
    jstring jDomain;
    jstring jMsg;
    int ok = 1;
+   /* java method cannot be called from multiple threads
+    * for unknown reasons a lock is insufficient too */
+#ifdef _OPENMP
+   ok = omp_get_thread_num() == 0;
+#endif
 
    ok = ok &&
       (env = currentEnv);
