@@ -1,4 +1,4 @@
-/* $Id: cpl_frame.h,v 1.19 2012/01/11 13:38:29 rpalsa Exp $
+/* $Id: cpl_frame.h,v 1.20 2013/01/10 13:18:50 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/01/11 13:38:29 $
- * $Revision: 1.19 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/01/10 13:18:50 $
+ * $Revision: 1.20 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifndef CPL_FRAME_H
@@ -45,6 +45,22 @@ CPL_BEGIN_DECLS
 
 typedef struct _cpl_frame_ cpl_frame;
 
+/**
+ * @ingroup cpl_frame
+ *
+ * @brief
+ *   Frame comparison function.
+ *
+ * Type definition for functions which compares the frame @em other with the
+ * frame @em self.
+ *
+ * All function of this type must return -1, 0, or 1 if @em self is considered
+ * to be less than, equal or greater than @em other respectively.
+ */
+
+typedef int (*cpl_frame_compare_func)(const cpl_frame *self,
+                                      const cpl_frame *other);
+
 
 /**
  * @ingroup cpl_frame
