@@ -1,4 +1,4 @@
-/* $Id: cpl_frameset.c,v 1.37 2012/01/11 13:38:29 rpalsa Exp $
+/* $Id: cpl_frameset.c,v 1.44 2013/02/11 14:34:10 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/01/11 13:38:29 $
- * $Revision: 1.37 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/11 14:34:10 $
+ * $Revision: 1.44 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -120,25 +120,27 @@ _cpl_frameset_cache_empty(const cpl_frameset *self, cpl_frameset_cacheid id)
 }
 
 
-/*----------------------------------------------------------------------------*/
-/**
+/*
   @internal
+
   @brief Reset the internal cache of the frameset
+
   @param self     The frameset
   @param id       The caching type (TAG/POS/ALL)
-  @return void
-  @note The internal (private) members of self are modified! The const
-        modifier is still used, because this change is not visible outside
-        this module.
 
+  @return void
   The internal modification means that even though the accessor
   cpl_frameset_get_next_first()
   has only const modifiers, the call does have side-effects, and it can thus
   not be subjected to optimizations applicable to 'pure' functions (e.g. to
   call the function fewer times than the program says).
 
+  @note The internal (private) members of self are modified! The const
+        modifier is still used, because this change is not visible outside
+        this module.
+
  */
-/*----------------------------------------------------------------------------*/
+
 inline static void
 _cpl_frameset_cache_reset(const cpl_frameset *self, cpl_frameset_cacheid id)
 {
@@ -166,17 +168,16 @@ _cpl_frameset_cache_reset(const cpl_frameset *self, cpl_frameset_cacheid id)
 
 
 
-/*----------------------------------------------------------------------------*/
-/**
+/*
   @internal
+
   @brief Update the internal cache of the frameset
+
   @param self     The frameset
   @param id       The caching type (TAG/POS/ALL)
   @param position The position to cache
+
   @return void
-  @note The internal (private) members of self are modified! The const
-        modifier is still used, because this change is not visible outside
-        this module.
 
   The internal modification means that even though the accessor
   cpl_frameset_get_next_const()
@@ -184,8 +185,12 @@ _cpl_frameset_cache_reset(const cpl_frameset *self, cpl_frameset_cacheid id)
   not be subjected to optimizations applicable to 'pure' functions (e.g. to
   call the function fewer times than the program says).
 
+  @note The internal (private) members of self are modified! The const
+        modifier is still used, because this change is not visible outside
+        this module.
+
  */
-/*----------------------------------------------------------------------------*/
+
 inline static void
 _cpl_frameset_cache_push(const cpl_frameset *self, cpl_frameset_cacheid id,
                          cx_multimap_const_iterator position)
@@ -268,6 +273,94 @@ _cpl_frameset_get(const cpl_frameset *self, const char *tag)
 }
 
 
+/*
+ *  Helper functions for sorting frame sets
+ */
+
+inline static void
+_cpl_frameset_history_merge(cx_list *self, cx_list *other,
+                            const cx_multimap *frames,
+                            cpl_frame_compare_func compare)
+{
+
+    cx_assert((self != NULL) && (other != NULL));
+    cx_assert(frames != NULL);
+    cx_assert(compare != NULL);
+
+
+    if (self != other) {
+
+        cx_list_iterator first1 = cx_list_begin(self);
+        cx_list_iterator last1  = cx_list_end(self);
+
+        cx_list_iterator first2 = cx_list_begin(other);
+        cx_list_iterator last2  = cx_list_end(other);
+
+        while ((first1 != last1) && (first2 != last2)) {
+
+            cx_multimap_const_iterator node1 = cx_list_get(self, first1);
+            cx_multimap_const_iterator node2 = cx_list_get(other, first2);
+
+            if (compare(cx_multimap_get_value(frames, node1),
+                        cx_multimap_get_value(frames, node2)) < 0) {
+
+                cx_list_iterator next = cx_list_next(other, first2);
+
+                cx_list_splice(self, first1, other,first2, next);
+                first2 = next;
+
+            }
+            else {
+                first1 = cx_list_next(self, first1);
+            }
+
+        }
+
+        if (first2 != last2) {
+            cx_list_splice(self, last1, other, first2, last2);
+        }
+
+    }
+
+    return;
+
+}
+
+
+inline static cpl_error_code
+_cpl_frameset_history_sort(cx_list *self, const cx_multimap *frames,
+                           cpl_frame_compare_func compare)
+{
+
+    if (cx_list_size(self) > 1) {
+
+        cx_list *tmp = cx_list_new();
+        cx_list_iterator position = cx_list_begin(self);
+
+        cxsize middle = cx_list_size(self) / 2;
+
+        while (middle--) {
+            position = cx_list_next(self, position);
+        }
+
+        cx_list_splice(tmp, cx_list_begin(tmp),
+                       self, position, cx_list_end(self));
+
+        _cpl_frameset_history_sort(self, frames, compare);
+        _cpl_frameset_history_sort(tmp, frames, compare);
+
+        _cpl_frameset_history_merge(self, tmp, frames, compare);
+
+        cx_assert(cx_list_empty(tmp));
+        cx_list_delete(tmp);
+
+    }
+
+    return CPL_ERROR_NONE;
+
+}
+
+
 /*
  * Public methods
  */
@@ -676,6 +769,7 @@ cpl_frameset_find(cpl_frameset *self, const char *tag)
     return frame;
 }
 
+
 /**
  * @brief
  *   Get the first frame in the given set.
@@ -703,6 +797,10 @@ cpl_frameset_find(cpl_frameset *self, const char *tag)
  * @c NULL is returned. The function also updates the internal cache.
  *
  * @see cpl_frameset_get_next_const()
+ *
+ * @deprecated
+ *   This function will be removed from CPL version 7. Code using these
+ *   functions should be ported to make use of frame set iterators instead!
  */
 
 const cpl_frame *
@@ -762,6 +860,10 @@ cpl_frameset_get_first_const(const cpl_frameset *self)
  * @c NULL is returned. The function also updates the internal cache.
  *
  * @see cpl_frameset_get_next()
+ *
+ * @deprecated
+ *   This function will be removed from CPL version 7. Code using these
+ *   functions should be ported to make use of frame set iterators instead!
  */
 
 cpl_frame *
@@ -809,6 +911,10 @@ cpl_frameset_get_first(cpl_frameset *self)
  * function.
  *
  * @see cpl_frameset_get_first_const()
+ *
+ * @deprecated
+ *   This function will be removed from CPL version 7. Code using these
+ *   functions should be ported to make use of frame set iterators instead!
  */
 
 const cpl_frame *
@@ -894,6 +1000,10 @@ cpl_frameset_get_next_const(const cpl_frameset *self)
  * function.
  *
  * @see cpl_frameset_get_first()
+ *
+ * @deprecated
+ *   This function will be removed from CPL version 7. Code using these
+ *   functions should be ported to make use of frame set iterators instead!
  */
 
 cpl_frame *
@@ -1189,6 +1299,140 @@ cpl_frameset_erase_frame(cpl_frameset *self, cpl_frame *frame)
 }
 
 
+/**
+ * @brief
+ *   Join two frame sets.
+ *
+ * @param self    The target frame set
+ * @param other   The source frame set
+ *
+ * @return
+ *   The function returns @c CPL_ERROR_NONE on success or a CPL error
+ *   code otherwise.
+ *
+ * @error
+ *   <table class="ec" align="center">
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_NULL_INPUT</td>
+ *       <td class="ecr">
+ *         The parameter <i>self</i> or <i>frame</i> is a <tt>NULL</tt>
+ *         pointer.
+ *       </td>
+ *     </tr>
+ *   </table>
+ * @enderror
+ *
+ * The function adds the contents of the frame set @em other to @em self by
+ * inserting copies of the elements of the frame set @em other. If the source
+ * frame set @em other is @c NULL, or if it is empty, the function has no
+ * effect.
+ */
+
+cpl_error_code
+cpl_frameset_join(cpl_frameset *self, const cpl_frameset *other)
+{
+
+    const cxchar *const _id = "cpl_frameset_join";
+
+
+    if (self == NULL) {
+        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        return CPL_ERROR_NULL_INPUT;
+    }
+
+    if ((other != NULL) && (cpl_frameset_is_empty(other) != 1)) {
+
+        cx_multimap_iterator position = cx_multimap_begin(other->frames);
+
+        cpl_error_code status = CPL_ERROR_NONE;
+
+
+        while (position != cx_multimap_end(other->frames)) {
+
+            cpl_frame *frame  = cx_multimap_get_value(other->frames, position);
+
+            frame = cpl_frame_duplicate(frame);
+
+            /*
+             * Use high level insertion here, so that insertion order tracking
+             * is handled implicitly
+             */
+
+            status = cpl_frameset_insert(self, frame);
+
+            if (status != CPL_ERROR_NONE) {
+                cpl_frame_delete(frame);
+                cpl_error_set(_id, status);
+
+                return status;
+            }
+
+            position = cx_multimap_next(other->frames, position);
+
+        }
+
+    }
+
+    return CPL_ERROR_NONE;
+
+}
+
+
+/**
+ * @brief
+ *   Sort a frame set.
+ *
+ * @param self     The frame set to sort.
+ * @param compare  Comparison function for frames.
+ *
+ * @return
+ *   The function returns @c CPL_ERROR_NONE on success, or an appropriate
+ *   CPL error code otherwise.
+ *
+ * @error
+ * *   <table class="ec" align="center">
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_NULL_INPUT</td>
+ *       <td class="ecr">
+ *         The parameter <i>self</i> or <i>compare</i> is a <tt>NULL</tt>
+ *         pointer.
+ *       </td>
+ *     </tr>
+ *   </table>
+ * @enderror
+ *
+ * The function replaces the existing order of the frame set @em self by
+ * sorting its contents according to the comparison function @em compare.
+ *
+ * By default, the order of a frame set, i.e. the order of any newly created
+ * frame set object, is defined by the order in which frames are inserted into
+ * the frame set. By calling this function, this order will be lost. If this
+ * order has to be preserved, sorting has to be done on a copy of @em self.
+ *
+ * The function @em compare compares two frames and must return -1, 0, or
+ * 1 if the first frame is considered to be less than, equal or larger than
+ * the second frame, respectively.
+ *
+ * @see cpl_frame_compare_func
+ */
+
+cpl_error_code
+cpl_frameset_sort(cpl_frameset *self, cpl_frame_compare_func compare)
+{
+
+    const cxchar *const _id = "cpl_frameset_sort";
+
+
+    if ((self == NULL) || (compare == NULL)) {
+        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        return CPL_ERROR_NULL_INPUT;
+    }
+
+    return _cpl_frameset_history_sort(self->history, self->frames, compare);
+
+}
+
+
 /**
  * @brief
  *   Separate a list of frames into groups, using a comparison function
@@ -1339,6 +1583,12 @@ cpl_frameset_labelise(const cpl_frameset *self,
  *         The parameter <i>self</i> is a <tt>NULL</tt> pointer.
  *       </td>
  *     </tr>
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_ILLEGAL_INPUT</td>
+ *       <td class="ecr">
+ *         The parameter <i>position</i> is out of range.
+ *       </td>
+ *     </tr>
  *   </table>
  * @enderror
  *
@@ -1357,6 +1607,10 @@ cpl_frameset_labelise(const cpl_frameset *self,
  * @see
  *   cpl_frameset_get_size(), cpl_frameset_get_first_const(),
  *   cpl_frameset_get_next_const()
+ *
+ * @deprecated
+ *   This function will be removed from CPL version 7. Code using these
+ *   functions should use cpl_frameset_get_position_const() instead!
  */
 
 const cpl_frame *
@@ -1420,6 +1674,12 @@ cpl_frameset_get_frame_const(const cpl_frameset *set, cpl_size position)
  *         The parameter <i>self</i> is a <tt>NULL</tt> pointer.
  *       </td>
  *     </tr>
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_ILLEGAL_INPUT</td>
+ *       <td class="ecr">
+ *         The parameter <i>position</i> is out of range.
+ *       </td>
+ *     </tr>
  *   </table>
  * @enderror
  *
@@ -1438,6 +1698,11 @@ cpl_frameset_get_frame_const(const cpl_frameset *set, cpl_size position)
  * @see
  *   cpl_frameset_get_size(), cpl_frameset_get_first(),
  *   cpl_frameset_get_next()
+ *
+ * @deprecated
+ *   This function will be removed from CPL version 7. Code using these
+ *   functions should use cpl_frameset_get_position() instead!
+ *
  */
 
 cpl_frame *
@@ -1455,6 +1720,146 @@ cpl_frameset_get_frame(cpl_frameset *set, cpl_size position)
 }
 
 
+/**
+ * @brief
+ *   Get the frame at a given position in the frame set.
+ *
+ * @param self      The frame set
+ * @param position  Frame position.
+ *
+ * @return
+ *   The function returns the frame at the given position, or @c NULL
+ *   if an error occurs.
+ *
+ * @error
+ *   <table class="ec" align="center">
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_NULL_INPUT</td>
+ *       <td class="ecr">
+ *         The parameter <i>self</i> is a <tt>NULL</tt> pointer.
+ *       </td>
+ *     </tr>
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_ILLEGAL_INPUT</td>
+ *       <td class="ecr">
+ *         The parameter <i>position</i> is invalid, i.e. the given value is
+ *         outside of its domain.
+ *       </td>
+ *     </tr>
+ *   </table>
+ * @enderror
+ *
+ * The function retrieves the frame stored in the frame set @em self at the
+ * index position @em position. The index positions are counted from zero,
+ * and reach up to one less than the number of frames in the frame set.
+ */
+
+cpl_frame *
+cpl_frameset_get_position(cpl_frameset *self, cpl_size position)
+{
+
+    const cxchar *const _id = "cpl_frameset_get_position";
+
+    cx_list_iterator _position = NULL;
+
+    cx_multimap_iterator frame = NULL;
+
+
+    if (self == NULL) {
+        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        return NULL;
+    }
+
+    if ((position < 0) || (position >= cpl_frameset_get_size(self))) {
+        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
+        return NULL;
+    }
+
+    _position = cx_list_begin(self->history);
+
+    while (position > 0) {
+        _position = cx_list_next(self->history, _position);
+        --position;
+    }
+
+    frame = cx_list_get(self->history, _position);
+    cx_assert(frame != cx_multimap_end(self->frames));
+
+    return cx_multimap_get_value(self->frames, frame);
+
+}
+
+
+/**
+ * @brief
+ *   Get the frame at a given iterator position.
+ *
+ * @param self      The iterator to dereference
+ * @param position  Iterator offset from the beginning of the frame set.
+ *
+ * @return
+ *   The function returns the frame at the iterator position, or @c NULL
+ *   if an error occurs.
+ *
+ * @error
+ *   <table class="ec" align="center">
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_NULL_INPUT</td>
+ *       <td class="ecr">
+ *         The parameter <i>self</i> is a <tt>NULL</tt> pointer.
+ *       </td>
+ *     </tr>
+ *     <tr>
+ *       <td class="ecl">CPL_ERROR_ILLEGAL_INPUT</td>
+ *       <td class="ecr">
+ *         The parameter <i>position</i> is invalid, i.e. the given value is
+ *         outside of its domain.
+ *       </td>
+ *     </tr>
+ *   </table>
+ * @enderror
+ *
+ * The function retrieves the frame stored in the frame set @em self at the
+ * index position @em position. The index positions are counted from zero,
+ * and reach up to one less than the number of frames in the frame set.
+ */
+
+const cpl_frame *
+cpl_frameset_get_position_const(const cpl_frameset *self, cpl_size position)
+{
+
+    const cxchar *const _id = "cpl_frameset_get_position_const";
+
+    cx_list_iterator _position = NULL;
+
+    cx_multimap_iterator frame = NULL;
+
+
+    if (self == NULL) {
+        cpl_error_set(_id, CPL_ERROR_NULL_INPUT);
+        return NULL;
+    }
+
+    if ((position < 0) || (position >= cpl_frameset_get_size(self))) {
+        cpl_error_set(_id, CPL_ERROR_ILLEGAL_INPUT);
+        return NULL;
+    }
+
+    _position = cx_list_begin(self->history);
+
+    while (position > 0) {
+        _position = cx_list_next(self->history, _position);
+        --position;
+    }
+
+    frame = cx_list_get(self->history, _position);
+    cx_assert(frame != cx_multimap_end(self->frames));
+
+    return cx_multimap_get_value(self->frames, frame);
+
+}
+
+
 /**
  * @brief
  *   Extract a subset of frames from a set of frames
@@ -1462,9 +1867,11 @@ cpl_frameset_get_frame(cpl_frameset *set, cpl_size position)
  * @param self           Input frame set
  * @param labels         The array of labels associated to each input frame
  * @param desired_label  The label identifying the requested frames
- * @note  The array of labels must have (at least) the length of the frameset
  *
- * @return a pointer to a newly allocated frame set or NULL on error
+ * @note  The array of labels must have (at least) the length of the frame set
+ *
+ * @return
+ *  A pointer to a newly allocated frame set or NULL on error
  *
  * @error
  *   <table class="ec" align="center">
@@ -1567,5 +1974,4 @@ cpl_frameset_dump(const cpl_frameset *self, FILE *stream)
 
     return;
 }
-
 /**@}*/
