@@ -1,4 +1,4 @@
-/* $Id: cpl_frameset.h,v 1.20 2012/01/11 13:38:29 rpalsa Exp $
+/* $Id: cpl_frameset.h,v 1.24 2013/01/24 07:50:20 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/01/11 13:38:29 $
- * $Revision: 1.20 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/01/24 07:50:20 $
+ * $Revision: 1.24 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifndef CPL_FRAMESET_H
@@ -96,22 +96,31 @@ cpl_error_code cpl_frameset_erase_frame(cpl_frameset *self, cpl_frame *frame);
  */
 
 const cpl_frame *cpl_frameset_get_frame_const(const cpl_frameset *self,
-                                              cpl_size position);
-cpl_frame *cpl_frameset_get_frame(cpl_frameset *self, cpl_size position);
+                                              cpl_size position) CPL_ATTR_DEPRECATED;
+cpl_frame *cpl_frameset_get_frame(cpl_frameset *self, cpl_size position) CPL_ATTR_DEPRECATED;
+
+
+cpl_frame *cpl_frameset_get_position(cpl_frameset *self, cpl_size position);
+
+const cpl_frame *cpl_frameset_get_position_const(const cpl_frameset *self,
+                                                 cpl_size position);
 
 /*
  * Miscellaneous functions
  */
 
-cpl_size *
-cpl_frameset_labelise(const cpl_frameset *self,
-                      int (*compare)(const cpl_frame *, const cpl_frame *),
-                      cpl_size *nb_labels);
+cpl_error_code cpl_frameset_join(cpl_frameset *self, const cpl_frameset *other);
+cpl_error_code cpl_frameset_sort(cpl_frameset *self,
+                                 cpl_frame_compare_func compare);
 
 cpl_frameset *cpl_frameset_extract(const cpl_frameset *self,
                                    const cpl_size *labels,
                                    cpl_size desired_label) CPL_ATTR_ALLOC;
 
+cpl_size *cpl_frameset_labelise(const cpl_frameset *self,
+                                int (*compare)(const cpl_frame *,
+                                const cpl_frame *), cpl_size *nb_labels);
+
 void cpl_frameset_dump(const cpl_frameset *self, FILE *stream);
 
 CPL_END_DECLS
