@@ -1,4 +1,4 @@
-/* $Id: cpl_parameter.h,v 1.15 2010/11/11 10:31:52 llundin Exp $
+/* $Id: cpl_parameter.h,v 1.16 2013/02/11 13:30:57 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2010/11/11 10:31:52 $
- * $Revision: 1.15 $
- * $Name: cpl-6_2 $
+ * $Author: rpalsa $
+ * $Date: 2013/02/11 13:30:57 $
+ * $Revision: 1.16 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifndef CPL_PARAMETER_H
@@ -155,6 +155,8 @@ cpl_parameter *cpl_parameter_new_enum(const char *name, cpl_type type,
                                       const char *description,
                                       const char *context, ...) CPL_ATTR_ALLOC;
 
+cpl_parameter *cpl_parameter_duplicate(const cpl_parameter *other) CPL_ATTR_ALLOC;
+
 void cpl_parameter_delete(cpl_parameter *self);
 
 
