@@ -1,4 +1,4 @@
-/* $Id: cpl_parameterlist.c,v 1.15 2012/01/11 13:38:29 rpalsa Exp $
+/* $Id: cpl_parameterlist.c,v 1.16 2012/12/13 13:54:18 rpalsa Exp $
  *
  * This file is part of the ESO Common Pipeline Library
  * Copyright (C) 2001-2005 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/01/11 13:38:29 $
- * $Revision: 1.15 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/12/13 13:54:18 $
+ * $Revision: 1.16 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -908,7 +908,7 @@ cpl_parameterlist_find_tag_const(const cpl_parameterlist *self, const char *tag)
         }
         else {
 
-            if (_tag != NULL) {
+            if ((tag != NULL) && (_tag != NULL)) {
 
                 if (strcmp(_tag, tag) == 0) {
                     return p;
