@@ -1,4 +1,4 @@
-/* $Id: cpl_parameter-test.c,v 1.9 2010/11/11 09:23:18 llundin Exp $
+/* $Id: cpl_parameter-test.c,v 1.10 2013/02/11 13:31:29 rpalsa Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2005 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2010/11/11 09:23:18 $
- * $Revision: 1.9 $
- * $Name: cpl-6_2 $
+ * $Author: rpalsa $
+ * $Date: 2013/02/11 13:31:29 $
+ * $Revision: 1.10 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,16 +35,20 @@
 int main(void)
 {
 
-    const char    *sval1 = "abcdefghijklmnopqrstuvwxyz";
-    const char    *sval2 = "zyxwvutsrqponmlkjihgfedcba";
-    cpl_error_code error;
-    int            ival;
+    const cxchar *sval1 = "abcdefghijklmnopqrstuvwxyz";
+    const cxchar *sval2 = "zyxwvutsrqponmlkjihgfedcba";
 
-    cpl_parameter *p;
+    cxint ival = 0;
+
+    cpl_error_code error = CPL_ERROR_NONE;
+
+    cpl_parameter *p = NULL;
+    cpl_parameter *q = NULL;
 
 
     cpl_test_init(PACKAGE_BUGREPORT, CPL_MSG_WARNING);
 
+
     /*
      * Test 1: Create a string parameter and check its validity
      */
@@ -115,11 +119,73 @@ int main(void)
     cpl_test_noneq_string(cpl_parameter_get_default_string(p),
                           cpl_parameter_get_string(p));
 
+    cpl_parameter_delete(p);
+
 
     /*
-     * Test 3: Test some error handling
+     * Test 3: Copy a parameter
      */
 
+    p = cpl_parameter_new_enum("a", CPL_TYPE_STRING, "A string enum.",
+                               "None", sval1, 2, sval1, sval2);
+
+    q = cpl_parameter_duplicate(p);
+
+    cpl_test_nonnull(q);
+
+    cpl_test_eq(cpl_parameter_get_class(q),
+                cpl_parameter_get_class(p));
+    cpl_test_eq(cpl_parameter_get_type(q),
+                cpl_parameter_get_type(p));
+
+    cpl_test_eq_string(cpl_parameter_get_name(q),
+                       cpl_parameter_get_name(p));
+    cpl_test_noneq_ptr(cpl_parameter_get_name(q),
+                       cpl_parameter_get_name(p));
+
+    cpl_test_eq_string(cpl_parameter_get_context(q),
+                       cpl_parameter_get_context(p));
+    cpl_test_noneq_ptr(cpl_parameter_get_context(q),
+                       cpl_parameter_get_context(p));
+
+    cpl_test_eq_string(cpl_parameter_get_help(q),
+                       cpl_parameter_get_help(p));
+    cpl_test_noneq_ptr(cpl_parameter_get_help(q),
+                       cpl_parameter_get_help(p));
+
+    cpl_test_eq_string(cpl_parameter_get_default_string(q),
+                       cpl_parameter_get_default_string(p));
+    cpl_test_noneq_ptr(cpl_parameter_get_default_string(q),
+                       cpl_parameter_get_default_string(p));
+
+    cpl_test_eq_string(cpl_parameter_get_string(q),
+                       cpl_parameter_get_string(p));
+    cpl_test_noneq_ptr(cpl_parameter_get_string(q),
+                       cpl_parameter_get_string(p));
+
+    cpl_test_eq(cpl_parameter_get_enum_size(q),
+                cpl_parameter_get_enum_size(p));
+
+    cpl_test_eq_string(cpl_parameter_get_enum_string(q, 0),
+                       cpl_parameter_get_enum_string(p, 0));
+    cpl_test_noneq_ptr(cpl_parameter_get_enum_string(q, 0),
+                       cpl_parameter_get_enum_string(p, 0));
+    cpl_test_eq_string(cpl_parameter_get_enum_string(q, 1),
+                       cpl_parameter_get_enum_string(p, 1));
+    cpl_test_noneq_ptr(cpl_parameter_get_enum_string(q, 1),
+                       cpl_parameter_get_enum_string(p, 1));
+
+    cpl_parameter_delete(q);
+    cpl_parameter_delete(p);
+
+
+    /*
+     * Test 4: Test some error handling
+     */
+
+    p = cpl_parameter_new_value("a", CPL_TYPE_STRING, "A string value.",
+                                "None", sval1);
+
     error = cpl_parameter_set_int(p, 0);
     cpl_test_eq_error(error, CPL_ERROR_TYPE_MISMATCH);
 
@@ -132,6 +198,7 @@ int main(void)
 
     cpl_parameter_delete(p);
 
+
     /*
      * All tests finished
      */
