@@ -1,4 +1,4 @@
-/* $Id: cpl_parameterlist-test.c,v 1.4 2010/11/11 09:23:18 llundin Exp $
+/* $Id: cpl_parameterlist-test.c,v 1.5 2012/12/13 14:21:29 rpalsa Exp $
  *
  *   This file is part of the ESO Common Pipeline Library
  *   Copyright (C) 2001-2005 European Southern Observatory
@@ -19,10 +19,10 @@
  */
 
 /*
- * $Author: llundin $
- * $Date: 2010/11/11 09:23:18 $
- * $Revision: 1.4 $
- * $Name: cpl-6_2 $
+ * $Author: rpalsa $
+ * $Date: 2012/12/13 14:21:29 $
+ * $Revision: 1.5 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,6 +35,8 @@
 int main(void)
 {
 
+    const cpl_parameter *cq = NULL;
+
     cpl_parameter *p[4];
     cpl_parameter *q = NULL;
 
@@ -97,8 +99,8 @@ int main(void)
 
 
     /*
-     * Test 4: Add a user tag to one of the parameters an check whether it
-     *        can be found by looking for the tag.
+     * Test 4: Add a user tag to one of the parameters and check whether it
+     *         can be found by looking for the tag.
      */
 
     error = cpl_parameter_set_tag(p[2], "mytag");
@@ -115,6 +117,38 @@ int main(void)
     cpl_parameterlist_delete(list);
 
 
+    /*
+     * Test 5: Check cpl_parameterlist_find_tag_const handles invalid
+     *         tags (passed as argument or as member of the list to search)
+     *         gracefully.
+     */
+
+    list = cpl_parameterlist_new();
+    cpl_test_nonnull(list);
+    p[0] = cpl_parameter_new_value("a", CPL_TYPE_STRING, "parameter1",
+                                   "None", "value1");
+    cpl_test_nonnull(p[0]);
+    error = cpl_parameter_set_tag(p[0], "mytag");
+    cpl_test_eq_error(error, CPL_ERROR_NONE);
+    error = cpl_parameterlist_append(list, p[0]);
+    cpl_test_eq_error(error, CPL_ERROR_NONE);
+    
+    cq = cpl_parameterlist_find_tag_const(list, NULL);
+    cpl_test_null(cq);
+    cpl_test_eq_error(error, CPL_ERROR_NONE);
+    
+    p[1] = cpl_parameter_new_value("b", CPL_TYPE_STRING, "parameter2",
+                                   "None", "value2");
+    cpl_test_nonnull(p[1]);
+    error = cpl_parameterlist_append(list, p[1]);
+    cpl_test_eq_error(error, CPL_ERROR_NONE);
+    
+    cq = cpl_parameterlist_find_tag_const(list, NULL);
+    cpl_test_eq_ptr(cq, p[1]);
+    cpl_test_eq_error(error, CPL_ERROR_NONE);
+    
+    cpl_parameterlist_delete(list);
+
     /*
      * All tests succeeded
      */
