@@ -1,4 +1,4 @@
-/* $Id: cxdeque.c,v 1.12 2012/03/13 15:52:56 rpalsa Exp $
+/* $Id: cxdeque.c,v 1.13 2012/12/18 16:05:45 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/03/13 15:52:56 $
- * $Revision: 1.12 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/12/18 16:05:45 $
+ * $Revision: 1.13 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,39 +37,6 @@
 #include "cxdeque.h"
 
 
-#if 0
-static cx_compare_func current_compare;
-
-#ifdef _OPENMP
-#pragma omp threadprivate(current_compare)
-#endif
-
-struct stable
-{
-   cxint indx;
-   cxptr member;
-};
-
-
-static cxint
-compare_stable(cxcptr *a, cxcptr *b)
-{
-
-    cxint comp = current_compare(((struct stable *)a)->member,
-                ((struct stable *)b)->member);
-
-    /* If members compare equal, compare their indices */
-
-    if (comp == 0) {
-        return ((struct stable *)a)->indx - ((struct stable *)b)->indx;
-    }
-
-    return comp;
-
-}
-#endif
-
-
 /**
  * @defgroup cxdeque Double-ended queue.
  *
