@@ -1,4 +1,4 @@
-/* $Id: cxmemory.c,v 1.10 2011/02/21 14:15:31 rpalsa Exp $
+/* $Id: cxmemory.c,v 1.11 2013/02/08 09:07:13 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2011/02/21 14:15:31 $
- * $Revision: 1.10 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/08 09:07:13 $
+ * $Revision: 1.11 $
+ * $Name: cpl-6_3_1 $
  */
 
 /*
@@ -75,7 +75,7 @@
 
 static cxbool cx_memory_vtable_lock = FALSE;
 
-CX_LOCK_DEFINE_STATIC(cx_memory_vtable_lock);
+CX_LOCK_DEFINE_INITIALIZED_STATIC(cx_memory_vtable_lock);
 
 
 /*
@@ -84,7 +84,7 @@ CX_LOCK_DEFINE_STATIC(cx_memory_vtable_lock);
  * initialization function.
  */
 
-CX_ONCE_DEFINE_STATIC(cx_memory_once);
+CX_ONCE_DEFINE_INITIALIZED_STATIC(cx_memory_once);
 
 /*
  * Internal initialization functions for the memory system. This
