@@ -1,4 +1,4 @@
-/* $Id: cxmessages.c,v 1.9 2011/03/04 12:15:10 rpalsa Exp $
+/* $Id: cxmessages.c,v 1.10 2013/02/08 09:11:27 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2011/03/04 12:15:10 $
- * $Revision: 1.9 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/08 09:11:27 $
+ * $Revision: 1.10 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -105,7 +105,8 @@ struct _cx_log_domain_ {
  */
 
 CX_LOCK_DEFINE_STATIC(cx_messages_lock);
-CX_ONCE_DEFINE_STATIC(cx_messages_once);
+
+CX_ONCE_DEFINE_INITIALIZED_STATIC(cx_messages_once);
 
 
 /*
@@ -608,6 +609,8 @@ static void
 _cx_log_thread_init(void)
 {
 
+    CX_INITLOCK(cx_messages_lock, CX_MUTEX_TYPE_RECURSIVE);
+
     cx_private_init(cx_log_depth, NULL);
     cx_log_prefix_init();
     cx_debug_init();
