@@ -1,4 +1,4 @@
-/* $Id: cxtree.c,v 1.9 2011/02/21 14:15:31 rpalsa Exp $
+/* $Id: cxtree.c,v 1.10 2012/12/10 14:36:49 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2011/02/21 14:15:31 $
- * $Revision: 1.9 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/12/10 14:36:49 $
+ * $Revision: 1.10 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -1721,7 +1721,7 @@ cx_tree_erase_position(cx_tree *tree, cx_tree_iterator position)
 
     cx_assert(tree != NULL);
 
-    if (!position) {
+    if (!position || _cx_tree_node_count(tree) == 0) {
         return;
     }
 
