@@ -1,4 +1,4 @@
-/* $Id: cxutils.c,v 1.15 2012/03/06 16:35:50 rpalsa Exp $
+/* $Id: cxutils.c,v 1.16 2013/02/08 09:07:13 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2012/03/06 16:35:50 $
- * $Revision: 1.15 $
- * $Name: cpl-6_2 $
+ * $Date: 2013/02/08 09:07:13 $
+ * $Revision: 1.16 $
+ * $Name: cpl-6_3_1 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -88,7 +88,7 @@
 
 static cxchar *cx_program_name = NULL;
 
-CX_LOCK_DEFINE_STATIC(cx_program_name);
+CX_LOCK_DEFINE_INITIALIZED_STATIC(cx_program_name);
 
 
 /**
