@@ -1,4 +1,4 @@
-/* $Id: cxstring-test.c,v 1.9 2011/02/21 14:15:31 rpalsa Exp $
+/* $Id: cxstring-test.c,v 1.10 2012/12/12 09:37:21 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,9 +20,9 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2011/02/21 14:15:31 $
- * $Revision: 1.9 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/12/12 09:37:21 $
+ * $Revision: 1.10 $
+ * $Name: cpl-6_3_1 $
  */
 
 #undef CX_DISABLE_ASSERT
@@ -507,6 +507,64 @@ test7(void)
 }
 
 
+static cxbool
+test8(void)
+{
+    cx_string *a       = NULL;
+    cx_string *b       = NULL;
+
+    cxbool    f_passed = TRUE;
+
+    a = cx_string_create("this is a test string");
+    b = cx_string_create("this is a test");
+
+    if (cx_string_erase(a, 14, -1) != NULL) {
+        if (verbose == TRUE) {
+            cx_print("cx_string_erase          : PASSED\n");
+        }
+    }
+    else {
+        if (verbose == TRUE) {
+            cx_print("cx_string_erase          : FAILED\n");
+        }
+        f_passed = FALSE;
+    }
+
+    if (cx_string_compare(a, b) == 0) {
+        if (verbose == TRUE) {
+            cx_print("cx_string_compare        : PASSED\n");
+        }
+    }
+    else {
+        if (verbose == TRUE) {
+            cx_print("cx_string_compare        : FAILED\n");
+        }
+        f_passed = FALSE;
+    }
+
+    cx_string_delete(b);
+    cx_string_delete(a);
+    
+    a = cx_string_new();
+    
+    if (cx_string_erase(a, 0, 0) != NULL) {
+        if (verbose == TRUE) {
+            cx_print("cx_string_erase          : PASSED\n");
+        }
+    }
+    else {
+        if (verbose == TRUE) {
+            cx_print("cx_string_erase          : FAILED\n");
+        }
+        f_passed = FALSE;
+    }
+    
+    cx_string_delete(a);
+
+    return f_passed;
+}
+
+
 int
 main(void) {
 
@@ -535,6 +593,9 @@ main(void) {
     /* Test 7: cx_string with copy functions */
     f_passed = f_passed && test7();
 
+    /* Test 8: cx_string erase function, end of string removal */
+    f_passed = f_passed && test8();
+
     if (f_passed != TRUE) {
     return 1;
     }
