@@ -1,4 +1,4 @@
-/* $Id: cxtree-test.c,v 1.8 2011/02/21 14:15:31 rpalsa Exp $
+/* $Id: cxtree-test.c,v 1.10 2012/12/10 14:43:58 rpalsa Exp $
  *
  * This file is part of the ESO C Extension Library
  * Copyright (C) 2001-2011 European Southern Observatory
@@ -20,22 +20,81 @@
 
 /*
  * $Author: rpalsa $
- * $Date: 2011/02/21 14:15:31 $
- * $Revision: 1.8 $
- * $Name: cpl-6_2 $
+ * $Date: 2012/12/10 14:43:58 $
+ * $Revision: 1.10 $
+ * $Name: cpl-6_3_1 $
  */
 
+
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #undef CX_DISABLE_ASSERT
 #undef CX_LOG_DOMAIN
 
+/*
+ * FIXME: Needed to get sigaction when C standard is set to strict c99.
+ *        A more portable way of asynchronously checking for a timeout
+ *        would be preferred!
+ */
+
+#if !defined(_POSIX_C_SOURCE)
+#define _POSIX_C_SOURCE 200112L
+#endif
+
+#ifdef HAVE_UNISTD_H
+#  include <unistd.h>
+#endif
+
+#include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <signal.h>
+#include <errno.h>
 
 #include "cxmemory.h"
 #include "cxmessages.h"
 #include "cxtree.h"
 
 
+
+/*
+ * The name of the current test being run. This should be updated just before
+ * calling the alarm() routine in a test for infinite loops so we can print
+ * a more informative message in the signal handler.
+ */
+
+static const cxchar* current_test_name = "unknown";
+
+
+/*
+ * Signal handler for the alarm timer to prevent the infinit loop test from
+ * actually hanging forever.
+ */
+
+static void
+cx_signal_handler(cxint signo)
+{
+
+    if (signo == SIGALRM) {
+
+        /*
+         * Should normally be very careful about what we call inside an
+         * asynchronous signal handler. But if we arrived at this point then
+         * we assume we have an infinit loop, which is an error condition.
+         * Anyway cx_error() will abort the process, so we dont care so much.
+         */
+
+        cx_error("An infinite loop detected in: %s.", current_test_name);
+
+    }
+
+	return;
+
+}
+
+
 static cxbool
 cx_test_tree_less_char(cxcptr a, cxcptr b)
 {
@@ -105,6 +164,7 @@ cx_test_tree_dump(cx_tree *tree, cxint fmt)
 }
 #endif
 
+
 int
 main(void)
 {
@@ -119,6 +179,23 @@ main(void)
     cx_tree_iterator pos, _pos;
     cx_tree_iterator first, last;
 
+    struct sigaction signal_info;
+
+
+    /*
+     * Register the signal handler for the alarm signal which is used during
+     * the infinite loop tests.
+     */
+
+    memset(&signal_info, 0x0, sizeof signal_info);
+
+    signal_info.sa_handler = &cx_signal_handler;
+    sigemptyset(&signal_info.sa_mask);
+
+    if (sigaction(SIGALRM, &signal_info, NULL) != 0) {
+        cx_error("Could not set signal handler: %s", strerror(errno));
+        return EXIT_FAILURE;
+    }
 
 
     /*
@@ -604,6 +681,33 @@ main(void)
     cx_tree_delete(tree);
 
 
+    /*
+     * Test 16: The following code sequence causes an infinite loop at
+     *          cxtree.c:447 for broken versions of libcext 0.1.0.
+     *          Should check if this still happens for new versions.
+     */
+
+    current_test_name = "Test 16 for infinite loop in cx_tree_erase_position";
+
+    /*
+     * Set the alarm for 10 seconds. If this test is not done by then we have
+     * to assume we are in an infinite loop.
+     */
+
+    alarm(10);
+
+    tree = cx_tree_new(cx_test_tree_less_char, NULL, NULL);
+    cx_assert(tree != NULL);
+    cx_tree_erase_position(tree, cx_tree_begin(tree));
+    cx_tree_delete(tree);
+
+	/*
+     *  Will stop any more alarm signals for subsequent tests.
+     */
+
+    alarm(0);
+
+
     /*
      * All tests succeeded
      */
